@@ -29,7 +29,7 @@ FXDEFMAP(BrowseInputDialog) BrowseInputDialogMap[]=
 FXIMPLEMENT(BrowseInputDialog,DialogBox,BrowseInputDialogMap,ARRAYNUMBER(BrowseInputDialogMap))
 
 // Construct a dialog box
-BrowseInputDialog::BrowseInputDialog(FXWindow *win,FXString inp,FXString message,FXString title,FXString label,FXIcon *ic, FXuint browse, FXbool option, FXString optiontext):
+BrowseInputDialog::BrowseInputDialog(FXWindow *win,FXString inp,FXString message,FXString title,FXString label,FXIcon *ic, unsigned int browse, FXbool option, FXString optiontext):
         DialogBox(win,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
     // Browse type flag
@@ -125,7 +125,7 @@ long BrowseInputDialog::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 	// File dialog
 	FileDialog browse(this,title);	
 		
-	const FXchar *patterns[]=
+	const char *patterns[]=
 		{
 			_("All Files"),          "*",	NULL
 		};
@@ -157,7 +157,7 @@ void BrowseInputDialog::setMessage(FXString message)
 	// Compute the equivalent size in number of columns of '8' of the message string,
 	// taking into account the real size of the font characters
 	FXFont *font=getApp()->getNormalFont();
-	FXint nbcols = (FXint)ceil ( (FXdouble)font->getTextWidth(message) / (FXdouble)font->getCharWidth('8') );
+	int nbcols = (int)ceil ( (double)font->getTextWidth(message) / (double)font->getCharWidth('8') );
 
 	// Tricks to adjust the dialog width to the real text size
 	this->setWidth(1);
@@ -196,10 +196,16 @@ void BrowseInputDialog::setIcon(FXIcon* icon)
 void BrowseInputDialog::SelectAll()
 {
 	input->setSelection(0,(input->getText()).length());
-};
+}
 
 
 void BrowseInputDialog::CursorEnd()
 {
 	input->onCmdCursorEnd(0,0,0);
 }
+
+
+FXbool BrowseInputDialog::setSelection(FXint pos, FXint len)
+{
+	input->setSelection(pos,len);
+}
