@@ -40,7 +40,7 @@ FXIMPLEMENT(CommandWindow,DialogBox,CommandWindowMap,ARRAYNUMBER(CommandWindowMa
 
 
 // Construct window which will always float over the owner window
-CommandWindow::CommandWindow(FXWindow *owner, const FXString& name, FXString strcmd, FXint nblines, FXint nbcols):
+CommandWindow::CommandWindow(FXWindow *owner, const FXString& name, FXString strcmd, int nblines, int nbcols):
         DialogBox(owner,name,DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE|DECOR_MAXIMIZE,0,0,0,0, 6,6,6,6, 4,4)
 {
 
@@ -53,7 +53,7 @@ CommandWindow::CommandWindow(FXWindow *owner, const FXString& name, FXString str
     FXButton *cancelbutton=new FXButton(buttonbox,_("&Cancel"),NULL,this,ID_KILLPROCESS,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);
 
     // Text part
-    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
+    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN,0,0,0,0, 0,0,0,0);
     text=new FXText(textbox,NULL,0,TEXT_READONLY|TEXT_WORDWRAP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     text->setVisibleRows(nblines);
     text->setVisibleColumns(nbcols);
@@ -62,7 +62,7 @@ CommandWindow::CommandWindow(FXWindow *owner, const FXString& name, FXString str
 }
 
 // Construct free-floating window
-CommandWindow::CommandWindow(FXApp* a, const FXString& name, FXString strcmd, FXint nblines, FXint nbcols):
+CommandWindow::CommandWindow(FXApp* a, const FXString& name, FXString strcmd, int nblines, int nbcols):
         DialogBox(a,name,DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE|DECOR_MAXIMIZE|DECOR_MINIMIZE,0,0,0,0, 6,6,6,6, 4,4)
 {
     // Get command to execute
@@ -74,7 +74,7 @@ CommandWindow::CommandWindow(FXApp* a, const FXString& name, FXString strcmd, FX
     FXButton *cancelbutton=new FXButton(buttonbox,_("&Cancel"),NULL,this,ID_KILLPROCESS,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);
 
     // Text part
-    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
+    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN,0,0,0,0, 0,0,0,0);
     text=new FXText(textbox,NULL,0,TEXT_READONLY|TEXT_WORDWRAP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     text->setVisibleRows(nblines);
     text->setVisibleColumns(nbcols);
@@ -139,7 +139,7 @@ long CommandWindow::onUpdClose(FXObject* sender,FXSelector,void*)
 
 
 // Execute a command and capture its output
-FXint CommandWindow::execCmd(FXString command)
+int CommandWindow::execCmd(FXString command)
 {
     // Open pipes to communicate with child process
     if (pipe(pipes)==-1)
@@ -182,8 +182,8 @@ FXint CommandWindow::execCmd(FXString command)
 // Watch progress of child process
 long CommandWindow::onWatchProcess(FXObject*,FXSelector,void*)
 {
-	FXchar  buf[1024];
-	FXint   nread;
+	char  buf[1024];
+	int   nread;
 
 	if (closed)
 	{
@@ -204,7 +204,7 @@ long CommandWindow::onWatchProcess(FXObject*,FXSelector,void*)
         getApp()->addChore(this,ID_WATCHPROCESS);
 
 		// Read data from the running child (first, set I-O to non-blocking)
-        FXint pflags;
+        int pflags;
         if ( (pflags = fcntl(pipes[0],F_GETFL)) >= 0 )
         {
             pflags |= O_NONBLOCK;
@@ -219,7 +219,7 @@ long CommandWindow::onWatchProcess(FXObject*,FXSelector,void*)
 					strbuf=strbuf.substitute("\b",".");
                     text->appendText(strbuf.text(),strlen(strbuf.text()));
 					scrollToLastLine();
-                    if ( nread  < (FXint)(sizeof(buf)-1) )
+                    if ( nread  < (int)(sizeof(buf)-1) )
                         break;
                 }
             }
@@ -238,7 +238,7 @@ long CommandWindow::onWatchProcess(FXObject*,FXSelector,void*)
 			strbuf=strbuf.substitute("\b",".");
 			text->appendText(strbuf.text(),strlen(strbuf.text()));
 			scrollToLastLine();
-			if ( nread  < (FXint)(sizeof(buf)-1) )
+			if ( nread  < (int)(sizeof(buf)-1) )
 				break;
 		}
 		if (killed)
@@ -269,14 +269,14 @@ long CommandWindow::onCmdClose(FXObject*,FXSelector,void*)
 }
 
 // Change the text in the buffer to new text
-void CommandWindow::setText(const FXchar* str)
+void CommandWindow::setText(const char* str)
 {
 	text->setText(str,strlen(str));
 	getApp()->repaint();
 }
 
 // Append new text at the end of the buffer
-void CommandWindow::appendText(const FXchar* str)
+void CommandWindow::appendText(const char* str)
 {
 	text->appendText(str,strlen(str));
 	getApp()->repaint();
@@ -290,7 +290,7 @@ void CommandWindow::scrollToLastLine(void)
 }
 
 // Get text length
-FXint CommandWindow::getLength(void)
+int CommandWindow::getLength(void)
 {
 	return (text->getLength());
 }
