@@ -25,14 +25,14 @@ FXIMPLEMENT(DialogBox,FXTopWindow,DialogBoxMap,ARRAYNUMBER(DialogBoxMap))
 
 
 // Contruct dialog which will stay on top of owner
-DialogBox::DialogBox(FXWindow* win,const FXString& name,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb,FXint hs,FXint vs):
+DialogBox::DialogBox(FXWindow* win,const FXString& name,unsigned int opts,int x,int y,int w,int h,int pl,int pr,int pt,int pb,int hs,int vs):
         FXTopWindow(win,name,NULL,NULL,opts,x,y,w,h,pl,pr,pt,pb,hs,vs)
 {
     _option = 0;
 }
 
 // Contruct free floating dialog
-DialogBox::DialogBox(FXApp* a,const FXString& name,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb,FXint hs,FXint vs):
+DialogBox::DialogBox(FXApp* a,const FXString& name,unsigned int opts,int x,int y,int w,int h,int pl,int pr,int pt,int pb,int hs,int vs):
         FXTopWindow(a,name,NULL,NULL,opts,x,y,w,h,pl,pr,pt,pb,hs,vs)
 {
     _option = 0;
@@ -74,7 +74,7 @@ long DialogBox::onCmdToggleOption(FXObject*,FXSelector,void*)
 }
 
 // Get option state
-FXuint DialogBox::getOption()
+unsigned int DialogBox::getOption()
 {
     return _option;
 }
@@ -88,11 +88,10 @@ void DialogBox::create()
 }
 
 // Show window such that the cursor is in it
-void DialogBox::show(FXuint placement)
+void DialogBox::show(unsigned int placement)
 {
-#if 0
-    FXint rw,rh,wx,wy,ww,wh,x,y;
-    FXuint state;
+    int rw,rh,wx,wy,ww,wh,x,y;
+    unsigned int state;
 
     // Get dialog size
     translateCoordinatesTo(wx,wy,getRoot(),0,0);
@@ -132,7 +131,6 @@ void DialogBox::show(FXuint placement)
 
         move(wx,wy);
     }
-#endif
 
     // Pop the window
     FXTopWindow::show(placement);
@@ -153,7 +151,7 @@ long DialogBox::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 
 
 // Execute dialog box modally
-FXuint DialogBox::execute(FXuint placement)
+unsigned int DialogBox::execute(unsigned int placement)
 {
     create();
     show(placement);
