@@ -26,14 +26,14 @@ public:
         ID_LAST
     };
 public:
-    DialogBox(FXWindow* win,const FXString& name,FXuint opts=DECOR_TITLE|DECOR_BORDER,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=10,FXint pr=10,FXint pt=10,FXint pb=10,FXint hs=4,FXint vs=4);
-    DialogBox(FXApp* a,const FXString& name,FXuint opts=DECOR_TITLE|DECOR_BORDER,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=10,FXint pr=10,FXint pt=10,FXint pb=10,FXint hs=4,FXint vs=4);
-    virtual void show(FXuint placement=PLACEMENT_CURSOR);
+    DialogBox(FXWindow* win,const FXString& name,unsigned int opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0,int w=0,int h=0,int pl=10,int pr=10,int pt=10,int pb=10,int hs=4,int vs=4);
+    DialogBox(FXApp* a,const FXString& name,unsigned int opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0,int w=0,int h=0,int pl=10,int pr=10,int pt=10,int pb=10,int hs=4,int vs=4);
+    virtual void show(unsigned int placement=PLACEMENT_CURSOR);
     virtual void create();
-    FXuint execute(FXuint placement=PLACEMENT_CURSOR);
-    FXuint getOption();
+    unsigned int execute(unsigned int placement=PLACEMENT_CURSOR);
+    unsigned int getOption();
 protected:
-    FXuint _option;
+    unsigned int _option;
 };
 
 
