@@ -34,18 +34,18 @@ public:
 public:
 
     // Construct list box with given caption, icon, message text, and with choices from array of strings
-    DirHistBox(FXWindow* owner,const FXchar** choices,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    DirHistBox(FXWindow* owner,const char** choices,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Construct list box with given caption, icon, message text, and with choices from newline separated strings
-    DirHistBox(FXWindow* owner,const FXString& choices,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    DirHistBox(FXWindow* owner,const FXString& choices,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
 
 	// Show a modal list dialog. Prompt the user using a dialog with given caption, icon, message text, and with choices from newline array of strings.
     // The return value is -1 if cancelled, or the given choice
-    static FXint box(FXWindow* owner,FXuint opts,const FXchar** choices,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    static int box(FXWindow* owner,unsigned int opts,const char** choices,int x=0,int y=0,int w=0,int h=0);
 
     // Show a modal list dialog. Prompt the user using a dialog with given caption, icon, message text, and with choices from newline separated strings.
     // The return value is -1 if cancelled, or the given choice
-    static FXint box(FXWindow* owner,FXuint opts,const FXString& choices,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    static int box(FXWindow* owner,unsigned int opts,const FXString& choices,int x=0,int y=0,int w=0,int h=0);
 
     // Destroy list box
     virtual ~DirHistBox();
