@@ -92,7 +92,8 @@ FXDEFMAP(DirList) DirListMap[]=
 	FXMAPFUNC(SEL_COMMAND,DirList::ID_SORT_REVERSE,DirList::onCmdSortReverse),
 	FXMAPFUNC(SEL_COMMAND,DirList::ID_REFRESH,DirList::onCmdRefresh),
 	FXMAPFUNC(SEL_COMMAND,DirList::ID_SORT_CASE,DirList::onCmdSortCase),
-	FXMAPFUNC(SEL_UPDATE,DirList::ID_SORT_CASE,DirList::onUpdSortCase)
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_SORT_CASE,DirList::onUpdSortCase),
+	FXMAPFUNC(SEL_UPDATE,0,DirList::onUpdRefreshTimers),
 };
 
 
@@ -102,7 +103,7 @@ FXIMPLEMENT(DirList,FXTreeList,DirListMap,ARRAYNUMBER(DirListMap))
 
 
 // Directory List Widget
-DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
         FXTreeList(p,tgt,sel,opts,x,y,w,h),pattern("*")
 {
     flags|=FLAG_ENABLED|FLAG_DROPTARGET;
@@ -203,7 +204,6 @@ DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,
 // Create the directory list
 void DirList::create()
 {
-
     FXTreeList::create();
     if(!deleteType)
         deleteType=getApp()->registerDragType(deleteTypeName);
@@ -224,8 +224,8 @@ void DirList::create()
 // Expand folder tree when hovering long over a folder
 long DirList::onExpandTimer(FXObject* sender,FXSelector sel,void* ptr)
 {
-    FXint xx,yy;
-    FXuint state;
+    int xx,yy;
+    unsigned int state;
     DirItem *item;
 
     getCursorPosition(xx,yy,state);
@@ -253,41 +253,41 @@ TreeItem* DirList::createItem(const FXString& text,FXIcon* oi,FXIcon* ci,void* p
 
 
 // Sort ascending order, keeping directories first
-FXint DirList::ascending(const FXTreeItem* pa,const FXTreeItem* pb)
+int DirList::ascending(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
-    register FXint diff=(FXint)b->isDirectory() - (FXint)a->isDirectory();
+    register int diff=(int)b->isDirectory() - (int)a->isDirectory();
     return diff ? diff : compare(a->label,b->label);
 }
 
 
 // Sort descending order, keeping directories first
-FXint DirList::descending(const FXTreeItem* pa,const FXTreeItem* pb)
+int DirList::descending(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
-    register FXint diff=(FXint)b->isDirectory() - (FXint)a->isDirectory();
+    register int diff=(int)b->isDirectory() - (int)a->isDirectory();
     return diff ? diff : compare(b->label,a->label);
 }
 
 
 // Sort ascending order, case insensitive, keeping directories first
-FXint DirList::ascendingCase(const FXTreeItem* pa,const FXTreeItem* pb)
+int DirList::ascendingCase(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
-    register FXint diff=(FXint)b->isDirectory() - (FXint)a->isDirectory();
+    register int diff=(int)b->isDirectory() - (int)a->isDirectory();
     return diff ? diff : comparecase(a->label,b->label);
 }
 
 
 // Sort descending order, case insensitive, keeping directories first
-FXint DirList::descendingCase(const FXTreeItem* pa,const FXTreeItem* pb)
+int DirList::descendingCase(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
-    register FXint diff=(FXint)b->isDirectory() - (FXint)a->isDirectory();
+    register int diff=(int)b->isDirectory() - (int)a->isDirectory();
     return diff ? diff : comparecase(b->label,a->label);
 }
 
@@ -361,8 +361,8 @@ long DirList::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr)
             if(::isWritable(dropdirectory))
             {
                 acceptDrop(DRAG_ACCEPT);
-                FXint x,y;
-                FXuint state;
+                int x,y;
+                unsigned int state;
                 getCursorPosition(x,y,state);
                 TreeItem* item=(TreeItem*)getItemAt(x,y);
 
@@ -420,10 +420,10 @@ long DirList::onCmdDragReject(FXObject* sender,FXSelector sel,void* ptr)
 // Handle drag-and-drop drop
 long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 {
-	FXuchar *data;
-    FXuint len;
+	unsigned char *data;
+    unsigned int len;
     FXbool showdialog=TRUE;
-	FXint ret;
+	int ret;
     File *f=NULL;
 
     FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
@@ -460,8 +460,8 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 		// Display a popup to select the drag type
 		dropaction=DRAG_REJECT;
 		FXMenuPane menu(this);
-		FXint x,y;
-		FXuint state;
+		int x,y;
+		unsigned int state;
 		getRoot()->getCursorPosition(x,y,state);
 		new FXMenuCommand(&menu,_("Copy here"),copy_clpicon,this,DirList::ID_DRAG_COPY);
 		new FXMenuCommand(&menu,_("Move here"),moveiticon,this,DirList::ID_DRAG_MOVE);
@@ -487,10 +487,10 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
     //if(getDNDData(FROM_DRAGNDROP,urilistType,data,len))
     if(dnd)  // See comment upper
     {
-        FXRESIZE(&data,FXuchar,len+1);
+        FXRESIZE(&data,unsigned char,len+1);
         data[len]='\0';
-        FXchar *p,*q;
-        p=q=(FXchar*)data;
+        char *p,*q;
+        p=q=(char*)data;
         
 		// Number of selected items
 		FXString buf=p;
@@ -498,7 +498,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 		
 		// Eventually correct the number of selected items
 		// because sometimes there is another '\n' at the end of the string
-		FXint pos=buf.rfind('\n');
+		int pos=buf.rfind('\n');
 		if (pos==buf.length()-1)
 			num=num-1;
 
@@ -704,8 +704,8 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 long DirList::onDNDRequest(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXEvent *event=(FXEvent*)ptr;
-    FXuchar *data;
-    FXuint len;
+    unsigned char *data;
+    unsigned int len;
 
     // Perhaps the target wants to supply its own data
     if(FXTreeList::onDNDRequest(sender,sel,ptr))
@@ -717,7 +717,7 @@ long DirList::onDNDRequest(FXObject* sender,FXSelector sel,void* ptr)
         if(!dragfiles.empty())
         {
             len=dragfiles.length();
-            FXMEMDUP(&data,dragfiles.text(),FXuchar,len);
+            FXMEMDUP(&data,dragfiles.text(),unsigned char,len);
             setDNDData(FROM_DRAGNDROP,event->target,data,len);
         }
         return 1;
@@ -1082,42 +1082,41 @@ FXbool DirList::collapseTree(TreeItem* tree,FXbool notify)
 // To periodically scan /proc/mounts and refresh the mtdevices list
 long DirList::onMtdevicesRefresh(FXObject*,FXSelector,void*)
 {
-	// Do the refresh only if xfe has the focus
-	//if (focuswindow->hasFocus())
-	//{
-		struct mntent *mnt;
-
-		FXStringDict* tmpdict = new FXStringDict();
-		FILE *mtab=setmntent(MTAB_PATH,"r");
-		if(mtab)
+	// Don't refresh if window is minimized
+	if (((FXTopWindow*)focuswindow)->isMinimized())
+		return 0;
+ 
+	struct mntent *mnt;
+	FXStringDict* tmpdict = new FXStringDict();
+	FILE *mtab=setmntent(MTAB_PATH,"r");
+	if(mtab)
+	{
+		while((mnt=getmntent(mtab)))
 		{
-			while((mnt=getmntent(mtab)))
+			// To fix an issue with some Linux distributions
+			FXString mntdir=mnt->mnt_dir;
+			if (mntdir!="/dev/.static/dev" &&   mntdir.rfind(".gvfs",5,mntdir.length())==-1)
 			{
-				// To fix an issue with some Linux distributions
-				FXString mntdir=mnt->mnt_dir;
-				if (mntdir!="/dev/.static/dev" &&   mntdir.rfind(".gvfs",5,mntdir.length())==-1)
-				{
-					tmpdict->insert(mnt->mnt_dir,"");
-					if (mtdevices->find(mnt->mnt_dir))
-						mtdevices->remove(mnt->mnt_dir);
-					mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
-				}
+				tmpdict->insert(mnt->mnt_dir,"");
+				if (mtdevices->find(mnt->mnt_dir))
+					mtdevices->remove(mnt->mnt_dir);
+				mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
 			}
-			endmntent(mtab);
 		}
+		endmntent(mtab);
+	}
 
-		// Remove mount points that don't exist anymore
-		FXint s;
-		const FXchar *key, *data;
-		for (s = mtdevices->first(); s < mtdevices->size(); s = mtdevices->next(s))
-		{
-			key = mtdevices->key(s);
-			data = mtdevices->data(s);
-			if (!tmpdict->find(mtdevices->key(s)))
-				mtdevices->remove(mtdevices->key(s));
-		}
-		delete tmpdict;
-	//}
+	// Remove mount points that don't exist anymore
+	int s;
+	const char *key, *data;
+	for (s = mtdevices->first(); s < mtdevices->size(); s = mtdevices->next(s))
+	{
+		key = mtdevices->key(s);
+		data = mtdevices->data(s);
+		if (!tmpdict->find(mtdevices->key(s)))
+			mtdevices->remove(mtdevices->key(s));
+	}
+	delete tmpdict;
     
 	// Reset timer again
     getApp()->addTimeout(this,ID_MTDEVICES_REFRESH,MTDEVICES_INTERVAL*1000);
@@ -1129,6 +1128,10 @@ long DirList::onMtdevicesRefresh(FXObject*,FXSelector,void*)
 // NB : the refresh period is much longer than for onMtdevicesRefresh
 long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
 {
+	// Don't refresh if window is minimized
+	if (((FXTopWindow*)focuswindow)->isMinimized())
+		return 0;
+
     struct mntent *mnt;
     struct stat statbuf;
     FXString mtstate;
@@ -1166,8 +1169,8 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
     }
 
     // Remove mount points that don't exist anymore
-    FXint s;
-    const FXchar *key, *data;
+    int s;
+    const char *key, *data;
     for (s = updevices->first(); s < updevices->size(); s = updevices->next(s))
     {
         key = updevices->key(s);
@@ -1188,6 +1191,10 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
 // Refresh with timer
 long DirList::onCmdRefreshTimer(FXObject*,FXSelector,void*)
 {
+	// Don't refresh if window is minimized
+	if (((FXTopWindow*)focuswindow)->isMinimized())
+		return 0;
+
     if(flags&FLAG_UPDATE)
     {
         scan(FALSE);
@@ -1339,12 +1346,16 @@ void DirList::listChildItems(DirItem *par)
     struct stat    info;
     FXString pathname, directory, name;
 	FXString type, mod, usrid, grpid, atts, del;
-    FXint islink;
+	FXString timeformat;
+    int islink;
 	long deldate;
 
     // Path to parent node
     directory=getItemPathname((TreeItem*)par);
 
+	// Read time format
+	timeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
+
     // Build new insert-order list
     oldlist=par->list;
     newlist=NULL;
@@ -1541,7 +1552,7 @@ fnd:
 			FXString atts=::permissions(info.st_mode);
 			
 			// Modification time
-			mod=FXSystem::time("%x %X",item->date);
+			mod=FXSystem::time(timeformat.text(),item->date);
 
 			// If we are in trash can, obtain the deletion time
 			deldate=0;
@@ -1554,7 +1565,7 @@ fnd:
 				str=str.rbefore('-');
 				deldate=strtol(str.text(),&endptr,10);
 				if (deldate!=0)
-					del=FXSystem::time("%x %X",deldate);
+					del=FXSystem::time(timeformat.text(),deldate);
 			}
 
 #if defined(linux)
@@ -1707,7 +1718,7 @@ FXString DirList::getItemPathname(const TreeItem* item) const
 TreeItem* DirList::getPathnameItem(const FXString& path)
 {
     register TreeItem *item,*it;
-    register FXint beg=0,end=0;
+    register int beg=0,end=0;
     FXString name;
     if(!path.empty())
     {
@@ -1844,7 +1855,7 @@ FXbool DirList::showFiles() const
 // Change list style
 void DirList::showFiles(FXbool showing)
 {
-    FXuint opts=options;
+    unsigned int opts=options;
     if(showing)
         opts|=DIRLIST_SHOWFILES;
     else
@@ -1867,7 +1878,7 @@ FXbool DirList::shownHiddenFiles() const
 // Change show hidden files mode
 void DirList::showHiddenFiles(FXbool showing)
 {
-    FXuint opts=options;
+    unsigned int opts=options;
     if(showing)
         opts|=DIRLIST_SHOWHIDDEN;
     else
@@ -1902,7 +1913,7 @@ void DirList::setPattern(const FXString& ptrn)
 
 
 // Change file match mode
-void DirList::setMatchMode(FXuint mode)
+void DirList::setMatchMode(unsigned int mode)
 {
     if(matchmode!=mode)
     {
@@ -1927,4 +1938,25 @@ DirList::~DirList()
     associations=(FileDict*)-1;
 }
 
+// Update refresh timers if the window gains focus
+long DirList::onUpdRefreshTimers(FXObject*,FXSelector,void*)
+{
+	static FXbool prevMinimized=TRUE;
+	static FXbool minimized=TRUE;
 
+	prevMinimized=minimized;
+	if (((FXTopWindow*)focuswindow)->isMinimized())
+		minimized=FALSE;
+	else
+		minimized=TRUE;
+
+	// Update refresh timers
+	if (prevMinimized == FALSE && minimized == TRUE)
+	{
+		onCmdRefreshTimer(0,0,0);
+		onMtdevicesRefresh(0,0,0);
+		onUpdevicesRefresh(0,0,0);
+	}
+
+    return 1;
+}
