@@ -28,7 +28,7 @@ protected:
     FileAssoc  *assoc;              // File association
     DirItem    *link;               // Link to next item
     DirItem    *list;               // List of child items
-    FXlong      size;               // File size (if a file)
+    FXulong      size;               // File size (if a file)
     FXTime      date;               // Time of item
     FXString	tdata;				// Tooltip data
 protected:
@@ -83,7 +83,7 @@ public:
     {
         return assoc;
     }
-    unsigned long getSize() const
+    FXulong getSize() const
     {
         return size;
     }
@@ -113,8 +113,8 @@ protected:
     FXDragAction	dropaction;				// Drop action
     FXString		dragfiles;				// Dragged files
     FXString		pattern;				// Pattern of file names
-    FXuint			matchmode;				// File wildcard match mode
-    FXuint			counter;				// Refresh counter
+    unsigned int			matchmode;				// File wildcard match mode
+    unsigned int			counter;				// Refresh counter
 	FXString		trashfileslocation;     // Location of the trash files directory
 	FXString		trashinfolocation;      // Location of the trash info directory
 	FXWindow		*focuswindow;			// Window used to test focus
@@ -122,7 +122,7 @@ protected:
     DirList()
     {}
     virtual TreeItem* createItem(const FXString& text,FXIcon* oi,FXIcon* ci,void* ptr);
-    TreeItem* getitem(FXchar* pathname);
+    TreeItem* getitem(char* pathname);
     void listRootItems();
     void listChildItems(DirItem *par);
 private:
@@ -170,11 +170,12 @@ public:
 	long onCmdDragMove(FXObject* sender,FXSelector,void*);
 	long onCmdDragLink(FXObject* sender,FXSelector,void*);
 	long onCmdDragReject(FXObject* sender,FXSelector,void*);
+	long onUpdRefreshTimers(FXObject*,FXSelector,void*);
 public:
-    static FXint ascending(const FXTreeItem* a,const FXTreeItem* b);
-    static FXint descending(const FXTreeItem* a,const FXTreeItem* b);
-    static FXint ascendingCase(const FXTreeItem* a,const FXTreeItem* b);
-    static FXint descendingCase(const FXTreeItem* a,const FXTreeItem* b);
+    static int ascending(const FXTreeItem* a,const FXTreeItem* b);
+    static int descending(const FXTreeItem* a,const FXTreeItem* b);
+    static int ascendingCase(const FXTreeItem* a,const FXTreeItem* b);
+    static int descendingCase(const FXTreeItem* a,const FXTreeItem* b);
 public:
     enum {
         ID_REFRESH_TIMER=FXTreeList::ID_LAST,
@@ -202,7 +203,7 @@ public:
 public:
 
     // Construct a directory list
-    DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
@@ -256,13 +257,13 @@ public:
     }
 
     // Return wildcard matching mode
-    FXuint getMatchMode() const
+    unsigned int getMatchMode() const
     {
         return matchmode;
     }
 
     // Change wildcard matching mode
-    void setMatchMode(FXuint mode);
+    void setMatchMode(unsigned int mode);
 
     // Return TRUE if showing files as well as directories
     FXbool showFiles() const;
