@@ -26,7 +26,7 @@
 
 
 // Refresh interval for the directory size (ms)
-#define DIRSIZE_INTERVAL 1000
+#define DIRSIZE_REFRESH_INTERVAL 1000
 
 // Duration (in ms) before we can stop refreshing the file list
 // Used for file operations on a large list of files
@@ -37,7 +37,7 @@
 
 // Clipboard
 extern FXString clipboard;
-extern FXuint clipboard_type;
+extern unsigned int clipboard_type;
 
 // Global variables
 extern FXMainWindow *mainWindow;
@@ -46,7 +46,7 @@ extern FXbool allowPopupScroll;
 extern FXStringDict* fsdevices;
 extern FXStringDict* mtdevices;
 #endif
-extern FXuint single_click;
+extern unsigned int single_click;
 extern FXString xdgdatahome;
 
 
@@ -60,7 +60,7 @@ long FXTreeList::onKeyPress(FXObject*,FXSelector,void* ptr)
     FXEvent* event=(FXEvent*)ptr;
     FXTreeItem *item=currentitem;
     FXTreeItem *succ;
-    FXint page;
+    int page;
     flags&=~FLAG_TIP;
     if (!isEnabled())
 		return 0;
@@ -263,7 +263,7 @@ hop:
             handle(this,FXSEL(SEL_COMMAND,0),(void*)currentitem);
         return 1;
     default:
-        if ((FXuchar)event->text[0]<' ')
+        if ((unsigned char)event->text[0]<' ')
 			return 0;
         if (event->state&(CONTROLMASK|ALTMASK))
 			return 0;
@@ -345,17 +345,18 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
 	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_DELETE,DirPanel::onUpdDirDelete),
 	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_NEW_DIR,DirPanel::onUpdMenu),
 	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TITLE,DirPanel::onUpdTitle),
+	FXMAPFUNC(SEL_UPDATE,0,DirPanel::onUpdDirsizeRefresh),
 };
 
 // Object implementation 
 FXIMPLEMENT(DirPanel,FXVerticalFrame,DirPanelMap,ARRAYNUMBER(DirPanelMap))
 
 // Construct Directory Panel
-DirPanel::DirPanel(FXWindow *owner, FXComposite *p, FXColor listbackcolor, FXColor listforecolor, FXbool smoothscroll, FXuint opts, FXint x, FXint y, FXint w, FXint h):
+DirPanel::DirPanel(FXWindow *owner, FXComposite *p, FXColor listbackcolor, FXColor listforecolor, FXbool smoothscroll, unsigned int opts, int x, int y, int w, int h):
         FXVerticalFrame(p,opts,x,y,w,h,0,0,0,0)
 {
 	// Construct directory panel
-    FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0, 0,0);
+    FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_NONE,0,0,0,0, 0,0,0,0, 0,0);
 	FXPacker* packer=new FXHorizontalFrame(cont,LAYOUT_LEFT|JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_NONE,0,0,0,0, 0,0,0,0);
 	
 	// Visually indicate if the panel is active
@@ -366,7 +367,7 @@ DirPanel::DirPanel(FXWindow *owner, FXComposite *p, FXColor listbackcolor, FXCol
 	paneltitle->setText(_("Folders"));
 	paneltitle->setBackColor(getApp()->getBaseColor());
 
-	FXuint options;
+	unsigned int options;
 	if (smoothscroll)
 		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|TREELIST_BROWSESELECT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|FRAME_SUNKEN;
 	else
@@ -383,7 +384,7 @@ DirPanel::DirPanel(FXWindow *owner, FXComposite *p, FXColor listbackcolor, FXCol
     new FXToggleButton(statusbar,TAB+_("Show hidden folders")+PARS(key),TAB+_("Hide hidden folders")+PARS(key),showhiddenicon,hidehiddenicon,this,
 	                   ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_NONE);
 
-    status=new FXLabel(statusbar,_("0 bytes in root"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
+    status=new FXLabel(statusbar,_("0 bytes in root"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_NONE);
     status->setTarget(this);
     status->setSelector(FXSEL(SEL_UPDATE,DirPanel::ID_TITLE));
 
@@ -448,7 +449,7 @@ void DirPanel::create()
 	// Register standard UTF-8 text type used for file dialogs 
 	utf8Type=getApp()->registerDragType("UTF8_STRING");
 
-    getApp()->addTimeout(this,ID_DIRSIZE_REFRESH,DIRSIZE_INTERVAL);
+    getApp()->addTimeout(this,ID_DIRSIZE_REFRESH,DIRSIZE_REFRESH_INTERVAL);
 	FXVerticalFrame::create();
 }
 
@@ -515,8 +516,8 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
 		
 		// Remember latest directory in the location address
        	FXString item;
-		FXint i=0;
-		FXint count=address->getNumItems();
+		int i=0;
+		int count=address->getNumItems();
        	FXString p=currentpanel->getDirectory();
 
 		if(!count)
@@ -593,8 +594,8 @@ long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	}
 
 	// Current item becomes item under cursor
-	FXint x, y, xitem, yitem;
-    FXuint state;
+	int x, y, xitem, yitem;
+    unsigned int state;
 	getRoot()->getCursorPosition(x,y,state);
 	list->getCursorPosition(xitem,yitem,state);   	    
 	DirItem* item=(DirItem*)list->getItemAt(xitem,yitem);
@@ -687,7 +688,7 @@ long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 
 
 // Helper function used to explore the directory tree and expand or collapse it
-long DirPanel::exploreUp(DirItem *item, const DirItem *rootitem, const FXint task)
+long DirPanel::exploreUp(DirItem *item, const DirItem *rootitem, const int task)
 {
 	DirItem* parentitem=item;
 	
@@ -706,7 +707,7 @@ long DirPanel::exploreUp(DirItem *item, const DirItem *rootitem, const FXint tas
 
 
 // Helper function used to explore the directory tree and expand or collapse it
-long DirPanel::exploreDown(DirItem *item, const DirItem *rootitem, const FXint task)
+long DirPanel::exploreDown(DirItem *item, const DirItem *rootitem, const int task)
 {
 	if (item==rootitem)
 		return 1;
@@ -836,7 +837,7 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 			cmd="bzip2 -v ";				
 		else if (ext1=="xz")
 			cmd="xz -v ";				
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
             cmd="tar -jcvf "+archive+" ";
 		else if (ext1=="txz")
             cmd="tar -Jcvf "+archive+" ";
@@ -900,8 +901,8 @@ long DirPanel::onClipboardLost(FXObject* sender,FXSelector sel,void* ptr)
 long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXEvent *event=(FXEvent*)ptr;
-    FXuchar *data;
-    FXuint len;
+    unsigned char *data;
+    unsigned int len;
 
 	// Perhaps the target wants to supply its own data for the clipboard
     if(FXVerticalFrame::onClipboardRequest(sender,sel,ptr))
@@ -929,7 +930,7 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 			if(!clipboard.empty())
 			{
 				len=clipboard.length();
-				FXMEMDUP(&data,clipboard.text(),FXuchar,len);
+				FXMEMDUP(&data,clipboard.text(),unsigned char,len);
 				setDNDData(FROM_CLIPBOARD,event->target,data,len);
 				
 				// Return because xfelistType is not compatible with other types
@@ -952,7 +953,7 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
         // Return clipboard content
         if(event->target==kdelistType)
         {
-			FXMEMDUP(&data,flag.text(),FXuchar,1);
+			FXMEMDUP(&data,flag.text(),unsigned char,1);
 			setDNDData(FROM_CLIPBOARD,event->target,data,1);
 		}
     }
@@ -963,7 +964,7 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 		if(!clipboard.empty())
 		{
 			len=clipboard.length();
-			FXMEMDUP(&data,clipboard.text(),FXuchar,len);
+			FXMEMDUP(&data,clipboard.text(),unsigned char,len);
 			setDNDData(FROM_CLIPBOARD,event->target,data,len);
 		
 			return 1;
@@ -975,7 +976,7 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
     {
 		if(!clipboard.empty())
 		{			
-			FXint beg=0, end=0;
+			int beg=0, end=0;
 			FXString str="";
 			FXString filepath, url;
 
@@ -1037,7 +1038,7 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 			if(!str.empty())
 			{
 				len=str.length();
-				FXMEMDUP(&data,str.text(),FXuchar,len);
+				FXMEMDUP(&data,str.text(),unsigned char,len);
 				setDNDData(FROM_CLIPBOARD,event->target,data,len);
 			
 				return 1;
@@ -1081,11 +1082,11 @@ long DirPanel::onCmdCopyCut(FXObject*,FXSelector sel,void*)
 // Paste file(s) from clipboard
 long DirPanel::onCmdPaste(FXObject*,FXSelector sel,void*)
 {
-    FXuchar *data;
-    FXuint len;
-	FXint beg, end, pos;
+    unsigned char *data;
+    unsigned int len;
+	int beg, end, pos;
 	FXString chaine, url, param;		  
-	FXint num=0;
+	int num=0;
 	FXbool from_kde=FALSE;
 	
     // Target directory
@@ -1094,10 +1095,10 @@ long DirPanel::onCmdPaste(FXObject*,FXSelector sel,void*)
 	// If source is xfelistType (Gnome, XFCE, or Xfe app)
     if(getDNDData(FROM_CLIPBOARD,xfelistType,data,len))
     {		
-        FXRESIZE(&data,FXuchar,len+1);
+        FXRESIZE(&data,unsigned char,len+1);
         data[len]='\0';
 		
-		clipboard=(FXchar*)data;
+		clipboard=(char*)data;
 		
 		// Loop over clipboard items
 		for(beg=0; beg<clipboard.length(); beg=end+1)
@@ -1177,9 +1178,9 @@ long DirPanel::onCmdPaste(FXObject*,FXSelector sel,void*)
     {		
         from_kde=TRUE;
 
-        FXRESIZE(&data,FXuchar,len+1);
+        FXRESIZE(&data,unsigned char,len+1);
         data[len]='\0';
-		clipboard=(FXchar*)data;
+		clipboard=(char*)data;
 				
 		// Obtain clipboard type (copy or cut)
 		if (clipboard=="1")
@@ -1198,9 +1199,9 @@ long DirPanel::onCmdPaste(FXObject*,FXSelector sel,void*)
 		if (!from_kde)
 			clipboard_type=COPY_CLIPBOARD;
 
-        FXRESIZE(&data,FXuchar,len+1);
+        FXRESIZE(&data,unsigned char,len+1);
         data[len]='\0';
-		clipboard=(FXchar*)data;
+		clipboard=(char*)data;
 				
 		// Loop over clipboard items
 		for(beg=0; beg<clipboard.length(); beg=end+1)
@@ -1256,7 +1257,7 @@ long DirPanel::onCmdStopListRefreshTimer(FXObject*,FXSelector,void*)
 // Copy/Move/Rename/Symlink directory
 long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 {
-	FXint num;
+	int num;
 	FXString src, targetdir, target, name, source;
 
 	// Confirmation dialog?
@@ -1325,6 +1326,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
         {
             message=_("Copy ");
             message+=source;
+            target+=name;
 		}
         else
 			message.format(_("Copy %s items from: %s"),FXStringVal(num).text(),dir.text());
@@ -1380,6 +1382,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
         {
             message=_("Move ");
             message+=source;
+            target+=name;
             title=_("Move");
         }
         else
@@ -1394,6 +1397,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
         {
             message=_("Symlink ");
             message+=source;
+            target+=name;
         }
         else
 			message.format(_("Symlink %s items from: %s"),FXStringVal(num).text(),dir.text());
@@ -1408,6 +1412,8 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 		operationdialog->setIcon(icon);
 		operationdialog->setMessage(message);
 		operationdialog->setText(target);
+		if (FXSELID(sel)==ID_DIR_RENAME)
+			operationdialog->SelectAll();
 		operationdialog->CursorEnd();
 		operationdialog->setDirectory(targetdir);
 		int rc=1;
@@ -1475,7 +1481,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 
 	// One source
 	File *f=NULL;
-	FXint ret;
+	int ret;
     if(num==1)
 	{
 		// An empty source file name corresponds to the ".." file
@@ -1608,7 +1614,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 	// Multiple sources
 	// Note : rename cannot be used in this case!
     else if(num>1)
-    {
+    {		
 		// Wait cursor
 		getApp()->beginWaitCursor();
 
@@ -1847,7 +1853,7 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 		FXString msg;
 		msg.format(_("Folder %s is write-protected, definitively delete it anyway?"),pathname.text());
 		MessageBox box(this,_("Confirm Delete"),msg,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
-		FXuint answer=box.execute(PLACEMENT_OWNER);
+		unsigned int answer=box.execute(PLACEMENT_OWNER);
 		if(answer == BOX_CLICKED_OK)
 		{
 			f->showProgressDialog();
@@ -1941,7 +1947,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		FXString str;
 		str.format(_("Folder %s is write-protected, move it to trash can anyway?"),pathname.text());
 		MessageBox box(this,_("Confirm Trash"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
-		FXuint answer=box.execute(PLACEMENT_OWNER);
+		unsigned int answer=box.execute(PLACEMENT_OWNER);
 		if(answer == BOX_CLICKED_OK)
 		{
 			// Allow progress dialog
@@ -1954,7 +1960,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 			createTrashinfo(pathname,trashpathname,trashfileslocation,trashinfolocation);
 
 			// Move file to trash files location
-			FXint ret=f->move(pathname,trashpathname);
+			int ret=f->move(pathname,trashpathname);
 
 			// An error has occurred
 			if (ret==0 && !f->isCancelled())
@@ -1987,7 +1993,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		createTrashinfo(pathname,trashpathname,trashfileslocation,trashinfolocation);
 
 		// Move file to trash files location
-		FXint ret=f->move(pathname,trashpathname);
+		int ret=f->move(pathname,trashpathname);
 
 		// An error has occurred
 		if (ret==0 && !f->isCancelled())
@@ -2039,7 +2045,7 @@ long DirPanel::onCmdDirRestore(FXObject*,FXSelector,void*)
 	
 	// Read the .trashinfo file
 	FILE *fp;
-	FXchar line[1024];
+	char line[1024];
 	FXbool success=TRUE;
 	FXString trashinfopathname=trashinfolocation+PATHSEPSTRING+trashbasename+".trashinfo";
 	FXString origpathname="";
@@ -2101,8 +2107,8 @@ long DirPanel::onCmdDirRestore(FXObject*,FXSelector,void*)
 			{
 				f->showProgressDialog();
 				errno=0;
-				FXint ret=mkpath(origparentdir.text(),0755);
-				FXint errcode=errno;
+				int ret=mkpath(origparentdir.text(),0755);
+				int errcode=errno;
 				if (ret==-1)
 				{
 					f->hideProgressDialog();
@@ -2116,7 +2122,7 @@ long DirPanel::onCmdDirRestore(FXObject*,FXSelector,void*)
 		}
 
 		// Move file to original location (with restore option)
-		FXint ret=f->move(pathname,origpathname,TRUE);
+		int ret=f->move(pathname,origpathname,TRUE);
 		
 		// An error has occurred
 		if (ret==0 && !f->isCancelled())
@@ -2174,20 +2180,20 @@ long DirPanel::onCmdNewDir(FXObject*,FXSelector,void*)
         if(dirname!=dirpath)
         {
 			// Create the new dir according to the current umask
-			FXint mask;
+			int mask;
 			mask=umask(0);
 			umask(mask);
 			
 			// Note that the umask value is in decimal (511 means octal 0777)
 			errno=0;
-			FXint ret=::mkdir(dirname.text(),511 & ~mask);
-			FXint errcode=errno;
+			int ret=::mkdir(dirname.text(),511 & ~mask);
+			int errcode=errno;
 			if (ret==-1)
 			{
          		if (errcode)
-					MessageBox::error(this,BOX_OK_SU,_("Error"),"Can't create folder %s : %s",dirname.text(),strerror(errcode));
+					MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't create folder %s : %s"),dirname.text(),strerror(errcode));
 				else
-					MessageBox::error(this,BOX_OK_SU,_("Error"),"Can't create folder %s",dirname.text());
+					MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't create folder %s"),dirname.text());
     			return 0;
 			}
 		}							
@@ -2317,8 +2323,8 @@ long DirPanel::onUpdUnmount(FXObject* o,FXSelector sel,void*)
 // Update the paste button
 long DirPanel::onUpdPaste(FXObject* o,FXSelector,void*)
 {
-    FXuchar *data;
-    FXuint len;	
+    unsigned char *data;
+    unsigned int len;	
 	FXString buf;
 	FXbool clipboard_empty=TRUE;
 	
@@ -2328,9 +2334,9 @@ long DirPanel::onUpdPaste(FXObject* o,FXSelector,void*)
 	// If source is xfelistType (Gnome, XFCE, or Xfe app)
     if (getDNDData(FROM_CLIPBOARD,xfelistType,data,len))
     {		
-        FXRESIZE(&data,FXuchar,len+1);
+        FXRESIZE(&data,unsigned char,len+1);
         data[len]='\0';
-		buf=(FXchar*)data;
+		buf=(char*)data;
 		
 		// Check if valid clipboard
 		if (buf.find("file:/")>=0)
@@ -2343,9 +2349,9 @@ long DirPanel::onUpdPaste(FXObject* o,FXSelector,void*)
 	// If source type is urilistType (KDE apps ; non Gnome, non XFCE and non Xfe apps)
 	else if (getDNDData(FROM_CLIPBOARD,urilistType,data,len))
 	{		
-		FXRESIZE(&data,FXuchar,len+1);
+		FXRESIZE(&data,unsigned char,len+1);
 		data[len]='\0';
-		buf=(FXchar*)data;
+		buf=(char*)data;
 		
 		// Test if valid clipboard
 		if (buf.find("file:/")>=0)
@@ -2486,11 +2492,11 @@ void DirPanel::setAllowDirsizeRefresh(FXbool flag)
 // Refresh the directory size in the status bar
 long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
 {
-	// Refresh only if desired 
-	if (!allowDirsizeRefresh)
+	// Don't refresh if not allowed or window is minimized
+	if (!allowDirsizeRefresh || ((FXTopWindow*)focuswindow)->isMinimized())
 		return 0;
-	
-	unsigned long long dnsize;
+
+	FXulong dnsize;
 	char dsize[64];
 	FXString hsize;
 		
@@ -2534,7 +2540,7 @@ long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
 	}
 
     // Reset timer again
-    getApp()->addTimeout(this,ID_DIRSIZE_REFRESH,DIRSIZE_INTERVAL);
+    getApp()->addTimeout(this,ID_DIRSIZE_REFRESH,DIRSIZE_REFRESH_INTERVAL);
 
     // Important : returning 0 here avoids to continuously update the GUI!
     return 0;
@@ -2568,3 +2574,21 @@ long DirPanel::onUpdTitle(FXObject* sender,FXSelector,void*)
 }
 
 
+// Update dirsize refresh timer if the window gains focus
+long DirPanel::onUpdDirsizeRefresh(FXObject*,FXSelector,void*)
+{
+	static FXbool prevMinimized=TRUE;
+	static FXbool minimized=TRUE;
+
+	prevMinimized=minimized;
+	if (((FXTopWindow*)focuswindow)->isMinimized())
+		minimized=FALSE;
+	else
+		minimized=TRUE;
+
+	// Update timer if window is unminimized
+	if (prevMinimized == FALSE && minimized == TRUE)
+		onCmdDirsizeRefresh(0,0,0);
+
+    return 1;
+}
