@@ -45,7 +45,7 @@ protected:
 
 public:
 DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0), FXbool smoothscroll=TRUE,
-         FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+         unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
     DirPanel()
     {}
     virtual void create();
@@ -83,8 +83,8 @@ DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255)
 #endif
         ID_LAST,
     	};
-	long exploreUp(DirItem *item, const DirItem *rootitem, const FXint task);
-	long exploreDown(DirItem *item, const DirItem *rootitem, const FXint task);
+	long exploreUp(DirItem *item, const DirItem *rootitem, const int task);
+	long exploreDown(DirItem *item, const DirItem *rootitem, const int task);
 public:
 	long onClipboardGained(FXObject*,FXSelector,void*);
 	long onClipboardLost(FXObject*,FXSelector,void*);
@@ -121,6 +121,7 @@ public:
 	long onKeyPress(FXObject*,FXSelector,void*);
 	long onCmdFocus(FXObject*,FXSelector,void*);
 	long onCmdStopListRefreshTimer(FXObject*,FXSelector,void*);
+	long onUpdDirsizeRefresh(FXObject*,FXSelector,void*);
 #if defined(linux)
 	long onCmdMount(FXObject*,FXSelector,void*);
 #endif
