@@ -47,7 +47,7 @@ FXDEFMAP(File) FileMap[]={
 FXIMPLEMENT(File,DialogBox,FileMap,ARRAYNUMBER(FileMap))
 
 // Construct object
-File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(owner,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
+File::File(FXWindow *owner, FXString title, const unsigned int operation):DialogBox(owner,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
     // Progress window
 	FXPacker *buttons=new FXPacker(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,10,10,PROGRESSDIALOG_WIDTH,PROGRESSDIALOG_WIDTH,5,5);
@@ -64,7 +64,7 @@ File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(ow
 	progressbar=NULL;
 	
 	// Progress bar colors (foreground, text and alternate text)
-	FXuint r, g, b, l;
+	unsigned int r, g, b, l;
 	FXColor textcolor, textaltcolor;
 	FXColor fgcolor=getApp()->reg().readColorEntry("SETTINGS","pbarcolor",FXRGB(0,0,255));
 	FXColor bgcolor=getApp()->reg().readColorEntry("SETTINGS","backcolor",FXRGB(0,0,255));
@@ -73,7 +73,7 @@ File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(ow
 	r=FXREDVAL(fgcolor);                                                     
 	g=FXGREENVAL(fgcolor);                                                   
 	b=FXBLUEVAL(fgcolor);
-	l=(FXuint)(0.3*r+0.59*g+0.11*b);                                                                                  
+	l=(unsigned int)(0.3*r+0.59*g+0.11*b);                                                                                  
 	if (l<150)
 		textaltcolor=FXRGB(255,255,255);
 	else
@@ -83,7 +83,7 @@ File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(ow
 	r=FXREDVAL(bgcolor);                                                     
 	g=FXGREENVAL(bgcolor);                                                   
 	b=FXBLUEVAL(bgcolor);
-	l=(FXuint)(0.3*r+0.59*g+0.11*b);                                                                                  
+	l=(unsigned int)(0.3*r+0.59*g+0.11*b);                                                                                  
 	if (l<150)
 		textcolor=FXRGB(255,255,255);
 	else
@@ -220,9 +220,9 @@ void File::restartTimeout(void)
 
 
 // Read bytes
-long File::fullread(FXint fd, FXuchar* ptr,long len)
+FXlong File::fullread(int fd, unsigned char* ptr, FXlong len)
 {
-    long nread;
+    FXlong nread;
 #ifdef EINTR
     do
         nread=read(fd,ptr,len);
@@ -235,9 +235,9 @@ long File::fullread(FXint fd, FXuchar* ptr,long len)
 
 
 // Write bytes
-long File::fullwrite(FXint fd, const FXuchar* ptr,long len)
+FXlong File::fullwrite(int fd, const unsigned char* ptr, FXlong len)
 {
-    long nwritten,ntotalwritten=0;
+    FXlong nwritten, ntotalwritten=0;
     while(len>0)
     {
         nwritten=write(fd,ptr,len);
@@ -258,7 +258,7 @@ long File::fullwrite(FXint fd, const FXuchar* ptr,long len)
 
 
 // Construct overwrite dialog and get user answer
-FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
+unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 {
 	// Message string
 	FXString msg;
@@ -267,6 +267,9 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 	else
 		msg.format(_("File %s already exists. Overwrite?"),tgtpath.text());
 
+	// Read time format
+	FXString timeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
+
 	// Get the size and mtime of the source and target
 	struct stat linfo;
 	FXString srcsize, srcmtime, tgtsize, tgtmtime;
@@ -274,35 +277,35 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 	if (lstatrep(srcpath.text(),&linfo)==0)
 	{
 		statsrc=TRUE;
-		srcmtime=FXSystem::time("%c",linfo.st_mtime);
-		FXchar buf[MAXPATHLEN];
+		srcmtime=FXSystem::time(timeformat.text(),linfo.st_mtime);
+		char buf[MAXPATHLEN];
 		if (S_ISDIR(linfo.st_mode)) // Folder
 		{
-			unsigned long long dirsize=0;
-			FXuint nbfiles=0, nbsubfolders=0;
+			FXulong dirsize=0;
+			unsigned int nbfiles=0, nbsubfolders=0;
 			strlcpy(buf,srcpath.text(),srcpath.length()+1);
 			dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
 			snprintf(buf,sizeof(buf),"%llu",dirsize);
 		}
 		else // File
-			snprintf(buf,sizeof(buf),"%llu",(unsigned long long)linfo.st_size);					
+			snprintf(buf,sizeof(buf),"%llu",(FXulong)linfo.st_size);					
 		srcsize=::hSize(buf);
 	}			
 	if (lstatrep(tgtpath.text(),&linfo)==0)
 	{
 		stattgt=TRUE;
-		tgtmtime=FXSystem::time("%c",linfo.st_mtime);
-		FXchar buf[64];
+		tgtmtime=FXSystem::time(timeformat.text(),linfo.st_mtime);
+		char buf[64];
 		if (S_ISDIR(linfo.st_mode)) // Folder
 		{
-			unsigned long long dirsize=0;
-			FXuint nbfiles=0, nbsubfolders=0;
+			FXulong dirsize=0;
+			unsigned int nbfiles=0, nbsubfolders=0;
 			strlcpy(buf,tgtpath.text(),tgtpath.length()+1);
 			dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
 			snprintf(buf,sizeof(buf),"%llu",dirsize);
 		}
 		else // File
-			snprintf(buf,sizeof(buf),"%llu",(unsigned long long)linfo.st_size);					
+			snprintf(buf,sizeof(buf),"%llu",(FXulong)linfo.st_size);					
 		tgtsize=::hSize(buf);
 	}			
 	
@@ -317,7 +320,7 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 	
 	// Overwrite dialog
 	OverwriteBox* dlg = new OverwriteBox(this,_("Confirm Overwrite"),msg);
-	FXuint answer=dlg->execute(PLACEMENT_CURSOR);
+	unsigned int answer=dlg->execute(PLACEMENT_CURSOR);
 	delete dlg;
 	restartTimeout();
 
@@ -326,18 +329,20 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 
 
 // Copy ordinary file
-FXint File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
+int File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
 {
 	FXString destfile;
-	FXuchar buffer[32768];
+	unsigned char buffer[32768];
     struct stat info;
 	struct utimbuf timbuf;
-    long long nread, nwritten;
-	long long size, nread_all=0;
+    FXlong nread, nwritten;
+	FXlong size, nread_all=0;
 	double pct=0;
-    FXint src, dst;
+    int src, dst;
     FXbool ok=FALSE;
 
+	FXbool warn=getApp()->reg().readUnsignedEntry("OPTIONS","preserve_date_warn",TRUE);
+
     if((src=::open(source.text(),O_RDONLY))>=0)
     {
         if(statrep(source.text(),&info)==0)
@@ -356,7 +361,7 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
                 {
                     errno=0;
                     nread=File::fullread(src,buffer,sizeof(buffer));
-                    FXint errcode=errno;
+                    int errcode=errno;
                     if(nread<0)
 					{
 						forceTimeout();
@@ -367,7 +372,7 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
 						else
 							str.format(_("Can't copy file %s"),target.text());
 						mbox->setText(str);
-						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+						unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -421,7 +426,7 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
 						else
 							str.format(_("Can't copy file %s"),target.text());
 						mbox->setText(str);
-						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+						unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -442,9 +447,9 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
 					timbuf.actime=info.st_atime;
 					timbuf.modtime=info.st_mtime;
 					errno=0;
-					FXint rc=utime(destfile.text(),&timbuf);
-					FXint errcode=errno;
-					if (rc)
+					int rc=utime(destfile.text(),&timbuf);
+					int errcode=errno;
+					if (warn && rc)
 					{
 						forceTimeout();
 
@@ -454,12 +459,11 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
 						else
 							str.format(_("Can't preserve date when copying file %s"),target.text());
 						mbox->setText(str);
-						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+						unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 						
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
 						{
-							::close(dst);
 							::close(src);
 							cancelled=TRUE;
 							return FALSE;
@@ -486,7 +490,7 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
  	else
  	{
 		forceTimeout();
-		FXint errcode=errno;
+		int errcode=errno;
 
 		FXString str;
 		if (errcode)
@@ -494,7 +498,7 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
 		else
 			str.format(_("Can't copy file %s"),target.text());
 		mbox->setText(str);
-		FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+		unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 		restartTimeout();
 		if(answer == BOX_CLICKED_CANCEL)
@@ -511,7 +515,7 @@ FXint File::copyfile(const FXString& source, const FXString& target, const FXboo
 
 
 // Copy directory
-FXint File::copydir(const FXString& source,const FXString& target,struct stat& parentinfo,inodelist* inodes, const FXbool preserve_date)
+int File::copydir(const FXString& source,const FXString& target,struct stat& parentinfo,inodelist* inodes, const FXbool preserve_date)
 {
     DIR *dirp;
     struct dirent *dp;
@@ -520,6 +524,8 @@ FXint File::copydir(const FXString& source,const FXString& target,struct stat& p
     inodelist *in,inode;
     FXString destfile,oldchild,newchild;
 
+	FXbool warn=getApp()->reg().readUnsignedEntry("OPTIONS","preserve_date_warn",TRUE);
+
 	// Destination file
 	destfile=target;
 
@@ -579,7 +585,7 @@ FXint File::copydir(const FXString& source,const FXString& target,struct stat& p
 						str.format(_("Can't copy file %s : Permission denied"),oldchild.text());
        				forceTimeout();
 					mbox->setText(str);
-					FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+					unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 					restartTimeout();
 					if(answer == BOX_CLICKED_CANCEL)
@@ -604,9 +610,9 @@ FXint File::copydir(const FXString& source,const FXString& target,struct stat& p
 			timbuf.actime=linfo.st_atime;
 			timbuf.modtime=linfo.st_mtime;
 			errno=0;
-			FXint rc=utime(destfile.text(),&timbuf);
-			FXint errcode=errno;
-			if (rc)
+			int rc=utime(destfile.text(),&timbuf);
+			int errcode=errno;
+			if (warn && rc)
 			{
 				forceTimeout();
 				FXString str;
@@ -615,12 +621,11 @@ FXint File::copydir(const FXString& source,const FXString& target,struct stat& p
 				else
 					str.format(_("Can't preserve date when copying folder %s"),target.text());
 				mbox->setText(str);
-				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+				unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
 				{
-					closedir(dirp);
 					cancelled=TRUE;
 					return FALSE;
 				}					
@@ -634,7 +639,7 @@ FXint File::copydir(const FXString& source,const FXString& target,struct stat& p
 
 
 // Recursive copy
-FXint File::copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date)
+int File::copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date)
 {
     struct stat linfo1, linfo2;
 	
@@ -665,7 +670,7 @@ FXint File::copyrec(const FXString& source,const FXString& target,inodelist* ino
  	// Remove target if it already exists
  	if (::exists(target))
  	{
- 		FXint ret=File::remove(target);
+ 		int ret=File::remove(target);
  		if (!ret)
  			return FALSE;
 	}
@@ -694,7 +699,7 @@ FXint File::copyrec(const FXString& source,const FXString& target,inodelist* ino
 // Copy file (with progress dialog)
 // Return  0 to allow displaying an error message in the calling routine
 // Return -1 to prevent displaying an error message in the calling routine
-FXint File::copy(const FXString& source, const FXString& target, const FXbool confirm_dialog, const FXbool preserve_date)
+int File::copy(const FXString& source, const FXString& target, const FXbool confirm_dialog, const FXbool preserve_date)
 {
 	FXString targetfile;
 
@@ -740,7 +745,7 @@ FXint File::copy(const FXString& source, const FXString& target, const FXbool co
 			downlabel->setText(label);
 			getApp()->repaint();
 			forceTimeout();
-			FXuint answer=getOverwriteAnswer(source,targetfile);
+			unsigned int answer=getOverwriteAnswer(source,targetfile);
        		switch(answer)
        		{
 				// Cancel
@@ -792,7 +797,7 @@ FXint File::copy(const FXString& source, const FXString& target, const FXbool co
 
 
 // Remove file or directory (with progress dialog)
-FXint File::remove(const FXString& file)
+int File::remove(const FXString& file)
 {
 	FXString dirname;
     struct stat linfo;
@@ -852,7 +857,7 @@ FXint File::remove(const FXString& file)
             }
 			if (rmdir(file.text())==-1)
 			{
-				FXint errcode=errno;
+				int errcode=errno;
 				forceTimeout();
 
 				FXString str;
@@ -861,7 +866,7 @@ FXint File::remove(const FXString& file)
 				else
 					str.format(_("Can't delete folder %s"),file.text());
 				mbox->setText(str);
-				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+				unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
@@ -903,7 +908,7 @@ FXint File::remove(const FXString& file)
 			}
 			if (::unlink(file.text())==-1)
 			{
-				FXint errcode=errno;
+				int errcode=errno;
 				forceTimeout();
 
 				FXString str;
@@ -912,7 +917,7 @@ FXint File::remove(const FXString& file)
 				else
 					str.format(_("Can't delete file %s"),file.text());
 				mbox->setText(str);
-				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+				unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
 
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
@@ -934,7 +939,7 @@ FXint File::remove(const FXString& file)
 // Rename a file or a directory (no progress dialog)
 // Return  0 to allow displaying an error message in the calling routine
 // Return -1 to prevent displaying an error message in the calling routine
-FXint File::rename(const FXString& source, const FXString& target)
+int File::rename(const FXString& source, const FXString& target)
 {
 	// Source doesn't exist
     if(!::exists(source))
@@ -956,7 +961,7 @@ FXint File::rename(const FXString& source, const FXString& target)
 		// Overwrite dialog if necessary
 		if (!(overwrite_all | skip_all))
     	{
-       		FXuint answer=getOverwriteAnswer(source,target);
+       		unsigned int answer=getOverwriteAnswer(source,target);
 			switch(answer)
        		{
 				// Cancel
@@ -1001,7 +1006,7 @@ FXint File::rename(const FXString& source, const FXString& target)
 	}
 
 	// If files are on different file systems, use the copy/delete scheme and preserve the original date
-	FXint ret=this->copy(source,target,FALSE,TRUE);
+	int ret=this->copy(source,target,FALSE,TRUE);
 	if (ret)
 		return (remove(source.text())==TRUE);
 	else
@@ -1012,7 +1017,7 @@ FXint File::rename(const FXString& source, const FXString& target)
 // Move files
 // Return  0 to allow displaying an error message in the calling routine
 // Return -1 to prevent displaying an error message in the calling routine
-FXint File::move(const FXString& source,const FXString& target,const FXbool restore)
+int File::move(const FXString& source,const FXString& target,const FXbool restore)
 {
 	// Source doesn't exist
 	if(!::exists(source))
@@ -1076,7 +1081,7 @@ FXint File::move(const FXString& source,const FXString& target,const FXbool rest
 		if (!overwrite_all & !skip_all)
 		{
 			forceTimeout();
-			FXuint answer=getOverwriteAnswer(source,targetfile);
+			unsigned int answer=getOverwriteAnswer(source,targetfile);
  			restartTimeout();
        		switch(answer)
        		{
@@ -1135,10 +1140,9 @@ FXint File::move(const FXString& source,const FXString& target,const FXbool rest
 		return FALSE;
 	}
 */
-	targetfile=FXPath::directory(targetfile);
 
 	// If files are on different file systems, use the copy/delete scheme and preserve the original date
-	FXint ret=this->copy(source,targetfile,FALSE,TRUE);
+	int ret=this->copy(source,targetfile,FALSE,TRUE);
 	if (ret)
 		return (remove(source.text())==TRUE);
 	else
@@ -1149,7 +1153,7 @@ FXint File::move(const FXString& source,const FXString& target,const FXbool rest
 // Symbolic Link file (no progress dialog)
 // Return  0 to allow displaying an error message in the calling routine
 // Return -1 to prevent displaying an error message in the calling routine
-FXint File::symlink(const FXString& source,const FXString& target)
+int File::symlink(const FXString& source,const FXString& target)
 {
 	// Source doesn't exist
     if(!::exists(source))
@@ -1180,7 +1184,7 @@ FXint File::symlink(const FXString& source,const FXString& target)
 		// Overwrite dialog if necessary
 		if (!(overwrite_all | skip_all))
     	{
-			FXuint answer=getOverwriteAnswer(source,targetfile);
+			unsigned int answer=getOverwriteAnswer(source,targetfile);
        		switch(answer)
        		{
 				// Cancel
@@ -1224,9 +1228,9 @@ FXint File::symlink(const FXString& source,const FXString& target)
 	else
 		relativepath=FXPath::relative(FXPath::directory(target),source);
 	
-	FXint ret=::symlink(relativepath.text(),targetfile.text());
+	int ret=::symlink(relativepath.text(),targetfile.text());
 
-	FXint errcode=errno;	
+	int errcode=errno;	
 	if (ret==0)
 		return TRUE;
 	else
@@ -1247,7 +1251,7 @@ FXint File::symlink(const FXString& source,const FXString& target)
 // Note : the variable file returns the last processed file
 // It can be different from the initial path, if recursive chmod is used
 // (Used to fill an error message, if needed) 
-FXint File::chmod(FXchar* path, FXchar* file, mode_t mode, FXbool rec, const FXbool dironly, const FXbool fileonly)
+int File::chmod(char* path, char* file, mode_t mode, FXbool rec, const FXbool dironly, const FXbool fileonly)
 {			
     struct stat linfo;
 
@@ -1322,7 +1326,7 @@ FXint File::chmod(FXchar* path, FXchar* file, mode_t mode, FXbool rec, const FXb
 
 // Recursive chmod for a directory
 // We don't process symbolic links (since their permissions cannot be changed)
-FXint File::rchmod(FXchar* path, FXchar* file, mode_t mode, const FXbool dironly, const FXbool fileonly)
+int File::rchmod(char* path, char* file, mode_t mode, const FXbool dironly, const FXbool fileonly)
 {
     struct stat linfo;
 
@@ -1365,7 +1369,7 @@ FXint File::rchmod(FXchar* path, FXchar* file, mode_t mode, const FXbool dironly
 
 	DIR *dir;
     struct dirent *entry;
-    FXint i, pl = strlen(path);
+    int i, pl = strlen(path);
 
     if (!(dir = opendir(path)))
         return -1;
@@ -1376,8 +1380,8 @@ FXint File::rchmod(FXchar* path, FXchar* file, mode_t mode, const FXbool dironly
                                         && (entry->d_name[1] != '.' ||
                                             entry->d_name[2] != '\0')))
         {
-            FXint pl1 = pl, l = strlen(entry->d_name);
-            FXchar* path1 = (FXchar*)alloca(pl1+l+2);
+            int pl1 = pl, l = strlen(entry->d_name);
+            char* path1 = (char*)alloca(pl1+l+2);
 
             strlcpy(path1, path, strlen(path)+1);
             if (path1[pl1-1] != '/')
@@ -1407,7 +1411,7 @@ FXint File::rchmod(FXchar* path, FXchar* file, mode_t mode, const FXbool dironly
 // Note : the variable file returns the last processed file
 // It can be different from the initial path, if recursive chmod is used
 // (Used to fill an error message, if needed) 
-FXint File::chown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly, const FXbool fileonly)
+int File::chown(char* path, char* file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly, const FXbool fileonly)
 {
     struct stat linfo;
 
@@ -1480,7 +1484,7 @@ FXint File::chown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXbool
 
 // Recursive chown for a directory
 // We don't follow symbolic links
-FXint File::rchown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly)
+int File::rchown(char* path, char* file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly)
 {
     struct stat linfo;
 
@@ -1519,7 +1523,7 @@ FXint File::rchown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXboo
 	
     DIR *dir;
     struct dirent *entry;
-    FXint i, pl = strlen(path);
+    int i, pl = strlen(path);
 
     if (!(dir = opendir(path)))
         return -1;
@@ -1529,8 +1533,8 @@ FXint File::rchown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXboo
                                         && (entry->d_name[1] != '.' ||
                                             entry->d_name[2] != '\0')))
         {
-            FXint pl1 = pl, l = strlen(entry->d_name);
-            FXchar* path1 = (FXchar*)alloca(pl1+l+2);
+            int pl1 = pl, l = strlen(entry->d_name);
+            char* path1 = (char*)alloca(pl1+l+2);
 
             strlcpy(path1, path, strlen(path)+1);
             if (path1[pl1-1] != '/')
@@ -1552,7 +1556,7 @@ FXint File::rchown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXboo
 
 
 // Extract an archive in a specified directory
-FXint File::extract(const FXString name, const FXString dir, const FXString cmd)
+int File::extract(const FXString name, const FXString dir, const FXString cmd)
 {
 	// Change to the specified directory
     FXString currentdir=FXSystem::getCurrentDirectory();
@@ -1573,7 +1577,7 @@ FXint File::extract(const FXString name, const FXString dir, const FXString cmd)
 
 
 // Create an archive
-FXint File::archive(const FXString name, const FXString cmd)
+int File::archive(const FXString name, const FXString cmd)
 {
 	// Target file already exists
 	if(::exists(FXPath::dequote(name)))
@@ -1584,7 +1588,7 @@ FXint File::archive(const FXString name, const FXString cmd)
 			FXString msg;
 			msg.format(_("File %s already exists. Overwrite?"),name.text());
        		OverwriteBox* dlg = new OverwriteBox(this,_("Confirm Overwrite"),msg);
-       		FXuint answer=dlg->execute(PLACEMENT_CURSOR);
+       		unsigned int answer=dlg->execute(PLACEMENT_CURSOR);
 			delete dlg;
        		switch(answer)
        		{
@@ -1630,7 +1634,7 @@ FXint File::archive(const FXString name, const FXString cmd)
 
 
 #if defined(linux)
-FXint File::mount(const FXString dir, const FXString msg, const FXString cmd, const FXuint op)
+int File::mount(const FXString dir, const FXString msg, const FXString cmd, const unsigned int op)
 {
 	FXbool mount_messages=getApp()->reg().readUnsignedEntry("OPTIONS","mount_messages",TRUE);
 
@@ -1661,7 +1665,7 @@ FXint File::mount(const FXString dir, const FXString msg, const FXString cmd, co
 	}
 
 	// Get error message if any
-	FXchar text[10000]={0};
+	char text[10000]={0};
 	FXString buf;
 	while(fgets(text,sizeof(text),pcmd))
 		buf+=text;
@@ -1689,7 +1693,7 @@ FXint File::mount(const FXString dir, const FXString msg, const FXString cmd, co
 
 
 // Install / Upgrade package
-FXint File::pkgInstall(const FXString name, const FXString cmd)
+int File::pkgInstall(const FXString name, const FXString cmd)
 {
     // Make and show command window
 	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Install/Upgrade package"),cmd,10,80);			
@@ -1705,7 +1709,7 @@ FXint File::pkgInstall(const FXString name, const FXString cmd)
 }
 
 // Uninstall package
-FXint File::pkgUninstall(const FXString name, const FXString cmd)
+int File::pkgUninstall(const FXString name, const FXString cmd)
 {
     // Make and show command window
 	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Uninstall package"),cmd,10,80);			
