@@ -20,7 +20,7 @@
 #define FILESTYLEMASK (_ICONLIST_DETAILED|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_ROWS|_ICONLIST_COLUMNS|_ICONLIST_AUTOSIZE)
 
 // Single click navigation
-extern FXuint single_click;
+extern unsigned int single_click;
 
 // To allow keyboard scrolling in popup dialogs
 extern FXbool allowPopupScroll;
@@ -59,10 +59,10 @@ FXIMPLEMENT(FileSelector,FXPacker,FileSelectorMap,ARRAYNUMBER(FileSelectorMap))
 
 
 // Default pattern
-static const FXchar allfiles[]="All Files (*)";
+static const char allfiles[]="All Files (*)";
 
 // File selector object
-FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
         FXPacker(p,opts,x,y,w,h,0,0,0,0,0,0)
 {
 	FXAccelTable *table=getShell()->getAccelTable();
@@ -79,7 +79,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     FXHorizontalFrame* pathframe=new FXHorizontalFrame(cont,LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0, 0,0);
 
  	// File list
- 	FXuint options;
+ 	unsigned int options;
 	FXbool smoothscroll=getApp()->reg().readUnsignedEntry("SETTINGS","smooth_scroll",TRUE);	
 	if (smoothscroll)
 		options=_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y;
@@ -101,7 +101,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     list->setHeaderSize(7,getApp()->reg().readUnsignedEntry("FILEDIALOG","attr_size",100));  	
 	
 	// Set file selector options
-	FXuint listmode=getApp()->reg().readUnsignedEntry("FILEDIALOG","listmode",_ICONLIST_MINI_ICONS);
+	unsigned int listmode=getApp()->reg().readUnsignedEntry("FILEDIALOG","listmode",_ICONLIST_MINI_ICONS);
 	FXbool hiddenfiles=getApp()->reg().readUnsignedEntry("FILEDIALOG","hiddenfiles",FALSE);
 	showHiddenFiles(hiddenfiles);
 	setFileBoxStyle	(listmode);
@@ -255,7 +255,7 @@ void FileSelector::create()
 // Double-clicked item in file list
 long FileSelector::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
 {
-    FXint index=(FXint)(long)ptr;
+    long index=(long)ptr;
     if(index<0)
         return 1;
 
@@ -297,13 +297,13 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 {
 	if (single_click != SINGLE_CLICK_NONE)
 	{		
-		FXint index=(FXint)(long)ptr;
+		long index=(long)ptr;
 		if(index<0)
 			return 1;
 
 		// In detailed mode, avoid single click when cursor is not over the first column
-		FXint x, y;
-		FXuint state;
+		int x, y;
+		unsigned int state;
 		getCursorPosition(x,y,state);
 		FXbool allow=TRUE;
 		if (!(list->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-list->getXPosition())>list->getHeaderSize(0))
@@ -347,12 +347,12 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 // Change in items which are selected
 long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
 {
-    FXint index=(FXint)(long)ptr;
+    long index=(long)ptr;
     FXString text,file;
 
     if(selectmode==SELECT_FILE_MULTIPLE)
     {
-        for(FXint i=0; i<list->getNumItems(); i++)
+        for(int i=0; i<list->getNumItems(); i++)
         {
             if(list->isItemFile(i) && list->isItemSelected(i))
             {
@@ -365,7 +365,7 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
     }
     else if(selectmode==SELECT_FILE_MULTIPLE_ALL)
     {
-        for(FXint i=0; i<list->getNumItems(); i++)
+        for(int i=0; i<list->getNumItems(); i++)
         {
             if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
             {
@@ -414,7 +414,7 @@ long FileSelector::onCmdItemDeselected(FXObject*,FXSelector,void*)
     FXString text,file;
     if(selectmode==SELECT_FILE_MULTIPLE)
     {
-        for(FXint i=0; i<list->getNumItems(); i++)
+        for(int i=0; i<list->getNumItems(); i++)
         {
             if(list->isItemFile(i) && list->isItemSelected(i))
             {
@@ -427,7 +427,7 @@ long FileSelector::onCmdItemDeselected(FXObject*,FXSelector,void*)
     }
     else if(selectmode==SELECT_FILE_MULTIPLE_ALL)
     {
-        for(FXint i=0; i<list->getNumItems(); i++)
+        for(int i=0; i<list->getNumItems(); i++)
         {
             if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
             {
@@ -509,7 +509,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
             // In multiple mode, return if all selected files exist
             else if(selectmode==SELECT_FILE_MULTIPLE)
             {
-                for(FXint i=0; i<list->getNumItems(); i++)
+                for(int i=0; i<list->getNumItems(); i++)
                 {
                     if(list->isItemSelected(i) && list->isItemFile(i))
                     {
@@ -523,7 +523,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
             // Multiple files and/or directories
             else
             {
-                for(FXint i=0; i<list->getNumItems(); i++)
+                for(int i=0; i<list->getNumItems(); i++)
                 {
                     if(list->isItemSelected(i) && list->getItemFilename(i)!="..")
                     {
@@ -688,7 +688,7 @@ long  FileSelector::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 	forwardhist=list->forwardhist;
 
 	// Get all string items and display them in a list box
-	FXint num=backhist->getNumItems();
+	int num=backhist->getNumItems();
 	if (num>0)
 	{
 		FXString *dirs= new FXString[num];
@@ -709,7 +709,7 @@ long  FileSelector::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 
 		// Display list box
 		FXWindow* owner=this->getOwner();
-		FXint pos=DirHistBox::box(btnbackhist,DECOR_NONE,strlist,owner->getX()+245,owner->getY()+37);
+		int pos=DirHistBox::box(btnbackhist,DECOR_NONE,strlist,owner->getX()+245,owner->getY()+37);
 		
 		// If an item was selected
 		if (pos!=-1)
@@ -728,7 +728,7 @@ long  FileSelector::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 			forwardhist->insertFirstItem(list->getDirectory());
 			if (pos>0)
 			{
-				for (FXint i=0; i<=pos-1; i++)
+				for (int i=0; i<=pos-1; i++)
 					forwardhist->insertFirstItem(dirs[i]);
 			}
 	
@@ -776,7 +776,7 @@ long  FileSelector::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* pt
 	forwardhist=list->forwardhist;
 
 	// Get all string items and display them in a list box
-	FXint num=forwardhist->getNumItems();
+	int num=forwardhist->getNumItems();
 	if (num>0)
 	{
 		FXString *dirs= new FXString[num];
@@ -797,7 +797,7 @@ long  FileSelector::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* pt
 		
 		// Display list box
 		FXWindow* owner=this->getOwner();
-		FXint pos=DirHistBox::box(btnforwardhist,DECOR_NONE,strlist,owner->getX()+285,owner->getY()+37);
+		int pos=DirHistBox::box(btnforwardhist,DECOR_NONE,strlist,owner->getX()+285,owner->getY()+37);
 		
 		// If an item was selected
 		if (pos!=-1)
@@ -815,7 +815,7 @@ long  FileSelector::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* pt
 			backhist->insertFirstItem(list->getDirectory());
 			if (pos>0)
 			{
-				for (FXint i=0; i<=pos-1; i++)
+				for (int i=0; i<=pos-1; i++)
 					backhist->insertFirstItem(dirs[i]);
 			}
 	
@@ -879,14 +879,14 @@ long FileSelector::onCmdNewDir(FXObject*,FXSelector,void*)
         if(dirname!=dirpath)
         {
 			// Create the new dir according to the current umask
-			FXint mask;
+			int mask;
 			mask=umask(0);
 			umask(mask);
 			
 			// Note that the umask value is in decimal (511 means octal 0777)
 			errno=0;
-			FXint ret=::mkdir(dirname.text(),511 & ~mask);
-			FXint errcode=errno;
+			int ret=::mkdir(dirname.text(),511 & ~mask);
+			int errcode=errno;
 			if (ret==-1)
 			{
 				if (errcode)
@@ -942,7 +942,7 @@ long FileSelector::onCmdNewFile(FXObject*,FXSelector,void*)
     			return 0;
 			}
 			// Change the file permissions according to the current umask
-			FXint mask;
+			int mask;
 			mask=umask(0);
 			umask(mask);
 			errno=0;
@@ -979,7 +979,7 @@ long FileSelector::onCmdWork(FXObject*,FXSelector,void*)
 // Strip pattern from text if present
 FXString FileSelector::patternFromText(const FXString& pattern)
 {
-    FXint beg,end;
+    int beg,end;
     end=pattern.rfind(')');         // Search from the end so we can allow ( ) in the pattern name itself
     beg=pattern.rfind('(',end-1);
     if(0<=beg && beg<end)
@@ -993,7 +993,7 @@ FXString FileSelector::patternFromText(const FXString& pattern)
 // if the pattern contains other wildcard combinations.
 FXString FileSelector::extensionFromPattern(const FXString& pattern)
 {
-    FXint beg,end,c;
+    int beg,end,c;
     beg=0;
     if(pattern[beg]=='*')
     {
@@ -1018,7 +1018,7 @@ FXString FileSelector::extensionFromPattern(const FXString& pattern)
 // Change the pattern; change the filename to the suggested extension
 long FileSelector::onCmdFilter(FXObject*,FXSelector,void* ptr)
 {
-    FXString pat=patternFromText((FXchar*)ptr);
+    FXString pat=patternFromText((char*)ptr);
     list->setPattern(pat);
     if(selectmode==SELECT_FILE_ANY)
     {
@@ -1068,7 +1068,7 @@ void FileSelector::setFilename(const FXString& path)
 // Get complete path + filename
 FXString FileSelector::getFilename() const
 {
-    register FXint i;
+    register int i;
     if(selectmode==SELECT_FILE_MULTIPLE_ALL)
     {
         for(i=0; i<list->getNumItems(); i++)
@@ -1098,7 +1098,7 @@ FXString FileSelector::getFilename() const
 FXString* FileSelector::getFilenames() const
 {
     register FXString *files=NULL;
-    register FXint i,n;
+    register int i,n;
     if(list->getNumItems())
     {
         if(selectmode==SELECT_FILE_MULTIPLE_ALL)
@@ -1143,7 +1143,7 @@ FXString* FileSelector::getFilenames() const
 
 
 // Set bunch of patterns
-void FileSelector::setPatternList(const FXchar **ptrns)
+void FileSelector::setPatternList(const char **ptrns)
 {
     filefilter->clearItems();
     if(ptrns)
@@ -1164,7 +1164,7 @@ void FileSelector::setPatternList(const FXchar **ptrns)
 void FileSelector::setPatternList(const FXString& patterns)
 {
     FXString pat;
-    FXint i;
+    int i;
     filefilter->clearItems();
     for(i=0; !(pat=patterns.section('\n',i)).empty(); i++)
         filefilter->appendItem(pat);
@@ -1178,7 +1178,7 @@ void FileSelector::setPatternList(const FXString& patterns)
 FXString FileSelector::getPatternList() const
 {
     FXString pat;
-    FXint i;
+    int i;
     for(i=0; i<filefilter->getNumItems(); i++)
     {
         if(!pat.empty())
@@ -1205,7 +1205,7 @@ FXString FileSelector::getPattern() const
 
 
 // Set current file pattern from the list
-void FileSelector::setCurrentPattern(FXint patno)
+void FileSelector::setCurrentPattern(int patno)
 {
 	if ((unsigned int)patno >= (unsigned int)filefilter->getNumItems())
         fxerror("%s::setCurrentPattern: index out of range.\n",getClassName());
@@ -1215,14 +1215,14 @@ void FileSelector::setCurrentPattern(FXint patno)
 
 
 // Return current pattern
-FXint FileSelector::getCurrentPattern() const
+int FileSelector::getCurrentPattern() const
 {
     return filefilter->getCurrentItem();
 }
 
 
 // Change pattern for pattern number patno
-void FileSelector::setPatternText(FXint patno,const FXString& text)
+void FileSelector::setPatternText(int patno,const FXString& text)
 {
 	if ((unsigned int)patno >= (unsigned int)filefilter->getNumItems())
         fxerror("%s::setPatternText: index out of range.\n",getClassName());
@@ -1233,7 +1233,7 @@ void FileSelector::setPatternText(FXint patno,const FXString& text)
 
 
 // Return pattern text of pattern patno
-FXString FileSelector::getPatternText(FXint patno) const
+FXString FileSelector::getPatternText(int patno) const
 {
 	if ((unsigned int)patno >= (unsigned int)filefilter->getNumItems())
         fxerror("%s::getPatternText: index out of range.\n",getClassName());
@@ -1242,28 +1242,28 @@ FXString FileSelector::getPatternText(FXint patno) const
 
 
 // Change space for item
-void FileSelector::setItemSpace(FXint s)
+void FileSelector::setItemSpace(int s)
 {
     list->setItemSpace(s);
 }
 
 
 // Get space for item
-FXint FileSelector::getItemSpace() const
+int FileSelector::getItemSpace() const
 {
     return list->getItemSpace();
 }
 
 
 // Change File List style
-void FileSelector::setFileBoxStyle(FXuint style)
+void FileSelector::setFileBoxStyle(unsigned int style)
 {
 	list->setListStyle((list->getListStyle()&~FILESTYLEMASK) | (style&FILESTYLEMASK));
 }
 
 
 // Return File List style
-FXuint FileSelector::getFileBoxStyle() const
+unsigned int FileSelector::getFileBoxStyle() const
 {
     return list->getListStyle()&FILESTYLEMASK;
 }
@@ -1271,7 +1271,7 @@ FXuint FileSelector::getFileBoxStyle() const
 
 
 // Change file selection mode
-void FileSelector::setSelectMode(FXuint mode)
+void FileSelector::setSelectMode(unsigned int mode)
 {
     switch(mode)
     {
@@ -1401,8 +1401,8 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 {
     // Popup menu pane
 	FXMenuPane menu(this);
-    FXint x,y;
-    FXuint state;
+    int x,y;
+    unsigned int state;
     getRoot()->getCursorPosition(x,y,state);
 
 	new FXMenuCommand(&menu,_("Go ho&me"),homeicon,this,ID_HOME);
@@ -1449,7 +1449,7 @@ FXIMPLEMENT(FileDialog,DialogBox,NULL,0)
 
 
 // File Dialog object
-FileDialog::FileDialog(FXWindow* owner,const FXString& name,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FileDialog::FileDialog(FXWindow* owner,const FXString& name,unsigned int opts,int x,int y,int w,int h):
         DialogBox(owner,name,opts|DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,x,y,w,h,0,0,0,0,4,4)
 {
     list=new FileSelector(this,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -1459,8 +1459,8 @@ FileDialog::FileDialog(FXWindow* owner,const FXString& name,FXuint opts,FXint x,
     list->cancelButton()->setSelector(DialogBox::ID_CANCEL);
     
     // Set file dialog options 
-	FXuint width=getApp()->reg().readUnsignedEntry("FILEDIALOG","width",640);
-	FXuint height=getApp()->reg().readUnsignedEntry("FILEDIALOG","height",480);
+	unsigned int width=getApp()->reg().readUnsignedEntry("FILEDIALOG","width",640);
+	unsigned int height=getApp()->reg().readUnsignedEntry("FILEDIALOG","height",480);
 	setWidth(width);
 	setHeight(height);
 }
@@ -1530,74 +1530,74 @@ FXString FileDialog::getDirectory() const
 
 
 // Set current file pattern from the list
-void FileDialog::setCurrentPattern(FXint n)
+void FileDialog::setCurrentPattern(int n)
 {
     list->setCurrentPattern(n);
 }
 
 
 // Return current pattern
-FXint FileDialog::getCurrentPattern() const
+int FileDialog::getCurrentPattern() const
 {
     return list->getCurrentPattern();
 }
 
-FXString FileDialog::getPatternText(FXint patno) const
+FXString FileDialog::getPatternText(int patno) const
 {
     return list->getPatternText(patno);
 }
 
 
-void FileDialog::setPatternText(FXint patno,const FXString& text)
+void FileDialog::setPatternText(int patno,const FXString& text)
 {
     list->setPatternText(patno,text);
 }
 
 
 // Set list of patterns (DEPRECATED)
-void FileDialog::setPatternList(const FXchar **ptrns)
+void FileDialog::setPatternList(const char **ptrns)
 {
     list->setPatternList(ptrns);
 }
 
 
 // Change space for item
-void FileDialog::setItemSpace(FXint s)
+void FileDialog::setItemSpace(int s)
 {
     list->setItemSpace(s);
 }
 
 
 // Get space for item
-FXint FileDialog::getItemSpace() const
+int FileDialog::getItemSpace() const
 {
     return list->getItemSpace();
 }
 
 
 // Change File List style
-void FileDialog::setFileBoxStyle(FXuint style)
+void FileDialog::setFileBoxStyle(unsigned int style)
 {
     list->setFileBoxStyle(style);
 }
 
 
 // Return File List style
-FXuint FileDialog::getFileBoxStyle() const
+unsigned int FileDialog::getFileBoxStyle() const
 {
     return list->getFileBoxStyle();
 }
 
 
 // Change file selection mode
-void FileDialog::setSelectMode(FXuint mode)
+void FileDialog::setSelectMode(unsigned int mode)
 {
     list->setSelectMode(mode);
 }
 
 
 // Return file selection mode
-FXuint FileDialog::getSelectMode() const
+unsigned int FileDialog::getSelectMode() const
 {
     return list->getSelectMode();
 }
@@ -1673,7 +1673,7 @@ FileDialog::~FileDialog()
 
 
 // Open existing filename
-FXString FileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,FXint initial)
+FXString FileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,int initial)
 {
     FileDialog opendialog(owner,caption);
     FXString filename;
@@ -1692,7 +1692,7 @@ FXString FileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,con
 
 
 // Save to filename
-FXString FileDialog::getSaveFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,FXint initial)
+FXString FileDialog::getSaveFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,int initial)
 {
     FileDialog savedialog(owner,caption);
     savedialog.setSelectMode(SELECT_FILE_ANY);
@@ -1706,7 +1706,7 @@ FXString FileDialog::getSaveFilename(FXWindow* owner,const FXString& caption,con
 
 
 // Open multiple existing files
-FXString* FileDialog::getOpenFilenames(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,FXint initial)
+FXString* FileDialog::getOpenFilenames(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,int initial)
 {
     FileDialog opendialog(owner,caption);
     opendialog.setSelectMode(SELECT_FILE_MULTIPLE);
