@@ -59,10 +59,10 @@ protected:
 	
 public:
 
-FilePanel(FXWindow *owner, const FXchar*,FXComposite*, DirPanel*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, FXuint ext_size=100, 
-	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXuint deldate_size=150, FXuint origpath_size=200, FXbool showthumbs=FALSE,
+FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, unsigned int name_size=200, unsigned int size_size=60, unsigned int type_size=100, unsigned int ext_size=100, 
+	      unsigned int modd_size=150, unsigned int user_size=50, unsigned int grou_size=50, unsigned int attr_size=100, unsigned int deldate_size=150, unsigned int origpath_size=200, FXbool showthumbs=FALSE,
           FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor attentioncolor=FXRGB(255,0,0), FXbool smoothscroll=TRUE,
- 		  FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+ 		  unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
     FilePanel()
     {}
     virtual void create();
@@ -75,6 +75,8 @@ FilePanel(FXWindow *owner, const FXchar*,FXComposite*, DirPanel*, FXuint name_si
 	void updateLocation();
 	void showCorner(FXbool show);
 	void showActiveIcon(FXbool show);
+	void execFile(FXString pathname);
+
 	enum
 	{
         ID_FILELIST=FXVerticalFrame::ID_LAST,
@@ -262,7 +264,7 @@ public:
 	}
 
 	// Get header size given its index
-	FXint getHeaderSize(FXint index) const
+	int getHeaderSize(int index) const
 	{
 		return list->getHeaderSize(index);
 	}
@@ -292,13 +294,13 @@ public:
 	}
 
 	// Get the current icon list style
-	FXuint getListStyle(void) const
+	unsigned int getListStyle(void) const
 	{
 		return list->getListStyle();
 	}
 
 	// Get the current icon list style
-	void setListStyle(FXuint style)
+	void setListStyle(unsigned int style)
 	{
 		list->setListStyle(style);
 	}
@@ -346,39 +348,39 @@ public:
 	}
 
 	// Get current item
-	FXint getCurrentItem(void) const
+	int getCurrentItem(void) const
 	{
 		return list->getCurrentItem();
 	}
 
 	// Set current item
-	void setCurrentItem(FXint item)
+	void setCurrentItem(int item)
 	{
 		list->setCurrentItem(item);
 		list->makeItemVisible(item);		
 	}
 
 	// Select item
-	void selectItem(FXint item)
+	void selectItem(int item)
 	{
 		list->selectItem(item);
 	}
 
 	// Deselect item
-	void deselectItem(FXint item)
+	void deselectItem(int item)
 	{
 		list->deselectItem(item);
 	}
 
 	// Is item selected?
-	FXbool isItemSelected(FXint item)
+	FXbool isItemSelected(int item)
 	{
 		return list->isItemSelected(item);
 		
 	}
 
 	// Get number od selected items
-	FXint getNumSelectedItems(void)
+	int getNumSelectedItems(void)
 	{
 		return list->getNumSelectedItems();
 	}
@@ -462,7 +464,7 @@ public:
 	}
 
 	// Get back history number of items
-	FXint backhistGetNumItems(void)
+	int backhistGetNumItems(void)
 	{
 		if (list->backhist)
 			return list->backhist->getNumItems();
@@ -471,7 +473,7 @@ public:
 	}
 
 	// Get forward history number of items
-	FXint forwardhistGetNumItems(void)
+	int forwardhistGetNumItems(void)
 	{
 		if (list->forwardhist)
 			return list->forwardhist->getNumItems();
@@ -505,13 +507,13 @@ public:
 	}
 
 	// Get back history item at position pos
-	StringItem* backhistGetItemAtPos(FXint pos)
+	StringItem* backhistGetItemAtPos(int pos)
 	{
 		return list->backhist->getItemAtPos(pos);
 	}
 
 	// Get forward history item at position pos
-	StringItem* forwardhistGetItemAtPos(FXint pos)
+	StringItem* forwardhistGetItemAtPos(int pos)
 	{
 		return list->forwardhist->getItemAtPos(pos);
 	}
