@@ -36,7 +36,7 @@
 #define SELECT_MASK   (_ICONLIST_EXTENDEDSELECT|_ICONLIST_SINGLESELECT|_ICONLIST_BROWSESELECT|_ICONLIST_MULTIPLESELECT)
 #define ICONLIST_MASK (SELECT_MASK|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_COLUMNS|_ICONLIST_SEARCH|_ICONLIST_STANDARD|_ICONLIST_AUTOSIZE)
 
-extern FXuint single_click;
+extern unsigned int single_click;
 extern FXbool file_tooltips;
 extern FXbool relative_resize;
 
@@ -46,15 +46,15 @@ FXIMPLEMENT(IconItem,FXObject,NULL,0)
 
 
 // Check if integer is odd (return TRUE) or even (return FALSE)
-inline FXbool IconItem::isOdd(FXint i) const
+inline FXbool IconItem::isOdd(int i) const
 {
 	return (FXbool)(i & 0x1);
 }
 
 // Draw item
-void IconItem::draw(IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const
+void IconItem::draw(IconList* list,FXDC& dc,int x,int y,int w,int h) const
 {
-    register FXuint options=list->getListStyle();
+    register unsigned int options=list->getListStyle();
     if (options&_ICONLIST_BIG_ICONS)
     	drawBigIcon(list,dc,x,y,w,h);
     else if (options&_ICONLIST_MINI_ICONS)
@@ -65,11 +65,11 @@ void IconItem::draw(IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) con
 
 
 // Draw big icon
-void IconItem::drawBigIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const
+void IconItem::drawBigIcon(const IconList* list,FXDC& dc,int x,int y,int w,int h) const
 {
-    register FXint len,dw,s,space,xt,yt,xi,yi;
+    register int len,dw,s,space,xt,yt,xi,yi;
     register FXFont *font=list->getFont();
-    register FXint iw=0,ih=0,tw=0,th=0,ss=0;
+    register int iw=0,ih=0,tw=0,th=0,ss=0;
     space=w-SIDE_SPACING;
       
     if (!label.empty())
@@ -126,11 +126,11 @@ void IconItem::drawBigIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w
 
 
 // Draw mini icon
-void IconItem::drawMiniIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const
+void IconItem::drawMiniIcon(const IconList* list,FXDC& dc,int x,int y,int w,int h) const
 {
     register FXFont *font=list->getFont();
-    register FXint iw=0,ih=0,tw=0,th=0;
-    register FXint len,dw,s,space;
+    register int iw=0,ih=0,tw=0,th=0;
+    register int len,dw,s,space;
     x+=SIDE_SPACING/2;
     space=w-SIDE_SPACING;
     if (miniIcon)
@@ -185,13 +185,13 @@ void IconItem::drawMiniIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint
 }
 
 
-void IconItem::drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h) const
+void IconItem::drawDetails(IconList* list,FXDC& dc,int x,int y,int,int h) const
 {
     register FXHeader *header=list->getHeader();
     register FXFont *font=list->getFont();
-    register FXint iw=0,ih=0,tw=0,th=0,yt,beg,end,hi,drw,space,used,dw,xx,dx=0;
+    register int iw=0,ih=0,tw=0,th=0,yt,beg,end,hi,drw,space,used,dw,xx,dx=0;
 	register FXbool highlight;
-	register FXuint options=list->getListStyle();
+	register unsigned int options=list->getListStyle();
 
     if (header->getNumItems()==0)
         return;
@@ -206,7 +206,7 @@ void IconItem::drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h
     highlight = !highlight;
 	
 	// Darken the sorted column
-	for (hi=0; hi<(FXint)list->getSortHeader(); hi++)
+	for (hi=0; hi<(int)list->getSortHeader(); hi++)
 		dx+=header->getItemSize(hi);
 
 	if (highlight)
@@ -299,10 +299,10 @@ void IconItem::drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h
 
 
 // See if item got hit and where: 0 is outside, 1 is icon, 2 is text
-FXint IconItem::hitItem(const IconList* list,FXint rx,FXint ry,FXint rw,FXint rh) const
+int IconItem::hitItem(const IconList* list,int rx,int ry,int rw,int rh) const
 {
-    register FXint iw=0,tw=0,ih=0,th=0,ss=0,ix,iy,tx,ty,w,h,sp,tlen;
-    register FXuint options=list->getListStyle();
+    register int iw=0,tw=0,ih=0,th=0,ss=0,ix,iy,tx,ty,w,h,sp,tlen;
+    register unsigned int options=list->getListStyle();
     register FXFont *font=list->getFont();
     for (tlen=0; tlen<label.length() && label[tlen]!='\t'; tlen++);
     if (options&_ICONLIST_BIG_ICONS)
@@ -490,11 +490,11 @@ void IconItem::detach()
 
 
 // Get item width
-FXint IconItem::getWidth(const IconList* list) const
+int IconItem::getWidth(const IconList* list) const
 {
-    register FXuint options=list->getListStyle();
+    register unsigned int options=list->getListStyle();
     register FXFont *font=list->getFont();
-    register FXint iw=0,tw=0,w=0,tlen;
+    register int iw=0,tw=0,w=0,tlen;
     for (tlen=0; tlen<label.length() && label[tlen]!='\t'; tlen++);
     if (options&_ICONLIST_BIG_ICONS)
     {
@@ -521,10 +521,10 @@ FXint IconItem::getWidth(const IconList* list) const
 
 
 // Get item height
-FXint IconItem::getHeight(const IconList* list) const
+int IconItem::getHeight(const IconList* list) const
 {
-    register FXuint options=list->getListStyle();
-    register FXint ih=0,th=0,h=0;
+    register unsigned int options=list->getListStyle();
+    register int ih=0,th=0,h=0;
     if (options&_ICONLIST_BIG_ICONS)
     {
         if (bigIcon)
@@ -613,12 +613,6 @@ FXDEFMAP(IconList) IconListMap[]=
     FXMAPFUNC(SEL_CLICKED,0,IconList::onClicked),
     FXMAPFUNC(SEL_DOUBLECLICKED,0,IconList::onDoubleClicked),
     FXMAPFUNC(SEL_TRIPLECLICKED,0,IconList::onTripleClicked),
-    
-	// Desactivated this one because of a conflict with KeybindingsBox
-	// I'll check if it is necessary
-	//FXMAPFUNC(SEL_COMMAND,0,IconList::onCommand),
-    
-	
 	FXMAPFUNC(SEL_QUERY_TIP,0,IconList::onQueryTip),
     FXMAPFUNC(SEL_QUERY_HELP,0,IconList::onQueryHelp),
     FXMAPFUNC(SEL_CHANGED,IconList::ID_HEADER_CHANGE,IconList::onHeaderChanged),
@@ -652,7 +646,7 @@ FXIMPLEMENT(IconList,FXScrollArea,IconListMap,ARRAYNUMBER(IconListMap))
 
 
 // Icon List
-IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
                    FXScrollArea(p,opts,x,y,w,h)
 {
 	//autosize=opts&_ICONLIST_AUTOSIZE; // Workaround for a bug (?)
@@ -683,14 +677,14 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
 
 	// Sort colors for detailed mode
 	FXColor listbackColor=getApp()->reg().readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
-	FXuint R, G, B;
-	R=(FXuint)(DARKEN_SORT*FXREDVAL(listbackColor));
-	G=(FXuint)(DARKEN_SORT*FXGREENVAL(listbackColor));
-	B=(FXuint)(DARKEN_SORT*FXBLUEVAL(listbackColor));
+	unsigned int R, G, B;
+	R=(unsigned int)(DARKEN_SORT*FXREDVAL(listbackColor));
+	G=(unsigned int)(DARKEN_SORT*FXGREENVAL(listbackColor));
+	B=(unsigned int)(DARKEN_SORT*FXBLUEVAL(listbackColor));
 	sortColor=FXRGB(R,G,B);
-	R=(FXuint)(DARKEN_SORT*FXREDVAL(highlightColor));
-	G=(FXuint)(DARKEN_SORT*FXGREENVAL(highlightColor));
-	B=(FXuint)(DARKEN_SORT*FXBLUEVAL(highlightColor));
+	R=(unsigned int)(DARKEN_SORT*FXREDVAL(highlightColor));
+	G=(unsigned int)(DARKEN_SORT*FXGREENVAL(highlightColor));
+	B=(unsigned int)(DARKEN_SORT*FXBLUEVAL(highlightColor));
 	highlightSortColor=FXRGB(R,G,B);
 
 	itemSpace=ITEM_SPACE;
@@ -715,14 +709,14 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
 long IconList::onConfigure(FXObject*,FXSelector,void*)
 {
 	// Obtain the main window width
-	FXint width=(this->getShell())->getWidth();
+	int width=(this->getShell())->getWidth();
 	
 	// Initialize the relative sizes, skipping the first call
 	if (count==1)
 	{
 		// Initialize the relative header sizes
-		for (FXint hi=0; hi<getNumHeaders(); hi++)
-			headerpct[hi]=(FXdouble)getHeaderSize(hi)/(FXdouble)width;
+		for (int hi=0; hi<getNumHeaders(); hi++)
+			headerpct[hi]=(double)getHeaderSize(hi)/(double)width;
 	}
 
 	// Update the relative header sizes
@@ -731,19 +725,19 @@ long IconList::onConfigure(FXObject*,FXSelector,void*)
 		// Initialize the extra header pcts if necessary
 		if (initheaderpct && getNumHeaders()==9)  // Search list, is it really necessary???
 		{
-			headerpct[8]=(FXdouble)getHeaderSize(8)/(FXdouble)width;
+			headerpct[8]=(double)getHeaderSize(8)/(double)width;
 			initheaderpct=FALSE;
 		}
 		if (initheaderpct && getNumHeaders()==10)
 		{
-			headerpct[8]=(FXdouble)getHeaderSize(8)/(FXdouble)width;
-			headerpct[9]=(FXdouble)getHeaderSize(9)/(FXdouble)width;
+			headerpct[8]=(double)getHeaderSize(8)/(double)width;
+			headerpct[9]=(double)getHeaderSize(9)/(double)width;
 			initheaderpct=FALSE;
 		}
-		FXint newhsize;
-		for (FXint hi=0; hi<getNumHeaders(); hi++)
+		int newhsize;
+		for (int hi=0; hi<getNumHeaders(); hi++)
 		{
-			newhsize=(FXint)round(headerpct[hi]*width);
+			newhsize=(int)round(headerpct[hi]*width);
 			setHeaderSize(hi,newhsize);		
 		}
 	}
@@ -760,7 +754,7 @@ long IconList::onConfigure(FXObject*,FXSelector,void*)
 // Create window
 void IconList::create()
 {
-    register FXint i;
+    register int i;
     FXScrollArea::create();
     for (i=0; i<items.no(); i++)
     {
@@ -773,7 +767,7 @@ void IconList::create()
 // Detach window
 void IconList::detach()
 {
-    register FXint i;
+    register int i;
     FXScrollArea::detach();
     for (i=0; i<items.no(); i++)
     {
@@ -807,11 +801,11 @@ void IconList::killFocus()
 
 
 // Move content
-void IconList::moveContents(FXint x,FXint y)
+void IconList::moveContents(int x,int y)
 {
-    FXint dx=x-pos_x;
-    FXint dy=y-pos_y;
-    FXint top=0;
+    int dx=x-pos_x;
+    int dy=y-pos_y;
+    int top=0;
     pos_x=x;
     pos_y=y;
     if (!(options&(_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS)))
@@ -834,7 +828,7 @@ void IconList::recalc()
 // Recompute interior
 void IconList::recompute()
 {	
-    register FXint w,h,i;
+    register int w,h,i;
 
     itemWidth=1;
     itemHeight=1;
@@ -870,7 +864,7 @@ void IconList::recompute()
 
 
 // Determine number of columns and number of rows
-void IconList::getrowscols(FXint& nr,FXint& nc,FXint w,FXint h) const
+void IconList::getrowscols(int& nr,int& nc,int w,int h) const
 {
     if (options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
     {
@@ -915,14 +909,14 @@ void IconList::getrowscols(FXint& nr,FXint& nc,FXint w,FXint h) const
 
 
 // Size of a possible column caption
-FXint IconList::getViewportHeight()
+int IconList::getViewportHeight()
 {
     return (options&(_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS)) ? height : height-header->getDefaultHeight();
 }
 
 
 // Determine content width of icon list
-FXint IconList::getContentWidth()
+int IconList::getContentWidth()
 {
     if (flags&FLAG_RECALC)
     	recompute();
@@ -933,7 +927,7 @@ FXint IconList::getContentWidth()
 
 
 // Determine content height of icon list
-FXint IconList::getContentHeight()
+int IconList::getContentHeight()
 {
     if (flags&FLAG_RECALC)
     	recompute();
@@ -978,10 +972,10 @@ void IconList::layout()
 // Changed size:- this is a bit tricky, because
 // we don't want to re-measure the items, but the content
 // size has changed because the number of rows/columns has...
-void IconList::resize(FXint w,FXint h)
+void IconList::resize(int w,int h)
 {
-    FXint nr=nrows;
-    FXint nc=ncols;
+    int nr=nrows;
+    int nc=ncols;
     if (w!=width || h!=height)
     {
         getrowscols(nrows,ncols,w,h);
@@ -995,10 +989,10 @@ void IconList::resize(FXint w,FXint h)
 // Changed size and/or pos:- this is a bit tricky, because
 // we don't want to re-measure the items, but the content
 // size has changed because the number of rows/columns has...
-void IconList::position(FXint x,FXint y,FXint w,FXint h)
+void IconList::position(int x,int y,int w,int h)
 {
-    FXint nr=nrows;
-    FXint nc=ncols;
+    int nr=nrows;
+    int nc=ncols;
     if (w!=width || h!=height)
     {
         getrowscols(nrows,ncols,w,h);
@@ -1022,11 +1016,11 @@ long IconList::onCmdHeaderClicked(FXObject*,FXSelector,void* ptr)
 long IconList::onHeaderChanged(FXObject*,FXSelector,void* ptr)
 {	
 	// Obtain the main window width
-	FXint width=(this->getShell())->getWidth();
+	int width=(this->getShell())->getWidth();
 
 	// Update the header relative sizes
-	for (FXint hi=0; hi<getNumHeaders(); hi++)
-		headerpct[hi]=(FXdouble)getHeaderSize(hi)/(FXdouble)width;
+	for (int hi=0; hi<getNumHeaders(); hi++)
+		headerpct[hi]=(double)getHeaderSize(hi)/(double)width;
 	
     flags&=~FLAG_RECALC;
     return 1;
@@ -1038,8 +1032,8 @@ long IconList::onHeaderChanged(FXObject*,FXSelector,void* ptr)
 // to that of the widest item.
 long IconList::onHeaderResize(FXObject*,FXSelector,void* ptr)
 {
-    register FXint hi=(FXint)(FXival)ptr;
-    register FXint i,iw,tw,w,nw=0;
+    register int hi=(int)(FXival)ptr;
+    register int i,iw,tw,w,nw=0;
     FXString text;
 
     // For detailed icon list
@@ -1084,7 +1078,7 @@ long IconList::onHeaderResize(FXObject*,FXSelector,void* ptr)
 
 
 // Set headers from array of strings
-void IconList::setHeaders(const FXchar** strings,FXint size)
+void IconList::setHeaders(const char** strings,int size)
 {
     header->clearItems();
     header->fillItems(strings,NULL,size);
@@ -1092,7 +1086,7 @@ void IconList::setHeaders(const FXchar** strings,FXint size)
 
 
 // Set headers from newline separated strings
-void IconList::setHeaders(const FXString& strings,FXint size)
+void IconList::setHeaders(const FXString& strings,int size)
 {
     header->clearItems();
     header->fillItems(strings,NULL,size);
@@ -1100,14 +1094,14 @@ void IconList::setHeaders(const FXString& strings,FXint size)
 
 
 // Append header caption
-void IconList::appendHeader(const FXString& text,FXIcon *icon,FXint size)
+void IconList::appendHeader(const FXString& text,FXIcon *icon,int size)
 {
     header->appendItem(text,icon,size);
 }
 
 
 // Remove header caption
-void IconList::removeHeader(FXint index)
+void IconList::removeHeader(int index)
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1118,7 +1112,7 @@ void IconList::removeHeader(FXint index)
 
 
 // Change header caption
-void IconList::setHeaderText(FXint index,const FXString& text)
+void IconList::setHeaderText(int index,const FXString& text)
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1129,7 +1123,7 @@ void IconList::setHeaderText(FXint index,const FXString& text)
 
 
 // Get header caption
-FXString IconList::getHeaderText(FXint index) const
+FXString IconList::getHeaderText(int index) const
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1140,7 +1134,7 @@ FXString IconList::getHeaderText(FXint index) const
 
 
 // Change header icon
-void IconList::setHeaderIcon(FXint index,FXIcon *icon)
+void IconList::setHeaderIcon(int index,FXIcon *icon)
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1151,7 +1145,7 @@ void IconList::setHeaderIcon(FXint index,FXIcon *icon)
 
 
 // Get header icon
-FXIcon* IconList::getHeaderIcon(FXint index) const
+FXIcon* IconList::getHeaderIcon(int index) const
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1162,7 +1156,7 @@ FXIcon* IconList::getHeaderIcon(FXint index) const
 
 
 // Change header size
-void IconList::setHeaderSize(FXint index,FXint size)
+void IconList::setHeaderSize(int index,int size)
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1173,7 +1167,7 @@ void IconList::setHeaderSize(FXint index,FXint size)
 
 
 // Get header size
-FXint IconList::getHeaderSize(FXint index) const
+int IconList::getHeaderSize(int index) const
 {
     if (index<0 || header->getNumItems()<=index)
     {
@@ -1184,14 +1178,14 @@ FXint IconList::getHeaderSize(FXint index) const
 
 
 // Return number of headers
-FXint IconList::getNumHeaders() const
+int IconList::getNumHeaders() const
 {
     return header->getNumItems();
 }
 
 
 // Change item text
-void IconList::setItemText(FXint index,const FXString& text)
+void IconList::setItemText(int index,const FXString& text)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1206,7 +1200,7 @@ void IconList::setItemText(FXint index,const FXString& text)
 
 
 // Get item text
-FXString IconList::getItemText(FXint index) const
+FXString IconList::getItemText(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -1217,7 +1211,7 @@ FXString IconList::getItemText(FXint index) const
 
 
 // Set item icon
-void IconList::setItemBigIcon(FXint index,FXIcon* icon,FXbool owned)
+void IconList::setItemBigIcon(int index,FXIcon* icon,FXbool owned)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1230,7 +1224,7 @@ void IconList::setItemBigIcon(FXint index,FXIcon* icon,FXbool owned)
 
 
 // Get item icon
-FXIcon* IconList::getItemBigIcon(FXint index) const
+FXIcon* IconList::getItemBigIcon(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -1241,7 +1235,7 @@ FXIcon* IconList::getItemBigIcon(FXint index) const
 
 
 // Set item icon
-void IconList::setItemMiniIcon(FXint index,FXIcon* icon,FXbool owned)
+void IconList::setItemMiniIcon(int index,FXIcon* icon,FXbool owned)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1254,7 +1248,7 @@ void IconList::setItemMiniIcon(FXint index,FXIcon* icon,FXbool owned)
 
 
 // Get item icon
-FXIcon* IconList::getItemMiniIcon(FXint index) const
+FXIcon* IconList::getItemMiniIcon(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -1265,7 +1259,7 @@ FXIcon* IconList::getItemMiniIcon(FXint index) const
 
 
 // Set item data
-void IconList::setItemData(FXint index,void* ptr)
+void IconList::setItemData(int index,void* ptr)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1276,7 +1270,7 @@ void IconList::setItemData(FXint index,void* ptr)
 
 
 // Get item data
-void* IconList::getItemData(FXint index) const
+void* IconList::getItemData(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -1287,7 +1281,7 @@ void* IconList::getItemData(FXint index) const
 
 
 // True if item is current
-FXbool IconList::isItemCurrent(FXint index) const
+FXbool IconList::isItemCurrent(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -1298,7 +1292,7 @@ FXbool IconList::isItemCurrent(FXint index) const
 
 
 // True if item is enabled
-FXbool IconList::isItemEnabled(FXint index) const
+FXbool IconList::isItemEnabled(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -1309,10 +1303,10 @@ FXbool IconList::isItemEnabled(FXint index) const
 
 
 // True if item (partially) visible
-FXbool IconList::isItemVisible(FXint index) const
+FXbool IconList::isItemVisible(int index) const
 {
     register FXbool vis=FALSE;
-    register FXint x,y,hh;
+    register int x,y,hh;
     if (index<0 || items.no()<=index)
     {
         fxerror("%s::isItemVisible: index out of range.\n",getClassName());
@@ -1346,9 +1340,9 @@ FXbool IconList::isItemVisible(FXint index) const
 
 
 // Make item fully visible
-void IconList::makeItemVisible(FXint index)
+void IconList::makeItemVisible(int index)
 {
-    register FXint x,y,hh,px,py;
+    register int x,y,hh,px,py;
     if (0<=index && index<items.no())
     {
         // Remember for later
@@ -1413,11 +1407,11 @@ void IconList::makeItemVisible(FXint index)
 
 // Hack to avoid displaying the allowTooltip in detailed mode when the mouse is not on the first column
 // Get item at position x,y
-//FXint IconList::getItemAt(FXint x,FXint y) const
-FXint IconList::getItemAt(FXint x,FXint y)
+//int IconList::getItemAt(int x,int y) const
+int IconList::getItemAt(int x,int y)
 {
-	register FXint ix,iy;
-	register FXint r,c,index;
+	register int ix,iy;
+	register int r,c,index;
 	y-=pos_y;
 	x-=pos_x;
 	
@@ -1478,11 +1472,11 @@ FXint IconList::getItemAt(FXint x,FXint y)
 
 
 // Compare strings up to n
-static FXint comp(const FXString& s1,const FXString& s2,FXint n)
+static int comp(const FXString& s1,const FXString& s2,int n)
 {
-    register const FXuchar *p1=(const FXuchar *)s1.text();
-    register const FXuchar *p2=(const FXuchar *)s2.text();
-    register FXint c1,c2;
+    register const unsigned char *p1=(const unsigned char *)s1.text();
+    register const unsigned char *p2=(const unsigned char *)s2.text();
+    register int c1,c2;
     if (0<n)
     {
         do
@@ -1502,11 +1496,11 @@ static FXint comp(const FXString& s1,const FXString& s2,FXint n)
 
 
 // Compare strings case insensitive up to n
-static FXint compcase(const FXString& s1,const FXString& s2,FXint n)
+static int compcase(const FXString& s1,const FXString& s2,int n)
 {
-    register const FXuchar *p1=(const FXuchar *)s1.text();
-    register const FXuchar *p2=(const FXuchar *)s2.text();
-    register FXint c1,c2;
+    register const unsigned char *p1=(const unsigned char *)s1.text();
+    register const unsigned char *p2=(const unsigned char *)s2.text();
+    register int c1,c2;
     if (0<n)
     {
         do
@@ -1525,14 +1519,14 @@ static FXint compcase(const FXString& s1,const FXString& s2,FXint n)
 }
 
 
-typedef FXint (*FXCompareFunc)(const FXString&,const FXString&,FXint);
+typedef int (*FXCompareFunc)(const FXString&,const FXString&,int);
 
 
 // Get item by name
-FXint IconList::findItem(const FXString& text,FXint start,FXuint flgs) const
+int IconList::findItem(const FXString& text,int start,unsigned int flgs) const
 {
     register FXCompareFunc comparefunc;
-    register FXint index,len;
+    register int index,len;
     if (0<items.no())
     {
         comparefunc=(flgs&SEARCH_IGNORECASE) ? (FXCompareFunc)compcase : (FXCompareFunc)comp;
@@ -1577,9 +1571,9 @@ FXint IconList::findItem(const FXString& text,FXint start,FXuint flgs) const
 
 
 // Get item by data
-FXint IconList::findItemByData(const void *ptr,FXint start,FXuint flgs) const
+int IconList::findItemByData(const void *ptr,int start,unsigned int flgs) const
 {
-    register FXint index;
+    register int index;
     if (0<items.no())
     {
         if (flgs&SEARCH_BACKWARD)
@@ -1621,9 +1615,9 @@ FXint IconList::findItemByData(const void *ptr,FXint start,FXuint flgs) const
 
 
 // Did we hit the item, and which part of it did we hit
-FXint IconList::hitItem(FXint index,FXint x,FXint y,FXint ww,FXint hh) const
+int IconList::hitItem(int index,int x,int y,int ww,int hh) const
 {
-    FXint ix,iy,r,c,hit=0;
+    int ix,iy,r,c,hit=0;
     if (0<=index && index<items.no())
     {
         x-=pos_x;
@@ -1657,7 +1651,7 @@ FXint IconList::hitItem(FXint index,FXint x,FXint y,FXint ww,FXint hh) const
 
 
 // Repaint
-void IconList::updateItem(FXint index) const
+void IconList::updateItem(int index) const
 {
     if (xid && 0<=index && index<items.no())
     {
@@ -1683,7 +1677,7 @@ void IconList::updateItem(FXint index) const
 
 
 // Enable one item
-FXbool IconList::enableItem(FXint index)
+FXbool IconList::enableItem(int index)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1700,7 +1694,7 @@ FXbool IconList::enableItem(FXint index)
 
 
 // Disable one item
-FXbool IconList::disableItem(FXint index)
+FXbool IconList::disableItem(int index)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1717,7 +1711,7 @@ FXbool IconList::disableItem(FXint index)
 
 
 // Select one item
-FXbool IconList::selectItem(FXint index,FXbool notify)
+FXbool IconList::selectItem(int index,FXbool notify)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1747,7 +1741,7 @@ FXbool IconList::selectItem(FXint index,FXbool notify)
 
 
 // Deselect one item
-FXbool IconList::deselectItem(FXint index,FXbool notify)
+FXbool IconList::deselectItem(int index,FXbool notify)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1775,7 +1769,7 @@ FXbool IconList::deselectItem(FXint index,FXbool notify)
 
 
 // Toggle one item
-FXbool IconList::toggleItem(FXint index,FXbool notify)
+FXbool IconList::toggleItem(int index,FXbool notify)
 {
     if (index<0 || items.no()<=index)
     {
@@ -1843,9 +1837,9 @@ FXbool IconList::toggleItem(FXint index,FXbool notify)
 
 
 // Select items in rectangle
-FXbool IconList::selectInRectangle(FXint x,FXint y,FXint w,FXint h,FXbool notify)
+FXbool IconList::selectInRectangle(int x,int y,int w,int h,FXbool notify)
 {
-    register FXint r,c,index;
+    register int r,c,index;
     register FXbool changed=FALSE;
     if (options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
     {
@@ -1879,10 +1873,10 @@ FXbool IconList::selectInRectangle(FXint x,FXint y,FXint w,FXint h,FXbool notify
 
 
 // Extend selection
-FXbool IconList::extendSelection(FXint index,FXbool notify)
+FXbool IconList::extendSelection(int index,FXbool notify)
 {
     register FXbool changes=FALSE;
-    FXint i1,i2,i3,i;
+    int i1,i2,i3,i;
     if (0<=index && 0<=anchor && 0<=extent)
     {
 
@@ -1996,7 +1990,7 @@ FXbool IconList::extendSelection(FXint index,FXbool notify)
 FXbool IconList::killSelection(FXbool notify)
 {
     register FXbool changes=FALSE;
-    register FXint i;
+    register int i;
     for (i=0; i<items.no(); i++)
     {
         if (items[i]->isSelected())
@@ -2015,10 +2009,10 @@ FXbool IconList::killSelection(FXbool notify)
 
 
 // Lasso changed, so select/unselect items based on difference between new and old lasso box
-void IconList::lassoChanged(FXint ox,FXint oy,FXint ow,FXint oh,FXint nx,FXint ny,FXint nw,FXint nh,FXbool notify)
+void IconList::lassoChanged(int ox,int oy,int ow,int oh,int nx,int ny,int nw,int nh,FXbool notify)
 {
-    register FXint r,c;
-    FXint ohit,nhit,index;
+    register int r,c;
+    int ohit,nhit,index;
     if (options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
     {
         for (r=0; r<nrows; r++)
@@ -2064,7 +2058,7 @@ void IconList::lassoChanged(FXint ox,FXint oy,FXint ow,FXint oh,FXint nx,FXint n
 // Update value from a message
 long IconList::onCmdSetValue(FXObject*,FXSelector,void* ptr)
 {
-    setCurrentItem((FXint)(FXival)ptr);
+    setCurrentItem((int)(FXival)ptr);
     return 1;
 }
 
@@ -2072,7 +2066,7 @@ long IconList::onCmdSetValue(FXObject*,FXSelector,void* ptr)
 // Obtain value from list
 long IconList::onCmdGetIntValue(FXObject*,FXSelector,void* ptr)
 {
-    *((FXint*)ptr)=getCurrentItem();
+    *((int*)ptr)=getCurrentItem();
     return 1;
 }
 
@@ -2080,7 +2074,7 @@ long IconList::onCmdGetIntValue(FXObject*,FXSelector,void* ptr)
 // Update value from a message
 long IconList::onCmdSetIntValue(FXObject*,FXSelector,void* ptr)
 {
-    setCurrentItem(*((FXint*)ptr));
+    setCurrentItem(*((int*)ptr));
     return 1;
 }
 
@@ -2152,7 +2146,7 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 				if (type==_("Folder") || type==_("Mount point"))
 				{
 					// Compute root file size
-					unsigned long long dnsize;
+					FXulong dnsize;
 					char dsize[64];
 					dnsize=::dirsize(pathname.text());
 					snprintf(dsize,sizeof(dsize)-1,"%llu",dnsize);
@@ -2246,8 +2240,8 @@ long IconList::onFocusOut(FXObject* sender,FXSelector sel,void* ptr)
 // Draw item list
 long IconList::onPaint(FXObject*,FXSelector,void* ptr)
 {
-    register FXint rlo,rhi,clo,chi,yy,xx;
-    register FXint x,y,r,c,index;
+    register int rlo,rhi,clo,chi,yy,xx;
+    register int x,y,r,c,index;
     FXEvent* event=(FXEvent*)ptr;
     FXDCWindow dc(this,event);
 
@@ -2362,7 +2356,7 @@ long IconList::onPaint(FXObject*,FXSelector,void* ptr)
 
 
 // Draw Lasso rectangle
-void IconList::drawLasso(FXint x0,FXint y0,FXint x1,FXint y1)
+void IconList::drawLasso(int x0,int y0,int x1,int y1)
 {
     FXDCWindow dc(this);
     dc.setFunction(BLT_NOT_DST);
@@ -2519,15 +2513,15 @@ long IconList::onCmdSelectInverse(FXObject*,FXSelector,void*)
 
 
 // Compare sectioned strings
-FXint IconList::compareSection(const FXchar *p,const FXchar* q,FXint s)
+int IconList::compareSection(const char *p,const char* q,int s)
 {
-    register FXint c1,c2,x;
+    register int c1,c2,x;
     for (x=s; x && *p; x-=(*p++=='\t'));
     for (x=s; x && *q; x-=(*q++=='\t'));
     do
     {
-        c1=FXuchar(*p++);
-        c2=FXuchar(*q++);
+        c1=(unsigned char)(*p++);
+        c2=(unsigned char)(*q++);
     }
     while ('\t'<c1 && (c1==c2));
     return c1-c2;
@@ -2535,9 +2529,9 @@ FXint IconList::compareSection(const FXchar *p,const FXchar* q,FXint s)
 
 
 // Compare sectioned strings, case-insensitive
-FXint IconList::compareSectionCase(const FXchar *p,const FXchar* q,FXint s)
+int IconList::compareSectionCase(const char *p,const char* q,int s)
 {
-    register FXint c1,c2,x;
+    register int c1,c2,x;
     for (x=s; x && *p; x-=(*p++=='\t'));
     for (x=s; x && *q; x-=(*q++=='\t'));
     do
@@ -2563,28 +2557,28 @@ FXint IconList::compareSectionCase(const FXchar *p,const FXchar* q,FXint s)
 
 
 // Sort items in ascending order
-FXint IconList::ascending(const IconItem* a,const IconItem* b)
+int IconList::ascending(const IconItem* a,const IconItem* b)
 {
     return compareSection(a->getText().text(),b->getText().text(),0);
 }
 
 
 // Sort items in descending order
-FXint IconList::descending(const IconItem* a,const IconItem* b)
+int IconList::descending(const IconItem* a,const IconItem* b)
 {
     return compareSection(b->getText().text(),a->getText().text(),0);
 }
 
 
 // Sort items in ascending order, case insensitive
-FXint IconList::ascendingCase(const IconItem* a,const IconItem* b)
+int IconList::ascendingCase(const IconItem* a,const IconItem* b)
 {
     return compareSectionCase(a->getText().text(),b->getText().text(),0);
 }
 
 
 // Sort items in descending order, case insensitive
-FXint IconList::descendingCase(const IconItem* a,const IconItem* b)
+int IconList::descendingCase(const IconItem* a,const IconItem* b)
 {
     return compareSectionCase(b->getText().text(),a->getText().text(),0);
 }
@@ -2595,7 +2589,7 @@ void IconList::sortItems()
 {
     register IconItem *v,*c=0;
     register FXbool exch=FALSE;
-    register FXint i,j,h;
+    register int i,j,h;
     if (sortfunc)
     {
         if (0<=current)
@@ -2636,7 +2630,7 @@ void IconList::sortItems()
 
 
 // Set current item
-void IconList::setCurrentItem(FXint index,FXbool notify)
+void IconList::setCurrentItem(int index,FXbool notify)
 {
     if (index<-1 || items.no()<=index)
     {
@@ -2687,7 +2681,7 @@ void IconList::setCurrentItem(FXint index,FXbool notify)
 
 
 // Set anchor item
-void IconList::setAnchorItem(FXint index)
+void IconList::setAnchorItem(int index)
 {
     if (index<-1 || items.no()<=index)
     {
@@ -2709,7 +2703,7 @@ long IconList::onLookupTimer(FXObject*,FXSelector,void*)
 long IconList::onKeyPress(FXObject*,FXSelector,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    FXint index=current;
+    int index=current;
     flags&=~FLAG_TIP;
     if (!isEnabled())
         return 0;
@@ -2731,7 +2725,7 @@ long IconList::onKeyPress(FXObject*,FXSelector,void* ptr)
         lookup=FXString::null;
         setPosition(pos_x,pos_y+verticalScrollBar()->getPage());
 		// To select an item in the current page
-		index-=(FXint)(verticalScrollBar()->getPage()/verticalScrollBar()->getLine());
+		index-=(int)(verticalScrollBar()->getPage()/verticalScrollBar()->getLine());
 		goto hop;
         return 1;
     case KEY_Page_Down:
@@ -2739,7 +2733,7 @@ long IconList::onKeyPress(FXObject*,FXSelector,void* ptr)
         lookup=FXString::null;
         setPosition(pos_x,pos_y-verticalScrollBar()->getPage());
 		// To select an item in the current page
-		index+=(FXint)(verticalScrollBar()->getPage()/verticalScrollBar()->getLine());
+		index+=(int)(verticalScrollBar()->getPage()/verticalScrollBar()->getLine());
 		goto hop;
 		return 1;
     case KEY_Right:
@@ -2868,7 +2862,7 @@ hop:
             handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
         return 1;
     default:
-        if ((FXuchar)event->text[0]<' ')
+        if ((unsigned char)event->text[0]<' ')
             return 0;
         if (event->state&(CONTROLMASK|ALTMASK))
             return 0;
@@ -2936,7 +2930,7 @@ long IconList::onKeyRelease(FXObject*,FXSelector,void* ptr)
 long IconList::onAutoScroll(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    FXint olx,orx,oty,oby,nlx,nrx,nty,nby;
+    int olx,orx,oty,oby,nlx,nrx,nty,nby;
 
     // Lasso mode
     if (flags&FLAG_LASSO)
@@ -2982,10 +2976,10 @@ long IconList::onAutoScroll(FXObject* sender,FXSelector sel,void* ptr)
 // Mouse moved
 long IconList::onMotion(FXObject*,FXSelector,void* ptr)
 {
-    FXint olx,orx,oty,oby,nlx,nrx,nty,nby;
+    int olx,orx,oty,oby,nlx,nrx,nty,nby;
     FXEvent* event=(FXEvent*)ptr;
-    FXint oldcursor=cursor;
-    FXuint flg=flags;
+    int oldcursor=cursor;
+    unsigned int flg=flags;
 
     // Kill the tip
     flags&=~FLAG_TIP;
@@ -3064,7 +3058,7 @@ long IconList::onMotion(FXObject*,FXSelector,void* ptr)
 long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    FXint index,code;
+    int index,code;
     flags&=~FLAG_TIP;
     handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr);
     if (isEnabled())
@@ -3165,7 +3159,7 @@ long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
 long IconList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    FXuint flg=flags;
+    unsigned int flg=flags;
     if (isEnabled())
     {
         ungrab();
@@ -3224,7 +3218,7 @@ long IconList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr)
                 break;
             }
 
-            // Scroll to make item visibke
+            // Scroll to make item visible
             makeItemVisible(current);
 
             // Update anchor
@@ -3340,7 +3334,7 @@ IconItem *IconList::createItem(const FXString& text,FXIcon *big,FXIcon* mini,voi
 
 
 // Retrieve item
-IconItem *IconList::getItem(FXint index) const
+IconItem *IconList::getItem(int index) const
 {
     if (index<0 || items.no()<=index)
     {
@@ -3351,7 +3345,7 @@ IconItem *IconList::getItem(FXint index) const
 
 
 // Replace item with another
-FXint IconList::setItem(FXint index,IconItem* item,FXbool notify)
+int IconList::setItem(int index,IconItem* item,FXbool notify)
 {
 
     // Must have item
@@ -3388,16 +3382,16 @@ FXint IconList::setItem(FXint index,IconItem* item,FXbool notify)
 
 
 // Replace item with another
-FXint IconList::setItem(FXint index,const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
+int IconList::setItem(int index,const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
 {
     return setItem(index,createItem(text,big,mini,ptr),notify);
 }
 
 
 // Insert item
-FXint IconList::insertItem(FXint index,IconItem* item,FXbool notify)
+int IconList::insertItem(int index,IconItem* item,FXbool notify)
 {
-    register FXint old=current;
+    register int old=current;
 
     // Must have item
     if (!item)
@@ -3461,44 +3455,44 @@ FXint IconList::insertItem(FXint index,IconItem* item,FXbool notify)
 
 
 // Insert item
-FXint IconList::insertItem(FXint index,const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
+int IconList::insertItem(int index,const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
 {
     return insertItem(index,createItem(text,big,mini,ptr),notify);
 }
 
 
 // Append item
-FXint IconList::appendItem(IconItem* item,FXbool notify)
+int IconList::appendItem(IconItem* item,FXbool notify)
 {
     return insertItem(items.no(),item,notify);
 }
 
 
 // Append item
-FXint IconList::appendItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
+int IconList::appendItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
 {
     return insertItem(items.no(),createItem(text,big,mini,ptr),notify);
 }
 
 
 // Prepend item
-FXint IconList::prependItem(IconItem* item,FXbool notify)
+int IconList::prependItem(IconItem* item,FXbool notify)
 {
     return insertItem(0,item,notify);
 }
 
 
 // Prepend item
-FXint IconList::prependItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
+int IconList::prependItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
 {
     return insertItem(0,createItem(text,big,mini,ptr),notify);
 }
 
 
 // Fill list by appending items from array of strings
-FXint IconList::fillItems(const FXchar** strings,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
+int IconList::fillItems(const char** strings,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
 {
-    register FXint n=0;
+    register int n=0;
     if (strings)
     {
         while (strings[n])
@@ -3511,9 +3505,9 @@ FXint IconList::fillItems(const FXchar** strings,FXIcon *big,FXIcon* mini,void*
 
 
 // Fill list by appending items from newline separated strings
-FXint IconList::fillItems(const FXString& strings,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
+int IconList::fillItems(const FXString& strings,FXIcon *big,FXIcon* mini,void* ptr,FXbool notify)
 {
-    register FXint n=0;
+    register int n=0;
     FXString text;
     while (!(text=strings.section('\n',n)).empty())
     {
@@ -3525,9 +3519,9 @@ FXint IconList::fillItems(const FXString& strings,FXIcon *big,FXIcon* mini,void*
 
 
 // Move item from oldindex to newindex
-FXint IconList::moveItem(FXint newindex,FXint oldindex,FXbool notify)
+int IconList::moveItem(int newindex,int oldindex,FXbool notify)
 {
-    register FXint old=current;
+    register int old=current;
     register IconItem *item;
 
     // Must be in range
@@ -3597,10 +3591,10 @@ FXint IconList::moveItem(FXint newindex,FXint oldindex,FXbool notify)
 
 
 // Extract node from list
-IconItem* IconList::extractItem(FXint index,FXbool notify)
+IconItem* IconList::extractItem(int index,FXbool notify)
 {
     register IconItem *result;
-    register FXint old=current;
+    register int old=current;
 
     // Must be in range
     if (index<0 || items.no()<=index)
@@ -3661,9 +3655,9 @@ IconItem* IconList::extractItem(FXint index,FXbool notify)
 
 
 // Remove node from list
-void IconList::removeItem(FXint index,FXbool notify)
+void IconList::removeItem(int index,FXbool notify)
 {
-    register FXint old=current;
+    register int old=current;
 
     // Must be in range
     if (index<0 || items.no()<=index)
@@ -3723,10 +3717,10 @@ void IconList::removeItem(FXint index,FXbool notify)
 // Remove all items
 void IconList::clearItems(FXbool notify)
 {
-    register FXint old=current;
+    register int old=current;
 
     // Delete items
-    for (FXint index=items.no()-1; 0<=index; index--)
+    for (int index=items.no()-1; 0<=index; index--)
     {
         if (notify && target)
         {
@@ -3808,7 +3802,7 @@ void IconList::setSelTextColor(FXColor clr)
 
 
 // Set text width
-void IconList::setItemSpace(FXint s)
+void IconList::setItemSpace(int s)
 {
     if (s<1) s=1;
     if (itemSpace!=s)
@@ -3820,9 +3814,9 @@ void IconList::setItemSpace(FXint s)
 
 
 // Change list style
-void IconList::setListStyle(FXuint style)
+void IconList::setListStyle(unsigned int style)
 {
-    FXuint opts=(options&~ICONLIST_MASK) | (style&ICONLIST_MASK);
+    unsigned int opts=(options&~ICONLIST_MASK) | (style&ICONLIST_MASK);
     if (options!=opts)
     {
         options=opts;
@@ -3832,7 +3826,7 @@ void IconList::setListStyle(FXuint style)
 
 
 // Get list style
-FXuint IconList::getListStyle() const
+unsigned int IconList::getListStyle() const
 {
     return (options&ICONLIST_MASK);
 }
