@@ -40,19 +40,19 @@ protected:
     FXIcon   *bigIcon;    // Icon of item
     FXIcon   *miniIcon;   // Icon of item
     void     *data;       // Item user data pointer
-    FXuint    state;      // Item state flags
+    unsigned int    state;      // Item state flags
 private:
     IconItem(const IconItem&);
     IconItem& operator=(const IconItem&);
 protected:
     IconItem():bigIcon(NULL),miniIcon(NULL),data(NULL),state(0){}
-    virtual void draw(IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-    virtual FXint hitItem(const IconList* list,FXint rx,FXint ry,FXint rw=1,FXint rh=1) const;
+    virtual void draw(IconList* list,FXDC& dc,int x,int y,int w,int h) const;
+    virtual int hitItem(const IconList* list,int rx,int ry,int rw=1,int rh=1) const;
 protected:
-    virtual void drawBigIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-    virtual void drawMiniIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-	FXbool isOdd(FXint i) const;
-    virtual void drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+    virtual void drawBigIcon(const IconList* list,FXDC& dc,int x,int y,int w,int h) const;
+    virtual void drawMiniIcon(const IconList* list,FXDC& dc,int x,int y,int w,int h) const;
+	FXbool isOdd(int i) const;
+    virtual void drawDetails(IconList* list,FXDC& dc,int x,int y,int w,int h) const;
 public:
     enum
     {
@@ -144,10 +144,10 @@ public:
     }
 
     // Return width of item as drawn in list
-    virtual FXint getWidth(const IconList* list) const;
+    virtual int getWidth(const IconList* list) const;
 
     // Return height of item as drawn in list
-    virtual FXint getHeight(const IconList* list) const;
+    virtual int getHeight(const IconList* list) const;
 
     // Create server-side resources
     virtual void create();
@@ -170,7 +170,7 @@ public:
 
 
 // Icon item collate function
-typedef FXint (*IconListSortFunc)(const IconItem*,const IconItem*);
+typedef int (*IconListSortFunc)(const IconItem*,const IconItem*);
 
 
 // List of IconItem's
@@ -202,13 +202,13 @@ class FXAPI IconList : public FXScrollArea
 protected:
     FXHeader          *header;            // Header control
     IconItemList      items;		      // Item list
-    FXint              nrows;             // Number of rows
-    FXint              ncols;             // Number of columns
-    FXint              anchor;            // Anchor item
-    FXint              current;           // Current item
-    FXint              extent;            // Extent item
-    FXint              cursor;            // Cursor item
-    FXint              viewable;          // Visible item
+    int              nrows;             // Number of rows
+    int              ncols;             // Number of columns
+    int              anchor;            // Anchor item
+    int              current;           // Current item
+    int              extent;            // Extent item
+    int              cursor;            // Cursor item
+    int              viewable;          // Visible item
     FXFont            *font;              // Font
     IconListSortFunc   sortfunc;          // Item sort function
     FXColor            textColor;         // Text color
@@ -217,22 +217,22 @@ protected:
 	FXColor			   highlightColor;    // Highlight color
 	FXColor			   sortColor;         // Sort color
 	FXColor			   highlightSortColor;// Highlight sort color
-    FXint              itemWidth;         // Item width
-    FXint              itemHeight;        // Item height
-    FXint              itemSpace;         // Space for item label
-    FXint              anchorx;           // Rectangular selection
-    FXint              anchory;
-    FXint              currentx;
-    FXint              currenty;
-    FXint              grabx;             // Grab point x
-    FXint              graby;             // Grab point y
+    int              itemWidth;         // Item width
+    int              itemHeight;        // Item height
+    int              itemSpace;         // Space for item label
+    int              anchorx;           // Rectangular selection
+    int              anchory;
+    int              currentx;
+    int              currenty;
+    int              grabx;             // Grab point x
+    int              graby;             // Grab point y
     FXString           lookup;            // Lookup string
     FXString           help;              // Help text
     FXbool             state;             // State of item
 	FXbool			   allowTooltip;      // Allow tooltip in single click mode
-	FXuint			   numsortheader;     // Index of the sorted column
-	FXdouble           headerpct[10];     // Header sizes, relatively to the list width (in percent)
-	FXint			   count;             // Counter used to properly initialize the relative header sizes
+	unsigned int			   numsortheader;     // Index of the sorted column
+	double           headerpct[10];     // Header sizes, relatively to the list width (in percent)
+	int			   count;             // Counter used to properly initialize the relative header sizes
 	FXbool 			   autosize;
 	FXbool             ignorecase;        // Case sensitivity for file name sorting
 	FXbool			   initheaderpct;	  // Indicates we have to initialize the headerpct for the deletion columns
@@ -240,13 +240,13 @@ protected:
     IconList()
 	{}
     void recompute();
-    void getrowscols(FXint& nr,FXint& nc,FXint w,FXint h) const;
-    void drawLasso(FXint x0,FXint y0,FXint x1,FXint y1);
-    void lassoChanged(FXint ox,FXint oy,FXint ow,FXint oh,FXint nx,FXint ny,FXint nw,FXint nh,FXbool notify);
-    virtual void moveContents(FXint x,FXint y);
+    void getrowscols(int& nr,int& nc,int w,int h) const;
+    void drawLasso(int x0,int y0,int x1,int y1);
+    void lassoChanged(int ox,int oy,int ow,int oh,int nx,int ny,int nw,int nh,FXbool notify);
+    virtual void moveContents(int x,int y);
     virtual IconItem *createItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr);
-    static FXint compareSection(const FXchar *p,const FXchar* q,FXint s);
-    static FXint compareSectionCase(const FXchar *p,const FXchar* q,FXint s);
+    static int compareSection(const char *p,const char* q,int s);
+    static int compareSectionCase(const char *p,const char* q,int s);
 private:
     IconList(const IconList&);
     IconList &operator=(const IconList&);
@@ -296,10 +296,10 @@ public:
 	long onUpdToggleAutosize(FXObject*,FXSelector,void*);
 	long onCmdHeaderClicked(FXObject*,FXSelector,void*);
 public:
-    static FXint ascending(const IconItem* a,const IconItem* b);
-    static FXint descending(const IconItem* a,const IconItem* b);
-    static FXint ascendingCase(const IconItem* a,const IconItem* b);
-    static FXint descendingCase(const IconItem* a,const IconItem* b);
+    static int ascending(const IconItem* a,const IconItem* b);
+    static int descending(const IconItem* a,const IconItem* b);
+    static int ascendingCase(const IconItem* a,const IconItem* b);
+    static int descendingCase(const IconItem* a,const IconItem* b);
 public:
     enum
     {
@@ -319,7 +319,7 @@ public:
 public:
 
     // Construct icon list with no items in it initially
-    IconList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=_ICONLIST_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    IconList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=_ICONLIST_NORMAL,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
@@ -334,10 +334,10 @@ public:
     virtual void layout();
 
 	// Compute and return content width
-    virtual FXint getContentWidth();
+    virtual int getContentWidth();
 
     // Return content height
-    virtual FXint getContentHeight();
+    virtual int getContentHeight();
 
     // Icon list can receive focus
     virtual bool canFocus() const;
@@ -349,13 +349,13 @@ public:
     virtual void killFocus();
 
     // Return viewport size
-    virtual FXint getViewportHeight();
+    virtual int getViewportHeight();
 
     // Resize this window to the specified width and height
-    virtual void resize(FXint w,FXint h);
+    virtual void resize(int w,int h);
 
     // Move and resize this window in the parent's coordinates
-    virtual void position(FXint x,FXint y,FXint w,FXint h);
+    virtual void position(int x,int y,int w,int h);
 
     // Return ignore case flag
 	FXbool getIgnoreCase() const
@@ -367,19 +367,19 @@ public:
 	void setIgnoreCase(const FXbool);
 	
 	// Return number of items
-    FXint getNumItems() const
+    int getNumItems() const
     {
         return items.no();
     }
 
     // Return number of rows
-    FXint getNumRows() const
+    int getNumRows() const
     {
         return nrows;
     }
 
     // Return number of columns
-    FXint getNumCols() const
+    int getNumCols() const
     {
         return ncols;
     }
@@ -391,98 +391,98 @@ public:
     }
 
     // Set headers from array of strings
-    void setHeaders(const FXchar** strings,FXint size=1);
+    void setHeaders(const char** strings,int size=1);
 
     // Set headers from newline separated strings
-    void setHeaders(const FXString& strings,FXint size=1);
+    void setHeaders(const FXString& strings,int size=1);
 
     // Append header with given text and optional icon
-    void appendHeader(const FXString& text,FXIcon *icon=NULL,FXint size=1);
+    void appendHeader(const FXString& text,FXIcon *icon=NULL,int size=1);
 
     // Remove header at index
-    void removeHeader(FXint index);
+    void removeHeader(int index);
 
     // Change text of header at index
-    void setHeaderText(FXint index,const FXString& text);
+    void setHeaderText(int index,const FXString& text);
 
     // Return text of header at index
-    FXString getHeaderText(FXint index) const;
+    FXString getHeaderText(int index) const;
 
     // Change icon of header at index
-    void setHeaderIcon(FXint index,FXIcon *icon);
+    void setHeaderIcon(int index,FXIcon *icon);
 
     // Return icon of header at index
-    FXIcon* getHeaderIcon(FXint index) const;
+    FXIcon* getHeaderIcon(int index) const;
 
     // Change size of header at index
-    void setHeaderSize(FXint index,FXint size);
+    void setHeaderSize(int index,int size);
 
     // Return width of header at index
-    FXint getHeaderSize(FXint index) const;
+    int getHeaderSize(int index) const;
 
     // Return number of headers
-    FXint getNumHeaders() const;
+    int getNumHeaders() const;
 
     // Return the item at the given index
-    IconItem *getItem(FXint index) const;
+    IconItem *getItem(int index) const;
 
     // Replace the item with a [possibly subclassed] item
-    FXint setItem(FXint index,IconItem* item,FXbool notify=FALSE);
+    int setItem(int index,IconItem* item,FXbool notify=FALSE);
 
     // Replace items text, icons, and user-data pointer
-    FXint setItem(FXint index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int setItem(int index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
 
     // Fill list by appending items from array of strings
-    FXint fillItems(const FXchar** strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int fillItems(const char** strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
 
     // Fill list by appending items from newline separated strings
-    FXint fillItems(const FXString& strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int fillItems(const FXString& strings,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
 
     // Insert a new [possibly subclassed] item at the give index
-    FXint insertItem(FXint index,IconItem* item,FXbool notify=FALSE);
+    int insertItem(int index,IconItem* item,FXbool notify=FALSE);
 
     // Insert item at index with given text, icons, and user-data pointer
-    FXint insertItem(FXint index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int insertItem(int index,const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
 
     // Append a [possibly subclassed] item to the end of the list
-    FXint appendItem(IconItem* item,FXbool notify=FALSE);
+    int appendItem(IconItem* item,FXbool notify=FALSE);
 
     // Append new item with given text and optional icons, and user-data pointer
-    FXint appendItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int appendItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
 
     // Prepend a [possibly subclassed] item to the end of the list
-    FXint prependItem(IconItem* item,FXbool notify=FALSE);
+    int prependItem(IconItem* item,FXbool notify=FALSE);
 
     // Prepend new item with given text and optional icons, and user-data pointer
-    FXint prependItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
+    int prependItem(const FXString& text,FXIcon *big=NULL,FXIcon* mini=NULL,void* ptr=NULL,FXbool notify=FALSE);
 
     // Move item from oldindex to newindex
-    FXint moveItem(FXint newindex,FXint oldindex,FXbool notify=FALSE);
+    int moveItem(int newindex,int oldindex,FXbool notify=FALSE);
 
     // Extract item from list
-    IconItem* extractItem(FXint index,FXbool notify=FALSE);
+    IconItem* extractItem(int index,FXbool notify=FALSE);
 
     // Remove item from list
-    void removeItem(FXint index,FXbool notify=FALSE);
+    void removeItem(int index,FXbool notify=FALSE);
 
     // Remove all items from list
     void clearItems(FXbool notify=FALSE);
 
     // Return item width
-    FXint getItemWidth() const
+    int getItemWidth() const
     {
         return itemWidth;
     }
 
     // Return item height
-    FXint getItemHeight() const
+    int getItemHeight() const
     {
         return itemHeight;
     }
 
 	
     // Return index of item at x,y, or -1 if none
-    virtual FXint getItemAt(FXint x,FXint y);
+    virtual int getItemAt(int x,int y);
 
 	// Search items by name, beginning from item start.  If the start
 	// item is -1 the search will start at the first item in the list.
@@ -492,7 +492,7 @@ public:
 	// The option SEARCH_IGNORECASE causes a case-insensitive match.  Finally,
 	// passing SEARCH_PREFIX causes searching for a prefix of the item name.
 	// Return -1 if no matching item is found.
-    FXint findItem(const FXString& text,FXint start=-1,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+    int findItem(const FXString& text,int start=-1,unsigned int flags=SEARCH_FORWARD|SEARCH_WRAP) const;
 
    
     // Search items by associated user data, beginning from item start. If the
@@ -500,37 +500,37 @@ public:
     // Flags may be SEARCH_FORWARD or SEARCH_BACKWARD to control the
     // search direction; this can be combined with SEARCH_NOWRAP or SEARCH_WRAP
     // to control whether the search wraps at the start or end of the list.
-    FXint findItemByData(const void *ptr,FXint start=-1,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+    int findItemByData(const void *ptr,int start=-1,unsigned int flags=SEARCH_FORWARD|SEARCH_WRAP) const;
 
     // Scroll to make item at index visible
-    virtual void makeItemVisible(FXint index);
+    virtual void makeItemVisible(int index);
 
     // Change item text
-    void setItemText(FXint index,const FXString& text);
+    void setItemText(int index,const FXString& text);
 
     // Return item text
-    FXString getItemText(FXint index) const;
+    FXString getItemText(int index) const;
 
     // Change item big icon
-    void setItemBigIcon(FXint index,FXIcon* icon,FXbool owned=FALSE);
+    void setItemBigIcon(int index,FXIcon* icon,FXbool owned=FALSE);
 
     // Return big icon of item at index
-    FXIcon* getItemBigIcon(FXint index) const;
+    FXIcon* getItemBigIcon(int index) const;
 
     // Change item mini icon
-    void setItemMiniIcon(FXint index,FXIcon* icon,FXbool owned=FALSE);
+    void setItemMiniIcon(int index,FXIcon* icon,FXbool owned=FALSE);
 
     // Return mini icon of item at index
-    FXIcon* getItemMiniIcon(FXint index) const;
+    FXIcon* getItemMiniIcon(int index) const;
 
     // Change item user-data pointer
-    void setItemData(FXint index,void* ptr);
+    void setItemData(int index,void* ptr);
 
     // Return item user-data pointer
-    void* getItemData(FXint index) const;
+    void* getItemData(int index) const;
 
 	// Return TRUE if item is selected
-	FXbool isItemSelected(FXint index) const
+	FXbool isItemSelected(int index) const
 	{
 		if ((unsigned int)index >= (unsigned int)items.no())
 			fxerror("%s::isItemSelected: index out of range.\n",getClassName());
@@ -538,64 +538,64 @@ public:
 	}
 
     // Return TRUE if item at index is current
-    FXbool isItemCurrent(FXint index) const;
+    FXbool isItemCurrent(int index) const;
 
     // Return TRUE if item at index is visible
-    FXbool isItemVisible(FXint index) const;
+    FXbool isItemVisible(int index) const;
 
     // Return TRUE if item at index is enabled
-    FXbool isItemEnabled(FXint index) const;
+    FXbool isItemEnabled(int index) const;
 
     // Return item hit code: 0 outside, 1 icon, 2 text
-    FXint hitItem(FXint index,FXint x,FXint y,FXint ww=1,FXint hh=1) const;
+    int hitItem(int index,int x,int y,int ww=1,int hh=1) const;
 
     // Repaint item at index
-    void updateItem(FXint index) const;
+    void updateItem(int index) const;
 
     // Enable item at index
-    virtual FXbool enableItem(FXint index);
+    virtual FXbool enableItem(int index);
 
     // Disable item at index
-    virtual FXbool disableItem(FXint index);
+    virtual FXbool disableItem(int index);
 
     // Select item at index
-    virtual FXbool selectItem(FXint index,FXbool notify=FALSE);
+    virtual FXbool selectItem(int index,FXbool notify=FALSE);
 
     // Deselect item at index
-    virtual FXbool deselectItem(FXint index,FXbool notify=FALSE);
+    virtual FXbool deselectItem(int index,FXbool notify=FALSE);
 
     // Toggle item at index
-    virtual FXbool toggleItem(FXint index,FXbool notify=FALSE);
+    virtual FXbool toggleItem(int index,FXbool notify=FALSE);
 
     // Select items in rectangle
-    virtual FXbool selectInRectangle(FXint x,FXint y,FXint w,FXint h,FXbool notify=FALSE);
+    virtual FXbool selectInRectangle(int x,int y,int w,int h,FXbool notify=FALSE);
 
     // Extend selection from anchor index to index
-    virtual FXbool extendSelection(FXint index,FXbool notify=FALSE);
+    virtual FXbool extendSelection(int index,FXbool notify=FALSE);
 
     // Deselect all items
     virtual FXbool killSelection(FXbool notify=FALSE);
 
     // Change current item index
-    virtual void setCurrentItem(FXint index,FXbool notify=FALSE);
+    virtual void setCurrentItem(int index,FXbool notify=FALSE);
 
     // Return current item index, or -1 if none
-    FXint getCurrentItem() const
+    int getCurrentItem() const
     {
         return current;
     }
 
     // Change anchor item index
-    void setAnchorItem(FXint index);
+    void setAnchorItem(int index);
 
     // Return anchor item index, or -1 if none
-    FXint getAnchorItem() const
+    int getAnchorItem() const
     {
         return anchor;
     }
 
     // Return index of item under cursor, or -1 if none
-    FXint getCursorItem() const
+    int getCursorItem() const
     {
         return cursor;
     }
@@ -616,13 +616,13 @@ public:
     }
 
 	// Set sort header
-	void setSortHeader(const FXuint num)
+	void setSortHeader(const unsigned int num)
 	{
 		numsortheader=num;
 	}
 	
 	// Get sort header
-	FXuint getSortHeader()
+	unsigned int getSortHeader()
 	{
 		return numsortheader;
 	}
@@ -683,19 +683,19 @@ public:
     void setSelTextColor(FXColor clr);
 
     // Change maximum item space for each item
-    void setItemSpace(FXint s);
+    void setItemSpace(int s);
 
     // Return maximum item space
-    FXint getItemSpace() const
+    int getItemSpace() const
     {
         return itemSpace;
     }
 
     // Get the current icon list style
-    FXuint getListStyle() const;
+    unsigned int getListStyle() const;
 
     // Set the current icon list style.
-    void setListStyle(FXuint style);
+    void setListStyle(unsigned int style);
 
     // Set the status line help text for this widget
     void setHelpText(const FXString& text);
