@@ -26,7 +26,7 @@ FXIMPLEMENT(OverwriteBox,DialogBox,OverwriteBoxMap,ARRAYNUMBER(OverwriteBoxMap))
 
 
 // Create message box
-OverwriteBox::OverwriteBox(FXWindow *win,const FXString& name,const FXString& text,FXuint opts,FXint x,FXint y):
+OverwriteBox::OverwriteBox(FXWindow *win,const FXString& name,const FXString& text,unsigned int opts,int x,int y):
         DialogBox(win,name,opts|DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,x,y,0,0)
 {
     FXVerticalFrame* content=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
