@@ -24,13 +24,13 @@ FXIMPLEMENT(PathLinker, FXHorizontalFrame, PathLinkerMap, ARRAYNUMBER(PathLinker
 
 
 // Construct object
-PathLinker::PathLinker(FXComposite* a, FileList* flist, DirList* dlist, FXuint opts): FXHorizontalFrame(a, opts, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2)
+PathLinker::PathLinker(FXComposite* a, FileList* flist, DirList* dlist, unsigned int opts): FXHorizontalFrame(a, opts, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2)
 {
 	filelist=flist;
 	dirlist=dlist;
 	
 	// Add some path links
-    FXint id = ID_START_LINK;
+    int id = ID_START_LINK;
     for(int i = 0; i < MAX_LINKS; i++)
     {
         std::stringstream ss;
@@ -82,21 +82,21 @@ PathLinker::~PathLinker()
 // Change current path
 void PathLinker::setPath(FXString text)
 {	
-	FXint nextPos = 0;
-    FXint previousPos = 0;
+	int nextPos = 0;
+    int previousPos = 0;
 
 	// Remove trailing /
 	FXString path = ::cleanPath(text);	
 	
 	// Indicates if actual path is included in the visited path
-	FXint visited;
+	int visited;
 	if (path==PATHSEPSTRING)
 		visited = visitedPath.find(PATHSEPSTRING);
 	else
 		visited = visitedPath.find(path+PATHSEPSTRING);
 
 	// If actual path is included in the visited path
-	FXuint index = 0;
+	unsigned int index = 0;
 	if (visited >= 0)
 	{		
 		nextPos = path.find(PATHSEPSTRING, 0);		
@@ -112,7 +112,7 @@ void PathLinker::setPath(FXString text)
 	}
 	
 	// File list width
-	//FXint frameWidth = filelist->getWidth();
+	//int frameWidth = filelist->getWidth();
 
 	// Hide all of the link buttons
     for(int i = 0; i < MAX_LINKS; i++)
@@ -123,7 +123,7 @@ void PathLinker::setPath(FXString text)
     }
 
     visitedPath = path;
-    //FXint textWidth = normalFont->getTextWidth(path.text(), path.length());
+    //int textWidth = normalFont->getTextWidth(path.text(), path.length());
 
     FXString displayText = visitedPath;
     
@@ -139,7 +139,7 @@ void PathLinker::setPath(FXString text)
     }
     */
     
-    FXuint ind = 0;
+    unsigned int ind = 0;
     nextPos = displayText.find(PATHSEPSTRING, 0);
     previousPos = 0;
         
@@ -177,13 +177,13 @@ void PathLinker::setPath(FXString text)
 
 
 // Update current path according to the clicked button
-void PathLinker::updatePath(FXString text, FXuint index)
+void PathLinker::updatePath(FXString text, unsigned int index)
 {	
 	// Remove trailing /
 	FXString path=::cleanPath(text);
 		
 	// File list width
-	//FXint frameWidth = filelist->getWidth();
+	//int frameWidth = filelist->getWidth();
 
 	// Hide all of the link buttons
     for(int i = 0; i < MAX_LINKS; i++)
@@ -195,7 +195,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
 
     visitedPath = path;
     //FXFont* normalFont = getApp()->getNormalFont();
-    //FXint textWidth = normalFont->getTextWidth(path.text(), path.length());
+    //int textWidth = normalFont->getTextWidth(path.text(), path.length());
 
     FXString displayText = visitedPath;
     
@@ -211,9 +211,9 @@ void PathLinker::updatePath(FXString text, FXuint index)
     }
     */
     
-	FXint nextPos = 0;
-    FXint previousPos = 0;
-    FXuint ind = 0;
+	int nextPos = 0;
+    int previousPos = 0;
+    unsigned int ind = 0;
     nextPos = displayText.find(PATHSEPSTRING, 0);
         
     while(nextPos >= 0)
@@ -239,7 +239,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
 }
 
 
-void PathLinker::setText(FXuint index, FXString displayText)
+void PathLinker::setText(unsigned int index, FXString displayText)
 {	
     if(index < MAX_LINKS)
     {        
@@ -266,8 +266,8 @@ long PathLinker::pathButtonPressed(FXObject * obj ,FXSelector sel ,void* ptr)
 	}
 	else
 	{
-		FXint rpos = 0;
-		rpos = visitedPath.rfind((FXchar)PATHSEPSTRING[0], 0x7FFFFFFF, nbActiveButtons - (endId - ID_START_LINK + 1));
+		int rpos = 0;
+		rpos = visitedPath.rfind((char)PATHSEPSTRING[0], 0x7FFFFFFF, nbActiveButtons - (endId - ID_START_LINK + 1));
 		filePath = visitedPath.left(rpos+1);
 	}
 
@@ -307,11 +307,11 @@ long PathLinker::onUpdPath(FXObject * obj ,FXSelector sel ,void* ptr)
 		if (currentButton==0)
 			currentlink=PATHSEPSTRING;
 		else
-			currentlink = visitedPath.before((FXchar)PATHSEPSTRING[0],currentButton+1);
+			currentlink = visitedPath.before((char)PATHSEPSTRING[0],currentButton+1);
 
 		// Test each link for existence and update to the current path if necessary
 		FXString path=visitedPath;
-		FXuint n=1;
+		unsigned int n=1;
 		while (path != "")
 		{
 			if (!::exists(path))
@@ -322,7 +322,7 @@ long PathLinker::onUpdPath(FXObject * obj ,FXSelector sel ,void* ptr)
 			}
 		
 			// Next path to test
-			path=visitedPath.rbefore((FXchar)PATHSEPSTRING[0],n);
+			path=visitedPath.rbefore((char)PATHSEPSTRING[0],n);
 			n++;
 		}
 			
