@@ -22,7 +22,7 @@ public:
         ID_LAST
     };
 
-    PathLinker(FXComposite* a, FileList* flist, DirList* dlist=NULL, FXuint opts=0);
+    PathLinker(FXComposite* a, FileList* flist, DirList* dlist=NULL, unsigned int opts=0);
 	PathLinker()
 	{}
     virtual void create();
@@ -36,8 +36,8 @@ public:
 protected:
     typedef std::vector<FXButton*> vector_FXButton;
     vector_FXButton linkButtons;
-    FXuint nbActiveButtons;
-    FXuint currentButton;
+    unsigned int nbActiveButtons;
+    unsigned int currentButton;
     FXString visitedPath;
 	TextLabel* focusButton;
 	FXFont* normalFont;
@@ -45,8 +45,8 @@ protected:
 	FileList* filelist;
 	DirList* dirlist;
 private:
-    void updatePath(FXString, FXuint);
-    void setText(FXuint, FXString);
+    void updatePath(FXString, unsigned int);
+    void setText(unsigned int, FXString);
 };
 
 #endif
