@@ -45,15 +45,15 @@ extern FXbool save_win_pos;
 // Create hilite color from given color for gradient controls
 FXColor makeHiliteColorGradient(FXColor color)
 {
-	FXuint r, g, b;
+	unsigned int r, g, b;
 	
 	r=FXREDVAL(color);
 	g=FXGREENVAL(color);
 	b=FXBLUEVAL(color);
 
-	r=(FXuint)(FXMIN(1.2*r,255));
-	g=(FXuint)(FXMIN(1.2*g,255));
-	b=(FXuint)(FXMIN(1.2*b,255));
+	r=(unsigned int)(FXMIN(1.2*r,255));
+	g=(unsigned int)(FXMIN(1.2*g,255));
+	b=(unsigned int)(FXMIN(1.2*b,255));
 
 	return FXRGB(r,g,b);
 }
@@ -62,15 +62,15 @@ FXColor makeHiliteColorGradient(FXColor color)
 // Create shadow color from given color for gradient controls
 FXColor makeShadowColorGradient(FXColor color)
 {
-	FXuint r, g, b;
+	unsigned int r, g, b;
 	
 	r=FXREDVAL(color);
 	g=FXGREENVAL(color);
 	b=FXBLUEVAL(color);
 
-	r=(FXuint)(0.7*r);
-	g=(FXuint)(0.7*g);
-	b=(FXuint)(0.7*b);
+	r=(unsigned int)(0.7*r);
+	g=(unsigned int)(0.7*g);
+	b=(unsigned int)(0.7*b);
 
 	return FXRGB(r,g,b);
 }
@@ -117,7 +117,7 @@ FXDEFMAP(PreferencesBox) PreferencesMap[]=
 FXIMPLEMENT(PreferencesBox,DialogBox,PreferencesMap,ARRAYNUMBER(PreferencesMap))
 
 // Construct window
-PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor listforecolor, FXColor highlightcolor, FXColor pbarcolor, FXColor attentioncolor): DialogBox(win,_("Preferences"), DECOR_TITLE|DECOR_BORDER)
+PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor listforecolor, FXColor highlightcolor, FXColor pbarcolor, FXColor attentioncolor, FXColor scrollbarcolor): DialogBox(win,_("Preferences"), DECOR_TITLE|DECOR_BORDER)
 {
     currTheme.name = _("Current Theme");
     currTheme.color[0] = getApp()->getBaseColor();
@@ -131,20 +131,20 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     currTheme.color[8] = highlightcolor;
     currTheme.color[9] = pbarcolor;
 	currTheme.color[10] = attentioncolor;
+	currTheme.color[11] = scrollbarcolor;
 
     Themes[0] = currTheme;
-    Themes[1] = Theme("FOX",FXRGB(212,208,200),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(10,36,106),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(10,36,106),FXRGB(255,0,0));
-    Themes[2] = Theme("GNOME2",FXRGB(220,218,213),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(75,105,131),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(75,105,131),FXRGB(255,0,0));
-    Themes[3] = Theme("KDE3",FXRGB(238,238,230),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(255,222,118),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(255,222,118),FXRGB(255,0,0));
-    Themes[4] = Theme("XFCE4",FXRGB(238,238,238),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,0),FXRGB(99,119,146),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(99,119,146),FXRGB(255,0,0));
-    Themes[5] = Theme("CDE",FXRGB(156,153,156),FXRGB(0,0,0),FXRGB(131,129,131),FXRGB(255,255,255),FXRGB(49,97,131),FXRGB(255,255,255),FXRGB(131,129,131),FXRGB(255,255,255),FXRGB(165,162,165),FXRGB(49,97,131),FXRGB(255,0,0));
-    Themes[6] = Theme("Digital CDE",FXRGB(74,121,131),FXRGB(0,0,0),FXRGB(49,76,74),FXRGB(255,255,255),FXRGB(82,101,113),FXRGB(255,255,255),FXRGB(49,76,74),FXRGB(255,255,255),FXRGB(69,107,104),FXRGB(82,101,113),FXRGB(255,0,0));
-    Themes[7] = Theme("Sea Sky",FXRGB(165,178,198),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(49,101,156),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(49,101,156),FXRGB(255,0,0));
-    Themes[8] = Theme("Blue Slate",FXRGB(156,186,205),FXRGB(0,0,0),FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(82,129,148),FXRGB(255,255,255),FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(82,129,148),FXRGB(255,0,0));
-    Themes[9] = Theme("Human",FXRGB(0xEF,0xEB,0xE7),FXRGB(0,0,0),FXRGB(0xEE,0xEE,0xEE),FXRGB(0,0,0),FXRGB(0xB3,0x91,0x69),FXRGB(0xFF,0xFF,0xFF),FXRGB(0xEE,0xEE,0xEE),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0xB3,0x91,0x69),FXRGB(255,0,0));
-    Themes[10] = Theme("iMac",FXRGB(205,206,205),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,128),FXRGB(255,0,0));
-    Themes[11] = Theme("BeOS",FXRGB(222,218,222),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(172,170,172),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(172,170,172),FXRGB(255,0,0));
-	Themes[12] = Theme("Windows 95",FXRGB(192,192,192),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,128),FXRGB(255,0,0));
+    Themes[1] = Theme("Clearlooks",FXRGB(237,236,235),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(139,175,220),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(121,153,192),FXRGB(255,0,0),FXRGB(149,178,215));
+    Themes[2] = Theme("Human",FXRGB(239,235,231),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,0),FXRGB(211,170,123),FXRGB(255,255,255),FXRGB(238,238,238),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(195,158,114),FXRGB(255,0,0),FXRGB(212,172,124));
+    Themes[3] = Theme("Sea Sky",FXRGB(165,178,198),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(49,101,156),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(49,101,156),FXRGB(255,0,0),FXRGB(68,106,146));
+    Themes[4] = Theme("Blue Slate",FXRGB(156,186,205),FXRGB(0,0,0),FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(82,129,148),FXRGB(255,255,255),FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(82,129,148),FXRGB(255,0,0),FXRGB(156,186,205));
+    Themes[5] = Theme("FOX",FXRGB(212,208,200),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(10,36,106),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(10,36,106),FXRGB(255,0,0),FXRGB(212,208,200));
+    Themes[6] = Theme("GNOME2",FXRGB(220,218,213),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(75,105,131),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(75,105,131),FXRGB(255,0,0),FXRGB(134,171,217));
+    Themes[7] = Theme("KDE3",FXRGB(238,238,230),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(255,222,118),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(255,222,118),FXRGB(255,0,0),FXRGB(238,238,230));
+    Themes[8] = Theme("XFCE4",FXRGB(238,238,238),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,0),FXRGB(99,119,146),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(99,119,146),FXRGB(255,0,0),FXRGB(238,238,238));
+    Themes[9] = Theme("CDE",FXRGB(156,153,156),FXRGB(0,0,0),FXRGB(131,129,131),FXRGB(255,255,255),FXRGB(49,97,131),FXRGB(255,255,255),FXRGB(131,129,131),FXRGB(255,255,255),FXRGB(165,162,165),FXRGB(49,97,131),FXRGB(255,0,0),FXRGB(156,153,156));
+    Themes[10] = Theme("iMac",FXRGB(205,206,205),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,128),FXRGB(255,0,0),FXRGB(205,206,205));
+	Themes[11] = Theme("Windows 95",FXRGB(192,192,192),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(238,238,238),FXRGB(0,0,128),FXRGB(255,0,0),FXRGB(192,192,192));
 
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
@@ -165,7 +165,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
     // First tab - General options
     new FXTabItem(tabbook,_("&General"),NULL);
-    FXVerticalFrame *options=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *options=new FXVerticalFrame(tabbook,FRAME_RAISED);
 
 	FXGroupBox *group=new FXGroupBox(options,_("Options"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     trashcan=new FXCheckButton(group,_("Use trash can for file deletion (safe delete)")); 
@@ -180,9 +180,17 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 #ifdef STARTUP_NOTIFICATION
 	usesn=new FXCheckButton(group,_("Notify when applications start up"));
 #endif
+
+    FXMatrix *matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    new FXLabel(matrix,_("Date format used in file and directory lists:\n(Type 'man strftime' in a terminal for help on the format)"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    timeformat = new FXTextField(matrix,15,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
+    oldtimeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
+    timeformat->setText(oldtimeformat);
+
+
 	group=new FXGroupBox(options,_("Mouse"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     scroll=new FXCheckButton(group,_("Smooth scrolling in file lists and text windows"));
-    FXMatrix *matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_Y);
+    matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_Y);
 	new FXLabel(matrix,_("Mouse scrolling speed:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     FXSpinner* spinner=new FXSpinner(matrix,3,this,PreferencesBox::ID_WHEELADJUST,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
     spinner->setRange(1,100);
@@ -267,7 +275,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 		
     // Second tab - Dialogs
     new FXTabItem(tabbook,_("&Dialogs"),NULL);
-    FXVerticalFrame *dialogs=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *dialogs=new FXVerticalFrame(tabbook,FRAME_RAISED);
 	group=new FXGroupBox(dialogs,_("Confirmations"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     ask=new FXCheckButton(group,_("Confirm copy/move/rename/symlink"));
     dnd=new FXCheckButton(group,_("Confirm drag and drop"));
@@ -275,17 +283,16 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	del=new FXCheckButton(group,_("Confirm delete"));
 	del_emptydir=new FXCheckButton(group,_("Confirm delete non empty directories"),this,ID_CONFIRM_DEL_EMPTYDIR);
     overwrite=new FXCheckButton(group,_("Confirm overwrite"));
-	quit=new FXCheckButton(group,_("Confirm quit"));
+    exec=new FXCheckButton(group,_("Confirm execute text files"));
 
 	group=new FXGroupBox(dialogs,_("Warnings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 #if defined(linux)
     mount=new FXCheckButton (group,_("Warn when mount points are not responding"));
 	show_mount=new FXCheckButton(group, _("Display mount/umount success messages"));
 #endif
+	preserve_date_warning = new FXCheckButton (group,_("Warn when date preservation failed"));
     root_warning=new FXCheckButton (group,_("Warn if running as root"));
 
-	FXbool confirm_quit=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_quit",TRUE);
-	quit->setCheck(confirm_quit);
     FXbool confirm_trash=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_trash",TRUE);
 	trashmv->setCheck(confirm_trash);
     FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
@@ -294,6 +301,8 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	del_emptydir->setCheck(confirm_del_emptydir);
     FXbool confirm_overwrite=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_overwrite",TRUE);
 	overwrite->setCheck(confirm_overwrite);
+    FXbool confirm_exec=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_execute",TRUE);
+	exec->setCheck(confirm_exec);
     FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
 	ask->setCheck(ask_before_copy);
     FXbool confirm_dnd=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_drag_and_drop",TRUE);
@@ -306,6 +315,9 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	show_mount->setCheck(mount_messages);
 #endif
 
+	FXbool preserve_date_warn=getApp()->reg().readUnsignedEntry("OPTIONS","preserve_date_warn",TRUE);
+    preserve_date_warning->setCheck(preserve_date_warn);
+
 	FXbool root_warn=getApp()->reg().readUnsignedEntry("OPTIONS","root_warn",TRUE);
 	if(getuid()) // Simple user
         root_warning->disable();
@@ -314,7 +326,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
 	// Third tab - Programs
     new FXTabItem(tabbook,_("&Programs"),NULL);
-    FXVerticalFrame *programs=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *programs=new FXVerticalFrame(tabbook,FRAME_RAISED);
     group=new FXGroupBox(programs,_("Default programs"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     matrix = new FXMatrix(group,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
@@ -374,7 +386,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
 	// Fourth tab - Visual
     new FXTabItem(tabbook,_("&Themes"),NULL);
-    FXVerticalFrame *visual=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *visual=new FXVerticalFrame(tabbook,FRAME_RAISED);
     FXGroupBox *themes=new FXGroupBox(visual,_("Color theme"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXPacker *pack = new FXPacker(themes,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
     themesList = new FXList(pack,this,ID_THEME,LIST_BROWSESELECT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -401,6 +413,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	colorsBox->appendItem(_("File list highlight color"));
 	colorsBox->appendItem(_("Progress bar color"));
 	colorsBox->appendItem(_("Attention color"));
+	colorsBox->appendItem(_("Scrollbar color"));
     colorsBox->setCurrentItem(0);
 
 	// Controls theme
@@ -419,7 +432,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
     // Fifth tab - Fonts
     new FXTabItem(tabbook,_("&Fonts"),NULL);
-    FXVerticalFrame *fonts=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *fonts=new FXVerticalFrame(tabbook,FRAME_RAISED);
     FXGroupBox *fgroup=new FXGroupBox(fonts,_("Fonts"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     FXMatrix *fmatrix = new FXMatrix(fgroup,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -437,7 +450,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
     // Sixth tab - Key bindings
     new FXTabItem(tabbook,_("&Key Bindings"),NULL);
-    FXVerticalFrame *keybindings=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *keybindings=new FXVerticalFrame(tabbook,FRAME_RAISED);
     FXGroupBox *kbgroup=new FXGroupBox(keybindings,_("Key Bindings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     FXPacker *kbpack = new FXPacker(kbgroup,LAYOUT_FILL_X);
@@ -500,7 +513,7 @@ long PreferencesBox::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 long PreferencesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 {
     FileDialog browse(this,_("Select an executable file"));
-    const FXchar *patterns[]=
+    const char *patterns[]=
         {
             _("All files"),     "*",NULL
         };
@@ -1062,7 +1075,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1105,7 +1118,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1146,7 +1159,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1189,7 +1202,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1230,7 +1243,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1275,7 +1288,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1320,7 +1333,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1365,7 +1378,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		FXStringDict *strdict = getApp()->reg().find("FILETYPES");
 		FileDict *assoc=new FileDict(getApp());
 
-		FXint i;
+		int i;
 		FXString key, value, newvalue;
 		FXString strtmp, open, view, edit, command;
 		for (i=strdict->first(); i<strdict->size(); i=strdict->next(i))
@@ -1409,12 +1422,14 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
     getApp()->reg().writeUnsignedEntry("OPTIONS","use_trash_bypass",trashbypass->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","ask_before_copy",ask->getCheck());
     getApp()->reg().writeUnsignedEntry("SETTINGS","single_click",single_click);
+	getApp()->reg().writeStringEntry("SETTINGS","time_format",timeformat->getText().text());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_trash",trashmv->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete",del->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete_emptydir",del_emptydir->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_overwrite",overwrite->getCheck());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_execute",exec->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_drag_and_drop",dnd->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","preserve_date_warn",preserve_date_warning->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warning->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_mode",rootmode->getCheck());
 #ifdef STARTUP_NOTIFICATION
@@ -1476,14 +1491,14 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		file_tooltips=TRUE;
 	else
 		file_tooltips=FALSE;
-	getApp()->reg().writeUnsignedEntry("SETTINGS","file_tooltips",(FXuint)file_tooltips);
+	getApp()->reg().writeUnsignedEntry("SETTINGS","file_tooltips",(unsigned int)file_tooltips);
 
 	// Update the relative resize flag
 	if (relativeresize->getCheck())
 		relative_resize=TRUE;
 	else
 		relative_resize=FALSE;
-	getApp()->reg().writeUnsignedEntry("SETTINGS","relative_resize",(FXuint)relative_resize);
+	getApp()->reg().writeUnsignedEntry("SETTINGS","relative_resize",(unsigned int)relative_resize);
 
 	// Update the display path linker flag
 	show_pathlink=showpathlink->getCheck();
@@ -1508,6 +1523,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		getApp()->reg().writeColorEntry("SETTINGS","highlightcolor",currTheme.color[8]);
 		getApp()->reg().writeColorEntry("SETTINGS","pbarcolor",currTheme.color[9]);
 		getApp()->reg().writeColorEntry("SETTINGS","attentioncolor",currTheme.color[10]);
+		getApp()->reg().writeColorEntry("SETTINGS","scrollbarcolor",currTheme.color[11]);
 
     	// Control themes
 		FXColor hilitecolor, shadowcolor;
@@ -1569,6 +1585,9 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 	// Finally, update the registry
 	getApp()->reg().write();
 		
+	// Refresh panels
+	mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_REFRESH),NULL);
+
     DialogBox::onCmdAccept(o,s,p);
     return 1;
 }
@@ -1593,6 +1612,12 @@ long PreferencesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 	getApp()->reg().writeUnsignedEntry("OPTIONS","use_sudo",use_sudo);
 	scroll->setCheck(smoothscroll_prev);
 	rootmode->setCheck(rootmode_prev);
+	
+	timeformat->setText(oldtimeformat);	
+
+	
+	
+	
 #ifdef STARTUP_NOTIFICATION
 	usesn->setCheck(usesn_prev);
 #endif
@@ -1604,11 +1629,12 @@ long PreferencesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 	del->setCheck(del_prev);
 	del_emptydir->setCheck(del_emptydir_prev);
 	overwrite->setCheck(overwrite_prev);
-	quit->setCheck(quit_prev);
+	exec->setCheck(exec_prev);
 #if defined(linux)
 	mount->setCheck(mount_prev);
 	show_mount->setCheck(show_mount_prev);
 #endif
+	preserve_date_warning->setCheck(preserve_date_warning_prev);
 	root_warning->setCheck(root_warning_prev);
 	
 	// Third tab - Programs
@@ -1642,7 +1668,7 @@ long PreferencesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 
 
 // Execute dialog box modally
-FXuint PreferencesBox::execute(FXuint placement)
+unsigned int PreferencesBox::execute(unsigned int placement)
 {
 	// Save current preferences to restore them if cancel is pressed
 	
@@ -1671,11 +1697,12 @@ FXuint PreferencesBox::execute(FXuint placement)
 	del_prev=del->getCheck();
 	del_emptydir_prev=del_emptydir->getCheck();
 	overwrite_prev=overwrite->getCheck();
-	quit_prev=quit->getCheck();
+	exec_prev=exec->getCheck();
 #if defined(linux)
 	mount_prev=mount->getCheck();
 	show_mount_prev=show_mount->getCheck();
 #endif
+	preserve_date_warning_prev=preserve_date_warning->getCheck();
 	root_warning_prev=root_warning->getCheck();
 
     // Third tab - Programs
@@ -1822,7 +1849,7 @@ long PreferencesBox::onUpdControls(FXObject* sender,FXSelector sel,void*)
 // Set scroll wheel lines (Mathew Robertson <mathew@optushome.com.au>)
 long PreferencesBox::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
 {
-    FXuint value;
+    unsigned int value;
     sender->handle(this,FXSEL(SEL_COMMAND,ID_GETINTVALUE),(void*)&value);
     getApp()->setWheelLines(value);
 	getApp()->reg().write();
@@ -1833,7 +1860,7 @@ long PreferencesBox::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
 // Update the wheel lines button
 long PreferencesBox::onUpdWheelAdjust(FXObject* sender,FXSelector,void*)
 {
-    FXuint value=getApp()->getWheelLines();
+    unsigned int value=getApp()->getWheelLines();
 	sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&value);
     return 1;
 }
