@@ -47,7 +47,7 @@ FXDEFMAP(PermFrame) PermFrameMap[]={};
 FXIMPLEMENT(PermFrame,FXVerticalFrame,PermFrameMap,ARRAYNUMBER(PermFrameMap))
 
 PermFrame::PermFrame(FXComposite* parent,FXObject *target):
-        FXVerticalFrame(parent,FRAME_THICK|FRAME_RAISED)
+        FXVerticalFrame(parent,FRAME_RAISED)
 {
     FXHorizontalFrame *accessframe=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXHorizontalFrame *chmodframe=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -152,7 +152,7 @@ FXIMPLEMENT(PropertiesBox,DialogBox,PropertiesBoxMap,ARRAYNUMBER(PropertiesBoxMa
 // Construct window for one file
 PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
-	unsigned long long filesize;
+	FXulong filesize;
     FXString mod,changed,accessed;
 	FXString grpid, usrid;	
 	FXLabel *sizelabel=NULL;
@@ -160,8 +160,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     FXString type="", extension, fileassoc;
     FXbool isLink, isBrokenLink;
     FXString filepath, referredpath;
-    FXchar mnttype[64], used[64], avail[64], pctr[64], size[64];
-    FXchar buf[MAXPATHLEN+1];
+    char mnttype[64], used[64], avail[64], pctr[64], size[64];
+    char buf[MAXPATHLEN+1];
 	FXString hsize;
 	FILE *p;
 
@@ -190,8 +190,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 
     // First item is General
     new FXTabItem(tabbook,_("&General"),NULL);
-    FXPacker *genpack = new FXPacker(tabbook,FRAME_THICK|FRAME_RAISED);
-    FXGroupBox *generalgroup=new FXGroupBox(genpack,FXString::null,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXPacker *genpack = new FXPacker(tabbook,FRAME_RAISED);
+    FXGroupBox *generalgroup=new FXGroupBox(genpack,FXString::null,FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXVerticalFrame *generalframe=new FXVerticalFrame(generalgroup,LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Second item is Access Permissions
@@ -204,8 +204,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 
     // Third tab - file associations
     FXTabItem *fassoctab = new FXTabItem(tabbook,_("&File Associations"),NULL);
-    FXPacker *fassocpack = new FXPacker(tabbook,FRAME_THICK|FRAME_RAISED);
-    FXGroupBox *fassocgroup=new FXGroupBox(fassocpack,FXString::null,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXPacker *fassocpack = new FXPacker(tabbook,FRAME_RAISED);
+    FXGroupBox *fassocgroup=new FXGroupBox(fassocpack,FXString::null,FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXVerticalFrame *contassoc=new FXVerticalFrame(fassocgroup,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXMatrix *matrix = new FXMatrix(contassoc,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     fassoctab->disable();
@@ -229,7 +229,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	extension=file.rafter('.',1);
 	extension=extension.lower();
 	if (extension=="gz" || extension=="tgz" || extension=="tar" || extension=="taz" || extension=="bz2"
-	    || extension=="tbz2" || extension =="xz" || extension=="txz" || extension=="zip"
+	    || extension=="tbz2" || extension=="tbz" || extension =="xz" || extension=="txz" || extension=="zip"
 	    || extension=="7z" || extension=="Z" || extension=="lzh" || extension=="rar"
 	    || extension=="ace" || extension=="arj")
 	{
@@ -311,17 +311,20 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     // Initialize exec flag
     executable=FALSE;
 
+	// Read time format
+	FXString timeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
+
     // Mod time of the file / link
-	mod=FXSystem::time("%c",linfo.st_mtime);
+	mod=FXSystem::time(timeformat.text(),linfo.st_mtime);
 
     // Change time of the file / link
-	changed=FXSystem::time("%c",linfo.st_ctime);
+	changed=FXSystem::time(timeformat.text(),linfo.st_ctime);
 
     // Accessed time of the file / link
-    accessed=FXSystem::time("%c",linfo.st_atime);;
+    accessed=FXSystem::time(timeformat.text(),linfo.st_atime);;
 
     // Size of the file / link
-    filesize=(unsigned long long)linfo.st_size;
+    filesize=(FXulong)linfo.st_size;
 
     // Is it a directory?
 	isDirectory=S_ISDIR(linfo.st_mode);
@@ -596,7 +599,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		if(snexcepts != "")
 		{
 			FXString entry;
-			for(FXint i=0; ; i++)
+			for(int i=0; ; i++)
 			{
 				entry=snexcepts.section(':',i);
 				if(streq(entry.text(),""))
@@ -677,7 +680,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		
 		// Read the .trashinfo file
 		FILE *fp;
-		FXchar line[1024];
+		char line[1024];
 		FXString origpath="", delstr="";
 		long deldate=0;
 		FXbool success=TRUE;
@@ -715,7 +718,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		// Convert date
 		deldate=deltime(delstr);
 		if (deldate!=0)
-			delstr=FXSystem::time("%c",deldate);
+			delstr=FXSystem::time(timeformat.text(),deldate);
 
 		// Maybe there is no deletion information
 		if (delstr!="")
@@ -751,8 +754,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 	struct stat linfo;
 	FXString grpid, usrid;
     FXString type, extension, fileassoc;
-    FXchar buf[MAXPATHLEN+1];
-	FXint i, isDirectory, nbseldirs=0, nbselfiles=0, dotdot=0;
+    char buf[MAXPATHLEN+1];
+	int i, isDirectory, nbseldirs=0, nbselfiles=0, dotdot=0;
 	FXbool firstfile=TRUE;
 
     // Buttons
@@ -773,7 +776,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 
     // First item is General
     new FXTabItem(tabbook,_("&General"),NULL);
-    FXVerticalFrame *generalframe=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *generalframe=new FXVerticalFrame(tabbook,FRAME_RAISED);
 	FXGroupBox *attrgroup=new FXGroupBox(generalframe,_("Properties"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	FXMatrix *attrmatrix=new FXMatrix(attrgroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	new FXLabel(attrmatrix,_("Selection:"),NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
@@ -927,10 +930,10 @@ void PropertiesBox::create()
 // Dialog for single selected file
 long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 {
-	FXchar **str=NULL;
-    FXint rc=0;
+	char **str=NULL;
+    int rc=0;
 	File *f=NULL;
-	FXchar file[MAXPATHLEN];
+	char file[MAXPATHLEN];
     FXString oldfileassoc,fileassoc,op,v,e;
 
 	// Don't proceed any task on the parent directory
@@ -955,7 +958,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 				if(snexcepts != "")
 				{
 					FXString entry;
-					for(FXint i=0; ; i++)
+					for(int i=0; ; i++)
 					{
 						entry=snexcepts.section(':',i);
 						if(streq(entry.text(),""))
@@ -976,11 +979,11 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 			else
 			{
 				FXbool inlist=FALSE;
-				FXint pos=0;
+				int pos=0;
 				if(snexcepts != "")
 				{
 					FXString entry;
-					for(FXint i=0; ; i++)
+					for(int i=0; ; i++)
 					{
 						entry=snexcepts.section(':',i);
 						if(streq(entry.text(),""))
@@ -1047,9 +1050,9 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 				getApp()->reg().writeStringEntry("FILETYPES",ext->getText().text(),command.text());
 
 				// Handle file association
-				str=new FXchar*[2];
-				str[0]=new FXchar[strlen(ext->getText().text())+1];
-				str[1]=new FXchar[strlen(command.text())+1];
+				str=new char*[2];
+				str[0]=new char[strlen(ext->getText().text())+1];
+				str[1]=new char[strlen(command.text())+1];
 				strlcpy(str[0],ext->getText().text(),ext->getText().length()+1);
 				strlcpy(str[1],command.text(),command.length()+1);
 				mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC),str);
@@ -1145,7 +1148,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         // Perform chown on the selected file or directory
 		errno=0;
 		rc = f->chown((char*)targetpath.text(),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
-		FXint errcode=errno;
+		int errcode=errno;
 
 		// If action is cancelled in progress dialog
 		if (f->isCancelled())
@@ -1212,7 +1215,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		// Perform chmod on the selected file or directory
 		errno=0;
 		rc=f->chmod((char*)targetpath.text(),file,m,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
-		FXint errcode=errno;
+		int errcode=errno;
 
 		// If action is cancelled in progress dialog
 		if (f->isCancelled())
@@ -1249,9 +1252,9 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 // Dialog for multiple selected files
 long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 {
-    FXint rc=0, i;
+    int rc=0, i;
 	File *f=NULL;
-	FXchar file[MAXPATHLEN];
+	char file[MAXPATHLEN];
 
     DialogBox::onCmdAccept(o,s,p);
 
@@ -1289,7 +1292,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 		errno=0;
 		if (files[i]!="..")
 			rc = f->chown((char*)pathname.text(),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
-		FXint errcode=errno;
+		int errcode=errno;
 		
 		// If action is cancelled in progress dialog
 		if (f->isCancelled())
@@ -1361,7 +1364,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 			{
 				errno=0;
 				rc=f->chmod((char*)pathname.text(),file,m,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
-				FXint errcode=errno;
+				int errcode=errno;
 				
 				// If action is cancelled in progress dialog
 				if (f->isCancelled())
@@ -1426,7 +1429,7 @@ long PropertiesBox::onCmdFilter(FXObject* o,FXSelector s,void* p)
 
 long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 {
-    FXint xmode=0;
+    int xmode=0;
 	switch (FXSELID(s))
 	{
 		case PropertiesBox::ID_RUSR:
@@ -1480,7 +1483,7 @@ long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 {
     FileDialog browseProgram(this,_("Select an executable file"));
-    const FXchar *patterns[]=
+    const char *patterns[]=
         {
             _("All files"),     "*",NULL
         };
@@ -1517,7 +1520,7 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
         icon= miniic->getText();
 
 	FXString iconpath=getApp()->reg().readStringEntry("SETTINGS","iconpath",DEFAULTICONPATH);
-    const FXchar *patterns[]=
+    const char *patterns[]=
         {
             _("PNG Images"),     "*.png",
 			_("GIF Images"),     "*.gif",
@@ -1549,8 +1552,8 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 	{
 		getApp()->beginWaitCursor();
 
-		FXchar buf[MAXPATHLEN+1];
-		FXchar size[64];
+		char buf[MAXPATHLEN+1];
+		char size[64];
 		FXString hsize;
 
 		// Single file
@@ -1559,8 +1562,8 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 			// Directory but not mount point
 			if (isDirectory && !isMountpoint)
 			{
-				unsigned long long dirsize;
-				FXuint nbfiles=0, nbsubfolders=0;
+				FXulong dirsize;
+				unsigned int nbfiles=0, nbsubfolders=0;
 
 				FXString dirpath=FXPath::absolute(parentdir,filename);
 				strlcpy(buf,dirpath.text(),dirpath.length()+1);
@@ -1577,13 +1580,13 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 		// Multiple files
 		else
 		{
-			unsigned long long filesize, dirsize, totalsize=0;
-			FXuint totalnbfiles=0, totalnbsubfolders=0;
+			FXulong filesize, dirsize, totalsize=0;
+			unsigned int totalnbfiles=0, totalnbsubfolders=0;
 			struct stat info;
-			FXint dotdot=0;
+			int dotdot=0;
 
 			// Total size and files type
-			for (FXint i=0;i<num;i++)
+			for (int i=0;i<num;i++)
 			{
 				if(lstatrep(files[i].text(),&info)!=0)
 					continue ;
@@ -1602,7 +1605,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 					// Recursive size
 					FXString dirpath=FXPath::absolute(parentdir,files[i]);
 					strlcpy(buf,dirpath.text(),dirpath.length()+1);
-					FXuint nbfiles=0, nbsubfolders=0;
+					unsigned int nbfiles=0, nbsubfolders=0;
 					dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
 					totalsize+=dirsize;
 					totalnbfiles+=(nbfiles-nbsubfolders);
@@ -1611,7 +1614,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 				else // Regular file
 				{
 					// File size	
-					filesize=(unsigned long long)info.st_size;
+					filesize=(FXulong)info.st_size;
 					totalsize+=filesize;
 					totalnbfiles++;
 				}
