@@ -32,8 +32,8 @@ private:
 	FXRadioButton*	fileonly;
 	FXRadioButton*	all;
 	FXRadioButton*	add;
-	FXint			cmd;
-	FXint			flt;
+	int			cmd;
+	int			flt;
     FXCheckButton*	rec;
     FXCheckButton*	own;
 	FXComboBox*		user;
@@ -70,7 +70,7 @@ private:
     FXString	edit_prev;
     FXString	bigic_prev;
     FXString	miniic_prev;
-    FXint 		num;
+    int 		num;
 	FXString		trashfileslocation;
 	FXString		trashinfolocation;
     FXCheckButton*    ur;
