@@ -56,11 +56,11 @@ FXIMPLEMENT(TextLabel,FXFrame,TextLabelMap,ARRAYNUMBER(TextLabelMap))
 
 
 // Delimiters
-const FXchar TextLabel::textDelimiters[]="~.,/\\`'!@#$%^&*()-=+{}|[]\":;<>?";
+const char TextLabel::textDelimiters[]="~.,/\\`'!@#$%^&*()-=+{}|[]\":;<>?";
 
 
 // Construct and init
-TextLabel::TextLabel(FXComposite* p,FXint ncols,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb):
+TextLabel::TextLabel(FXComposite* p,int ncols,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h,int pl,int pr,int pt,int pb):
         FXFrame(p,opts,x,y,w,h,pl,pr,pt,pb)
 {
     if (ncols<0)
@@ -143,14 +143,14 @@ void TextLabel::disable()
 
 
 // Get default width
-FXint TextLabel::getDefaultWidth()
+int TextLabel::getDefaultWidth()
 {
     return padleft+padright+(border<<1)+columns*font->getTextWidth("8",1);
 }
 
 
 // Get default height
-FXint TextLabel::getDefaultHeight()
+int TextLabel::getDefaultHeight()
 {
     return padtop+padbottom+(border<<1)+font->getFontHeight();
 }
@@ -199,8 +199,8 @@ long TextLabel::onSelectionRequest(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXEvent *event=(FXEvent*)ptr;
     FXString string;
-    FXuint   start;
-    FXuint   len;
+    unsigned int   start;
+    unsigned int   len;
 
     // Make sure
     FXASSERT(0<=anchor && anchor<=contents.length());
@@ -454,7 +454,7 @@ long TextLabel::onLeftBtnRelease(FXObject*,FXSelector,void* ptr)
 long TextLabel::onMotion(FXObject*,FXSelector,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    FXint t;
+    int t;
     if (flags&FLAG_PRESSED)
     {
         if (event->win_x<(border+padleft) || (width-border-padright)<event->win_x)
@@ -484,11 +484,11 @@ long TextLabel::onAutoScroll(FXObject*,FXSelector,void* ptr)
     register FXEvent* event=(FXEvent*)ptr;
     if (flags&FLAG_PRESSED)
     {
-        register FXint newcursor=cursor;
-        register FXint ll=border+padleft;
-        register FXint rr=width-border-padright;
-        register FXint ww=rr-ll;
-        register FXint tw;
+        register int newcursor=cursor;
+        register int ll=border+padleft;
+        register int rr=width-border-padright;
+        register int ww=rr-ll;
+        register int tw;
 
         if (options&TEXTFIELD_PASSWD)
             tw=font->getTextWidth("*",1)*contents.count();
@@ -620,7 +620,7 @@ long TextLabel::onUpdSelectAll(FXObject* sender,FXSelector,void* ptr)
 
 
 // Move the cursor to new valid position
-void TextLabel::setCursorPos(FXint pos)
+void TextLabel::setCursorPos(int pos)
 {
     pos=contents.validate(FXCLAMP(0,pos,contents.length()));
     if (cursor!=pos)
@@ -629,7 +629,7 @@ void TextLabel::setCursorPos(FXint pos)
 
 
 // Set anchor position to valid position
-void TextLabel::setAnchorPos(FXint pos)
+void TextLabel::setAnchorPos(int pos)
 {
     anchor=contents.validate(FXCLAMP(0,pos,contents.length()));
 }
@@ -639,10 +639,10 @@ void TextLabel::setAnchorPos(FXint pos)
 // Fix scroll amount after text changes or widget resize
 void TextLabel::layout()
 {
-    register FXint rr=width-border-padright;
-    register FXint ll=border+padleft;
-    register FXint ww=rr-ll;
-    register FXint tw;
+    register int rr=width-border-padright;
+    register int ll=border+padleft;
+    register int ww=rr-ll;
+    register int tw;
     if (!xid)
     	return;
 
@@ -692,13 +692,13 @@ void TextLabel::layout()
 
 
 // Force position to become fully visible; we assume layout is correct
-void TextLabel::makePositionVisible(FXint pos)
+void TextLabel::makePositionVisible(int pos)
 {
-    register FXint rr=width-border-padright;
-    register FXint ll=border+padleft;
-    register FXint ww=rr-ll;
-    register FXint oldshift=shift;
-    register FXint xx;
+    register int rr=width-border-padright;
+    register int ll=border+padleft;
+    register int ww=rr-ll;
+    register int oldshift=shift;
+    register int xx;
     if (!xid)
     	return;
     pos=contents.validate(FXCLAMP(0,pos,contents.length()));
@@ -741,12 +741,12 @@ void TextLabel::makePositionVisible(FXint pos)
 
 
 // Find index from coord
-FXint TextLabel::index(FXint x) const
+int TextLabel::index(int x) const
 {
-    register FXint rr=width-border-padright;
-    register FXint ll=border+padleft;
-    register FXint mm=(ll+rr)/2;
-    register FXint pos,xx,cw;
+    register int rr=width-border-padright;
+    register int ll=border+padleft;
+    register int mm=(ll+rr)/2;
+    register int pos,xx,cw;
     if (options&TEXTFIELD_PASSWD)
     {
         cw=font->getTextWidth("*",1);
@@ -785,12 +785,12 @@ FXint TextLabel::index(FXint x) const
 
 
 // Find coordinate from index
-FXint TextLabel::coord(FXint i) const
+int TextLabel::coord(int i) const
 {
-    register FXint rr=width-border-padright;
-    register FXint ll=border+padleft;
-    register FXint mm=(ll+rr)/2;
-    register FXint pos;
+    register int rr=width-border-padright;
+    register int ll=border+padleft;
+    register int mm=(ll+rr)/2;
+    register int pos;
     FXASSERT(0<=i && i<=contents.length());
     if (options&JUSTIFY_RIGHT)
     {
@@ -818,11 +818,11 @@ FXint TextLabel::coord(FXint i) const
 
 
 // Return TRUE if position is visible
-FXbool TextLabel::isPosVisible(FXint pos) const
+FXbool TextLabel::isPosVisible(int pos) const
 {
     if (0<=pos && pos<=contents.length())
     {
-        register FXint x=coord(contents.validate(pos));
+        register int x=coord(contents.validate(pos));
         return border+padleft<=x && x<=width-border-padright;
     }
     return FALSE;
@@ -830,14 +830,14 @@ FXbool TextLabel::isPosVisible(FXint pos) const
 
 
 // Return TRUE if position pos is selected
-FXbool TextLabel::isPosSelected(FXint pos) const
+FXbool TextLabel::isPosSelected(int pos) const
 {
     return hasSelection() && FXMIN(anchor,cursor)<=pos && pos<=FXMAX(anchor,cursor);
 }
 
 
 // Draw text fragment
-void TextLabel::drawTextFragment(FXDCWindow& dc,FXint x,FXint y,FXint fm,FXint to)
+void TextLabel::drawTextFragment(FXDCWindow& dc,int x,int y,int fm,int to)
 {
     x+=font->getTextWidth(contents.text(),fm);
     y+=font->getFontAscent();
@@ -847,12 +847,12 @@ void TextLabel::drawTextFragment(FXDCWindow& dc,FXint x,FXint y,FXint fm,FXint t
 
 
 // Draw range of text
-void TextLabel::drawTextRange(FXDCWindow& dc,FXint fm,FXint to)
+void TextLabel::drawTextRange(FXDCWindow& dc,int fm,int to)
 {
-    register FXint sx,ex,xx,yy,cw,hh,ww,si,ei,lx,rx,t;
-    register FXint rr=width-border-padright;
-    register FXint ll=border+padleft;
-    register FXint mm=(ll+rr)/2;
+    register int sx,ex,xx,yy,cw,hh,ww,si,ei,lx,rx,t;
+    register int rr=width-border-padright;
+    register int ll=border+padleft;
+    register int mm=(ll+rr)/2;
 
     if (to<=fm)
     	return;
@@ -1033,16 +1033,16 @@ long TextLabel::onCmdCursorLeft(FXObject*,FXSelector,void*)
 
 
 // Check if w is delimiter
-static FXbool isdelimiter(const FXchar *delimiters,FXwchar w)
+static FXbool isdelimiter(const char *delimiters,FXwchar w)
 {
     return w<256 && strchr(delimiters,w); // FIXME for w>256
 }
 
 
 // Find end of previous word
-FXint TextLabel::leftWord(FXint pos) const
+int TextLabel::leftWord(int pos) const
 {
-    register FXint pp=pos,p;
+    register int pp=pos,p;
 
     // Ensure input is valid
     FXASSERT(0<=pos && pos<=contents.length());
@@ -1062,9 +1062,9 @@ FXint TextLabel::leftWord(FXint pos) const
 
 
 // Find begin of next word
-FXint TextLabel::rightWord(FXint pos) const
+int TextLabel::rightWord(int pos) const
 {
-    register FXint pp=pos;
+    register int pp=pos;
 
     // Ensure input is valid
     FXASSERT(0<=pos && pos<=contents.length());
@@ -1084,9 +1084,9 @@ FXint TextLabel::rightWord(FXint pos) const
 
 
 // Find begin of a word
-FXint TextLabel::wordStart(FXint pos) const
+int TextLabel::wordStart(int pos) const
 {
-    register FXint p;
+    register int p;
     FXASSERT(0<=pos && pos<=contents.length());
     if (pos==contents.length() || Unicode::isSpace(contents.wc(pos)))
     {
@@ -1105,7 +1105,7 @@ FXint TextLabel::wordStart(FXint pos) const
 
 
 // Find end of word
-FXint TextLabel::wordEnd(FXint pos) const
+int TextLabel::wordEnd(int pos) const
 {
     FXASSERT(0<=pos && pos<=contents.length());
     if (pos==contents.length() || Unicode::isSpace(contents.wc(pos)))
@@ -1284,7 +1284,7 @@ long TextLabel::onKeyPress(FXObject*,FXSelector,void* ptr)
             return 1;
         default:
 ins:
-            if ((event->state&(CONTROLMASK|ALTMASK)) || ((FXuchar)event->text[0]<32))
+            if ((event->state&(CONTROLMASK|ALTMASK)) || ((unsigned char)event->text[0]<32))
             	return 0;
             return 1;
         }
@@ -1328,7 +1328,7 @@ long TextLabel::onKeyRelease(FXObject*,FXSelector,void* ptr)
             if (event->state&CONTROLMASK)
             	return 1;
         default:
-            if ((event->state&(CONTROLMASK|ALTMASK)) || ((FXuchar)event->text[0]<32))
+            if ((event->state&(CONTROLMASK|ALTMASK)) || ((unsigned char)event->text[0]<32))
             	return 0;
             return 1;
         }
@@ -1361,7 +1361,7 @@ FXbool TextLabel::selectAll()
 
 
 // Set selection
-FXbool TextLabel::setSelection(FXint pos,FXint len)
+FXbool TextLabel::setSelection(int pos,int len)
 {
     setAnchorPos(pos);
     setCursorPos(pos+len);
@@ -1371,7 +1371,7 @@ FXbool TextLabel::setSelection(FXint pos,FXint len)
 
 
 // Extend selection
-FXbool TextLabel::extendSelection(FXint pos)
+FXbool TextLabel::extendSelection(int pos)
 {
 	// Don't select text if ncols=0
 	if (columns==0)
@@ -1465,7 +1465,7 @@ void TextLabel::setCursorColor(FXColor clr)
 
 
 // Change number of columns
-void TextLabel::setNumColumns(FXint ncols)
+void TextLabel::setNumColumns(int ncols)
 {
     if (ncols<0)
     	ncols=0;
@@ -1481,9 +1481,9 @@ void TextLabel::setNumColumns(FXint ncols)
 
 
 // Set text justify style
-void TextLabel::setJustify(FXuint style)
+void TextLabel::setJustify(unsigned int style)
 {
-    FXuint opts=(options&~JUSTIFY_MASK) | (style&JUSTIFY_MASK);
+    unsigned int opts=(options&~JUSTIFY_MASK) | (style&JUSTIFY_MASK);
     if (options!=opts)
     {
         shift=0;
@@ -1495,7 +1495,7 @@ void TextLabel::setJustify(FXuint style)
 
 
 // Get text justify style
-FXuint TextLabel::getJustify() const
+unsigned int TextLabel::getJustify() const
 {
     return (options&JUSTIFY_MASK);
 }
