@@ -113,7 +113,7 @@ ViewWindow::ViewWindow(XFileView* a,const FXString& file):FXMainWindow(a,"XFileV
     new FXMenuTitle(menubar,_("&Help"),NULL,helpmenu);
 
 	// Make contents
-    contents=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_NONE,0,0,0,0, 0,0,0,0, 0,0);
+    contents=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_RAISED,0,0,0,0, 0,0,0,0, 0,0);
 
     // Make viewer window
     viewer=new FXText(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -148,6 +148,7 @@ ViewWindow::ViewWindow(XFileView* a,const FXString& file):FXMainWindow(a,"XFileV
 	// Toolbar button: Quit
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","quit","Ctrl-Q");
     new FXButton(toolbar,TAB+_("Quit")+PARS(key)+TAB+_("Quit Xfv.")+PARS(key),quiticon,this,ID_QUIT,style|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+	getAccelTable()->addAccel(KEY_Escape,this,FXSEL(SEL_COMMAND,ID_QUIT));
 
 	// Toolbar button: Copy
     new FXSeparator(toolbar,SEPARATOR_GROOVE);
@@ -225,8 +226,8 @@ ViewWindow::ViewWindow(XFileView* a,const FXString& file):FXMainWindow(a,"XFileV
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
 
     // Preferences menu
-    new FXMenuCheck(prefsmenu,_("&Toolbar")+TAB2+_("Display or hide toolbar."),toolbar,FXWindow::ID_TOGGLESHOWN);
-    new FXMenuCheck(prefsmenu,_("&Status bar")+TAB2+_("Display or hide status bar."),statusbar,FXWindow::ID_TOGGLESHOWN);
+    new FXMenuCheck(prefsmenu,_("&Toolbar")+TAB2+_("Display toolbar."),toolbar,FXWindow::ID_TOGGLESHOWN);
+    new FXMenuCheck(prefsmenu,_("&Status bar")+TAB2+_("Display status bar."),statusbar,FXWindow::ID_TOGGLESHOWN);
     new FXMenuCommand(prefsmenu,_("&Font...")+TAB2+_("Change text font."),fontsicon,this,ID_FONT);
 
     // Window menu
@@ -357,8 +358,8 @@ void ViewWindow::create()
 	// Get position and position window    
     if (save_win_pos && fromreg)
 	{
-		FXint xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
-		FXint ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
+		int xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+		int ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 		position(xpos,ypos,ww,hh);
 	}
 	else
@@ -440,7 +441,7 @@ FXbool ViewWindow::loadFile(const FXString& file)
     // Set wait cursor
     getApp()->beginWaitCursor();
 
-    FXMALLOC(&text,FXchar,info.st_size+1);
+    FXMALLOC(&text,char,info.st_size+1);
     n=fread(text,1,info.st_size,fp);
     if(n!=info.st_size)
     {
@@ -470,7 +471,7 @@ FXbool ViewWindow::loadFile(const FXString& file)
 // Open
 long ViewWindow::onCmdOpen(FXObject*,FXSelector,void*)
 {
-    const FXchar *patterns[]=
+    const char *patterns[]=
         {
             _("All Files"),          "*",
             _("Text Files"),         "*.txt",
@@ -492,7 +493,7 @@ long ViewWindow::onCmdOpen(FXObject*,FXSelector,void*)
     if(opendialog.execute())
     {
         FXString* files=opendialog.getFilenames();
-		FXuint i=0;
+		unsigned int i=0;
 		while (files[i]!=FXString::null)
 		{
 			ViewWindow *window=findWindow(files[i]);
@@ -609,8 +610,8 @@ void ViewWindow::saveConfig()
     FXString fontspec;
 
 	// Write new window size and position back to registry
-    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
-    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(unsigned int)getWidth());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(unsigned int)getHeight());
 
 	if (save_win_pos)
 	{
@@ -696,7 +697,7 @@ long ViewWindow::onUpdMenu(FXObject* sender,FXSelector,void*)
 // Open find dialog
 long ViewWindow::onCmdFind(FXObject* obj,FXSelector sel,void* ptr)
 {
-    FXint loc;
+    int loc;
 
     if(FXSELTYPE(sel)==SEL_UPDATE)
     {
@@ -742,7 +743,7 @@ long ViewWindow::onCmdFind(FXObject* obj,FXSelector sel,void* ptr)
 
 
 // Find string
-FXint ViewWindow::find(const FXString str,FXint pos)
+int ViewWindow::find(const FXString str,int pos)
 {
     FXString buf=viewer->getText();
     const char* text=buf.text();
@@ -766,7 +767,7 @@ FXbool ViewWindow::close(FXbool notify)
 // User clicks on one of the window menus
 long ViewWindow::onCmdWindow(FXObject*,FXSelector sel,void*)
 {
-    FXint which=FXSELID(sel)-ID_WINDOW_1;
+    int which=FXSELID(sel)-ID_WINDOW_1;
     if(which<getApp()->windowlist.no())
     {
 		getApp()->windowlist[which]->raise();
@@ -779,7 +780,7 @@ long ViewWindow::onCmdWindow(FXObject*,FXSelector sel,void*)
 // Update handler for window menus
 long ViewWindow::onUpdWindow(FXObject *sender,FXSelector sel,void*)
 {
-    FXint which=FXSELID(sel)-ID_WINDOW_1;
+    int which=FXSELID(sel)-ID_WINDOW_1;
 
     if(which<getApp()->windowlist.no())
     {
@@ -808,7 +809,7 @@ long ViewWindow::onUpdWindow(FXObject *sender,FXSelector sel,void*)
 FXString ViewWindow::unique() const
 {
     FXString name=_("untitled");
-    for(FXint i=1; i<2147483647; i++)
+    for(int i=1; i<2147483647; i++)
     {
         if(!findWindow(name))
         	break;
@@ -821,7 +822,7 @@ FXString ViewWindow::unique() const
 // Find an as yet untitled, unedited window
 ViewWindow *ViewWindow::findUnused() const
 {
-    for(FXint w=0; w<getApp()->windowlist.no(); w++)
+    for(int w=0; w<getApp()->windowlist.no(); w++)
     {
 		if(!getApp()->windowlist[w]->isFilenameSet())
             return getApp()->windowlist[w];
@@ -833,7 +834,7 @@ ViewWindow *ViewWindow::findUnused() const
 // Find window, if any, currently editing the given file
 ViewWindow *ViewWindow::findWindow(const FXString& file) const
 {
-    for(FXint w=0; w<getApp()->windowlist.no(); w++)
+    for(int w=0; w<getApp()->windowlist.no(); w++)
     {
         if(getApp()->windowlist[w]->getFilename()==file)
 			return getApp()->windowlist[w];
