@@ -37,7 +37,7 @@ FXbool save_win_pos;
 FXIMPLEMENT_ABSTRACT(FXTextCommand,FXCommand,NULL,0)
 
 // Return size of record plus any data kept here
-FXuint FXTextCommand::size() const
+unsigned int FXTextCommand::size() const
 {
     return sizeof(FXTextCommand)+ndel;
 }
@@ -46,9 +46,9 @@ FXuint FXTextCommand::size() const
 FXIMPLEMENT_ABSTRACT(FXTextInsert,FXTextCommand,NULL,0)
 
 // Insert command
-FXTextInsert::FXTextInsert(FXText* txt,FXint p,FXint ni,const FXchar* ins):FXTextCommand(txt,p,0,ni)
+FXTextInsert::FXTextInsert(FXText* txt,int p,int ni,const char* ins):FXTextCommand(txt,p,0,ni)
 {
-    FXMALLOC(&buffer,FXchar,ni);
+    FXMALLOC(&buffer,char,ni);
     memcpy(buffer,ins,ni);
 }
 
@@ -74,9 +74,9 @@ void FXTextInsert::redo()
 FXIMPLEMENT_ABSTRACT(FXTextDelete,FXTextCommand,NULL,0)
 
 // Delete command
-FXTextDelete::FXTextDelete(FXText* txt,FXint p,FXint nd,const FXchar* del):FXTextCommand(txt,p,nd,0)
+FXTextDelete::FXTextDelete(FXText* txt,int p,int nd,const char* del):FXTextCommand(txt,p,nd,0)
 {
-    FXMALLOC(&buffer,FXchar,nd);
+    FXMALLOC(&buffer,char,nd);
     memcpy(buffer,del,nd);
 }
 
@@ -102,9 +102,9 @@ void FXTextDelete::redo()
 FXIMPLEMENT_ABSTRACT(FXTextReplace,FXTextCommand,NULL,0)
 
 // Replace command
-FXTextReplace::FXTextReplace(FXText* txt,FXint p,FXint nd,FXint ni,const FXchar* del,const FXchar* ins):FXTextCommand(txt,p,nd,ni)
+FXTextReplace::FXTextReplace(FXText* txt,int p,int nd,int ni,const char* del,const char* ins):FXTextCommand(txt,p,nd,ni)
 {
-    FXMALLOC(&buffer,FXchar,nd+ni);
+    FXMALLOC(&buffer,char,nd+ni);
     memcpy(buffer,del,nd);
     memcpy(buffer+nd,ins,ni);
 }
@@ -196,28 +196,28 @@ Preferences::Preferences(WriteWindow *owner):DialogBox(owner,_("XFileWrite Prefe
 
     // First tab - Editor
     new FXTabItem(tabbook,_("&Editor"),NULL);
-    FXVerticalFrame *editor=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *editor=new FXVerticalFrame(tabbook,FRAME_RAISED);
     FXGroupBox *group=new FXGroupBox(editor,_("Text"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
     FXMatrix *matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     
 	new FXLabel(matrix,_("Wrap margin:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     wrapmargin = new FXTextField(matrix,10,NULL,0,TEXTFIELD_INTEGER|JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
-    FXint wrapcols=getApp()->reg().readIntEntry("OPTIONS","wrapcols",80);
+    int wrapcols=getApp()->reg().readIntEntry("OPTIONS","wrapcols",80);
 	wrapmargin->setText(FXStringVal(wrapcols));
 	
 	new FXLabel(matrix,_("Tabulation size:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     tabsize = new FXTextField(matrix,10,NULL,0,TEXTFIELD_INTEGER|JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
-    FXint tabcols=getApp()->reg().readIntEntry("OPTIONS","tabcols",80);
+    int tabcols=getApp()->reg().readIntEntry("OPTIONS","tabcols",80);
 	tabsize->setText(FXStringVal(tabcols));
 
     new FXLabel(matrix,_("Strip carriage returns:")+(FXString)"                ",NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     stripcr = new FXCheckButton(matrix,FXString::null,NULL,0,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW,0,0,0,0, 0,0,0,0);
-    FXint stripreturn=getApp()->reg().readIntEntry("OPTIONS","stripreturn",FALSE);
+    int stripreturn=getApp()->reg().readIntEntry("OPTIONS","stripreturn",FALSE);
 	stripcr->setCheck(stripreturn);
 
     // Second tab - Colors
     new FXTabItem(tabbook,_("&Colors"),NULL);
-    FXVerticalFrame *colors=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    FXVerticalFrame *colors=new FXVerticalFrame(tabbook,FRAME_RAISED);
     group=new FXGroupBox(colors,_("Text"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
     FXMatrix *matrix1 = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     group=new FXGroupBox(colors,_("Lines"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
@@ -304,7 +304,7 @@ long Preferences::onCmdCancel(FXObject* o,FXSelector s,void* p)
 
 
 // Execute dialog box modally
-FXuint Preferences::execute(FXuint placement)
+unsigned int Preferences::execute(unsigned int placement)
 {
 	// Save current preferences to restore them if cancel is pressed
 	
@@ -586,7 +586,7 @@ WriteWindow::WriteWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFi
     new FXMenuTitle(menubar,_("&Help"),NULL,helpmenu,LAYOUT_LEFT);
 
     // Make editor window
-    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
+    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
     editor=new FXText(textbox,this,ID_TEXT,LAYOUT_FILL_X|LAYOUT_FILL_Y|TEXT_SHOWACTIVE);
     editor->setHiliteMatchTime(2000);
     editor->setTextStyle(editor->getTextStyle()|TEXT_FIXEDWRAP);
@@ -1024,8 +1024,8 @@ FXbool WriteWindow::isModified() const
 FXbool WriteWindow::loadFile(const FXString& file)
 {
     FXFile textfile(file,FXFile::Reading);
-    FXint size,n,i,j,c;
-    FXchar *text;
+    int size,n,i,j,c;
+    char *text;
 
     // Opened file?
     if(!textfile.isOpen())
@@ -1038,7 +1038,7 @@ FXbool WriteWindow::loadFile(const FXString& file)
     size=textfile.size();
 
     // Make buffer to load file
-    if(!FXMALLOC(&text,FXchar,size))
+    if(!FXMALLOC(&text,char,size))
     {
         MessageBox::error(this,BOX_OK,_("Error Loading File"),_("File is too big: %s (%d bytes)"),file.text(),size);
         return FALSE;
@@ -1076,8 +1076,8 @@ FXbool WriteWindow::loadFile(const FXString& file)
     // Lines numbering
     if (linesnum)
     {
-        FXuint size=editor->getNumRows();
-        FXuint cols=(FXuint)ceil(log10(size));
+        unsigned int size=editor->getNumRows();
+        unsigned int cols=(unsigned int)ceil(log10(size));
         editor->setBarColumns(cols);
     }
     else
@@ -1107,8 +1107,8 @@ FXbool WriteWindow::loadFile(const FXString& file)
 FXbool WriteWindow::saveFile(const FXString& file)
 {
     FXFile textfile(file,FXFile::Writing);
-    FXint size,n;
-    FXchar *text;
+    int size,n;
+    char *text;
 
     // Opened file?
     if(!textfile.isOpen())
@@ -1121,7 +1121,7 @@ FXbool WriteWindow::saveFile(const FXString& file)
     size=editor->getLength();
 
     // Alloc buffer
-    if(!FXMALLOC(&text,FXchar,size+1))
+    if(!FXMALLOC(&text,char,size+1))
     {
         MessageBox::error(this,BOX_OK,_("Error Saving File"),_("File is too big: %s"),file.text());
         return FALSE;
@@ -1162,7 +1162,7 @@ FXbool WriteWindow::saveFile(const FXString& file)
 FXString WriteWindow::unique() const
 {
     FXString name=_("untitled");
-    for(FXint i=1; i<2147483647; i++)
+    for(int i=1; i<2147483647; i++)
     {
         if(!findWindow(name))
         	break;
@@ -1175,7 +1175,7 @@ FXString WriteWindow::unique() const
 // Find an as yet untitled, unedited window
 WriteWindow *WriteWindow::findUnused() const
 {
-    for(FXint w=0; w<getApp()->windowlist.no(); w++)
+    for(int w=0; w<getApp()->windowlist.no(); w++)
     {
         if(!getApp()->windowlist[w]->isFilenameSet() && !getApp()->windowlist[w]->isModified())
             return getApp()->windowlist[w];
@@ -1187,7 +1187,7 @@ WriteWindow *WriteWindow::findUnused() const
 // Find window, if any, currently editing the given file
 WriteWindow *WriteWindow::findWindow(const FXString& file) const
 {
-    for(FXint w=0; w<getApp()->windowlist.no(); w++)
+    for(int w=0; w<getApp()->windowlist.no(); w++)
     {
         if(getApp()->windowlist[w]->getFilename()==file)
             return getApp()->windowlist[w];
@@ -1197,9 +1197,9 @@ WriteWindow *WriteWindow::findWindow(const FXString& file) const
 
 
 // Visit given line
-void WriteWindow::visitLine(FXint line)
+void WriteWindow::visitLine(int line)
 {
-    FXint pos=editor->nextLine(0,line-1);
+    int pos=editor->nextLine(0,line-1);
     editor->setCursorPos(pos);
     editor->setCenterLine(pos);
 }
@@ -1210,8 +1210,8 @@ void WriteWindow::loadConfig()
 {
     FXColor textback,textfore,textselback,textselfore,textcursor,texthilitefore,texthiliteback;
     FXColor textbar,textnumber;
-    FXint wrapping,wrapcols,tabcols;
-    FXint hidestatus,hidetoolbar,hilitematchtime;
+    int wrapping,wrapcols,tabcols;
+    int hidestatus,hidetoolbar,hilitematchtime;
     FXString fontspec;
 
     // Text colors
@@ -1306,8 +1306,8 @@ void WriteWindow::loadConfig()
 	// Get position and position window
     if (save_win_pos && fromreg)
 	{
-		FXint xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
-		FXint ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
+		int xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+		int ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 		position(xpos,ypos,ww,hh);
 	}
 	else
@@ -1452,7 +1452,7 @@ long WriteWindow::onCmdNew(FXObject*,FXSelector,void*)
 // Open
 long WriteWindow::onCmdOpen(FXObject*,FXSelector,void*)
 {
-    const FXchar *patterns[]=
+    const char *patterns[]=
         {
             _("All Files"),          "*",
             _("Text Files"),         "*.txt",
@@ -1473,7 +1473,7 @@ long WriteWindow::onCmdOpen(FXObject*,FXSelector,void*)
     if(opendialog.execute())
     {
         FXString* files=opendialog.getFilenames();
-        FXuint i=0;
+        unsigned int i=0;
         while (files[i]!=FXString::null)
         {
             WriteWindow *window=findWindow(files[i]);
@@ -1539,9 +1539,9 @@ long WriteWindow::onCmdOpenRecent(FXObject*,FXSelector,void* ptr)
 // See if we can get it as a filename
 long WriteWindow::onEditDNDDrop(FXObject*,FXSelector,void*)
 {
-    FXchar *data;
-    FXuint len;
-    if(getDNDData(FROM_DRAGNDROP,urilistType,(FXuchar*&)data,len))
+    char *data;
+    unsigned int len;
+    if(getDNDData(FROM_DRAGNDROP,urilistType,(unsigned char*&)data,len))
     {
         FXString urilist(data,len);
         FXString file=FXURL::fileFromURL(urilist.before('\r'));
@@ -1572,7 +1572,7 @@ long WriteWindow::onEditDNDMotion(FXObject*,FXSelector,void*)
 // Save changes, prompt for new filename
 FXbool WriteWindow::saveChanges()
 {
-    FXuint answer;
+    unsigned int answer;
     FXString file;
     if(isModified())
     {
@@ -1659,7 +1659,7 @@ FXbool WriteWindow::close(FXbool notify)
 // User clicks on one of the window menus
 long WriteWindow::onCmdWindow(FXObject*,FXSelector sel,void*)
 {
-    FXint which=FXSELID(sel)-ID_WINDOW_1;
+    int which=FXSELID(sel)-ID_WINDOW_1;
     if(which<getApp()->windowlist.no())
     {
         getApp()->windowlist[which]->raise();
@@ -1672,7 +1672,7 @@ long WriteWindow::onCmdWindow(FXObject*,FXSelector sel,void*)
 // Update handler for window menus
 long WriteWindow::onUpdWindow(FXObject *sender,FXSelector sel,void*)
 {
-    FXint which=FXSELID(sel)-ID_WINDOW_1;
+    int which=FXSELID(sel)-ID_WINDOW_1;
     if(which<getApp()->windowlist.no())
     {
         WriteWindow *window=getApp()->windowlist[which];
@@ -1767,8 +1767,8 @@ long WriteWindow::onCmdLinesNum(FXObject*,FXSelector,void*)
     linesnum=!linesnum;
     if (linesnum)
     {
-        FXuint size=editor->getNumRows();
-        FXuint cols=(FXuint)ceil(log10(size));
+        unsigned int size=editor->getNumRows();
+        unsigned int cols=(unsigned int)ceil(log10(size));
         editor->setBarColumns(cols);
     }
     else
@@ -1801,7 +1801,7 @@ long WriteWindow::onUpdOverstrike(FXObject* sender,FXSelector,void*)
 // Update box for size display
 long WriteWindow::onUpdNumRows(FXObject* sender,FXSelector,void*)
 {
-    FXuint size=editor->getNumRows();
+    unsigned int size=editor->getNumRows();
     sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&size);
     return 1;
 }
@@ -1889,8 +1889,8 @@ long WriteWindow::onFocusIn(FXObject* sender,FXSelector sel,void* ptr)
             filetime=t;
             if(BOX_CLICKED_OK==MessageBox::warning(this,BOX_OK_CANCEL,_("File Was Changed"),_("%s\nwas changed by another program. Reload this file from disk?"),filename.text()))
             {
-                FXint top=editor->getTopLine();
-                FXint pos=editor->getCursorPos();
+                int top=editor->getTopLine();
+                int pos=editor->getCursorPos();
                 loadFile(filename);
                 editor->setTopLine(top);
                 editor->setCursorPos(pos);
@@ -1906,12 +1906,12 @@ long WriteWindow::onCmdSearch(FXObject*,FXSelector,void*)
 {
     if (searchdialog==NULL)
         searchdialog=new FXSearchDialog(this,_("Search"),searchicon);
-    FXint beg[10];
-    FXint end[10];
-    FXint pos;
-    FXuint code;
+    int beg[10];
+    int end[10];
+    int pos;
+    unsigned int code;
     FXString searchstring;
-    FXuint searchflags;
+    unsigned int searchflags;
     do
     {
         code=searchdialog->execute();
@@ -1942,16 +1942,16 @@ long WriteWindow::onCmdSearch(FXObject*,FXSelector,void*)
 long WriteWindow::onCmdReplace(FXObject*,FXSelector,void*)
 {
     replacedialog=new FXReplaceDialog(this,_("Replace"),replaceicon);
-    FXint beg[10],end[10],fm,to,len,pos;
-    FXuint searchflags,code;
+    int beg[10],end[10],fm,to,len,pos;
+    unsigned int searchflags,code;
     FXString searchstring;
     FXString replacestring;
     FXString replacevalue;
 
     // Get text into buffer
-    FXchar* buffer;
-    FXint length=editor->getLength();
-    FXMALLOC(&buffer,FXchar,length);
+    char* buffer;
+    int length=editor->getLength();
+    FXMALLOC(&buffer,char,length);
     editor->getText(buffer,length);
 
     do
@@ -2018,10 +2018,10 @@ ret:
 long WriteWindow::onCmdSearchSel(FXObject*,FXSelector sel,void*)
 {
     FXString string;
-    FXuint searchflags;
+    unsigned int searchflags;
     FXString searchstring;
-    FXint pos=editor->getCursorPos();
-    FXint beg,end;
+    int pos=editor->getCursorPos();
+    int beg,end;
 
     // First, try UTF-8
     if(getDNDData(FROM_SELECTION,utf8Type,string))
@@ -2085,7 +2085,7 @@ x:
 // Go to line number
 long WriteWindow::onCmdGotoLine(FXObject*,FXSelector,void*)
 {
-    FXint row=editor->getCursorRow()+1;
+    int row=editor->getCursorRow()+1;
     if(FXInputDialog::getInteger(row,this,_("Goto Line"),_("&Goto line number:"),gotobigicon,1,2147483647))
     {
         update();
