@@ -77,29 +77,31 @@ protected:
 	FXString		trashfileslocation;
 	FXString		trashinfolocation;
 	FXString		startlocation;
-	FXuint			liststyle;
+	unsigned int			liststyle;
 	FXColor			listbackcolor;
 	FXColor			listforecolor;
 	FXColor			highlightcolor;
 	FXColor			pbarcolor;
 	FXColor			attentioncolor;
+	FXColor			scrollbarcolor;
 	FXArrowButton   *btnbackhist;
 	FXArrowButton   *btnforwardhist;
 	HistInputDialog*   rundialog;
 	PreferencesBox*    prefsdialog;
 	TextWindow*		   helpwindow;
 	FXString 		message;
-	FXuint 			panelfocus;
-	FXString		startdirectory;
+	unsigned int 			panelfocus;
+	FXString		startdirectory1;
+	FXString		startdirectory2;
 	FXbool			starticonic;
 	FXbool			startmaximized;
 	FXbool			smoothscroll;
-	FXdouble        twopanels_lpanel_pct;      // Panel sizes, relatively to the window width (in percent)
-	FXdouble        treepanel_tree_pct;
-	FXdouble        treetwopanels_tree_pct;
-	FXdouble        treetwopanels_lpanel_pct;
+	double        twopanels_lpanel_pct;      // Panel sizes, relatively to the window width (in percent)
+	double        treepanel_tree_pct;
+	double        treetwopanels_tree_pct;
+	double        treetwopanels_lpanel_pct;
 	FXString        prevdir;
-	FXint			prev_width;
+	int			prev_width;
 public:
 	enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -147,7 +149,7 @@ public:
 		ID_LAST
     };
 public:
-    XFileExplorer(FXApp *app=NULL,const FXbool iconic=FALSE,const FXbool maximized=FALSE,const FXString startdir = "",const char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
+    XFileExplorer(FXApp *app=NULL,const FXbool iconic=FALSE,const FXbool maximized=FALSE,const FXString startdir1 = "",const FXString startdir2 = "",const char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
     virtual void create();
     ~XFileExplorer();
     void saveConfig();
