@@ -37,7 +37,7 @@ char **args;
 FXColor listbackcolor, listforecolor;
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
-FXuint single_click;
+unsigned int single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXbool show_pathlink;
@@ -52,7 +52,7 @@ FXString xdgdatahome;
 #define hand_height 32
 #define hand_x_hot 6
 #define hand_y_hot 1
- static const FXuchar hand_bits[] = {
+ static const unsigned char hand_bits[] = {
 	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
 	0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
 	0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
@@ -65,7 +65,7 @@ FXString xdgdatahome;
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
  
- static const FXuchar hand_mask_bits[] = {
+ static const unsigned char hand_mask_bits[] = {
 	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
 	0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
 	0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
@@ -81,7 +81,7 @@ FXString xdgdatahome;
 
 // Predefined zoom factors 
 #define NB_ZOOM 24
-FXdouble zoomtab[NB_ZOOM]={0.01, 0.025, 0.05, 0.075, 0.10, 0.15, 0.20, 0.30, 0.50, 0.75, 1, \
+double zoomtab[NB_ZOOM]={0.01, 0.025, 0.05, 0.075, 0.10, 0.15, 0.20, 0.30, 0.50, 0.75, 1, \
                         1.5, 2, 3, 4, 5, 7.5, 10, 15, 20, 30, 50, 75, 100};
 #define ZOOM_100 10
 
@@ -89,7 +89,7 @@ FXdouble zoomtab[NB_ZOOM]={0.01, 0.025, 0.05, 0.075, 0.10, 0.15, 0.20, 0.30, 0.5
 #define MAX_IMGSIZE 5120
 
 // Patterns for supported image formats
-const FXchar *patterns[]=
+const char *patterns[]=
 {
     _("All Files"),		"*",
     _("GIF Image"),		"*.gif",
@@ -252,7 +252,7 @@ XFileImage::XFileImage(FXApp* a, FXbool smoothscroll):FXMainWindow(a,"Xfi ",NULL
     FXHorizontalFrame* pathframe=new FXHorizontalFrame(filebox,LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0, 0,0);
 
 	// File list
-	FXuint options;
+	unsigned int options;
 	if (smoothscroll)
 		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT;
 	else
@@ -469,6 +469,7 @@ XFileImage::XFileImage(FXApp* a, FXbool smoothscroll):FXMainWindow(a,"Xfi ",NULL
     mc=new FXMenuCommand(filemenu,text,quiticon,this,ID_QUIT);
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
+	getAccelTable()->addAccel(KEY_Escape,this,FXSEL(SEL_COMMAND,ID_QUIT));
 
     // Image Menu entries
     new FXMenuCommand(imagemenu,_("Zoom &in")+TAB+(FXString)"Ctrl+"+TAB+_("Zoom in image.")+PARS("Ctrl+"),zoominicon,this,ID_ZOOM_IN);
@@ -625,8 +626,8 @@ long XFileImage::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 {
     // Popup menu pane
 	FXMenuPane menu(this);
-    FXint x,y;
-    FXuint state;
+    int x,y;
+    unsigned int state;
     getRoot()->getCursorPosition(x,y,state);
 
 	new FXMenuCommand(&menu,_("Go ho&me"),homeicon,this,ID_HOME);
@@ -794,7 +795,7 @@ long  XFileImage::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 	forwardhist=filelist->forwardhist;
 
 	// Get all string items and display them in a list box
-	FXint num=backhist->getNumItems();
+	int num=backhist->getNumItems();
 	if (num>0)
 	{
 		FXString *dirs= new FXString[num];
@@ -814,7 +815,7 @@ long  XFileImage::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 		}
 
 		// Display list box
-		FXint pos=DirHistBox::box(btnbackhist,DECOR_NONE,strlist,this->getX()+245,this->getY()+37);
+		int pos=DirHistBox::box(btnbackhist,DECOR_NONE,strlist,this->getX()+245,this->getY()+37);
 		
 		// If an item was selected
 		if (pos!=-1)
@@ -833,7 +834,7 @@ long  XFileImage::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 			forwardhist->insertFirstItem(filelist->getDirectory());
 			if (pos>0)
 			{
-				for (FXint i=0; i<=pos-1; i++)
+				for (int i=0; i<=pos-1; i++)
 					forwardhist->insertFirstItem(dirs[i]);
 			}
 	
@@ -882,7 +883,7 @@ long  XFileImage::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* ptr)
 	forwardhist=filelist->forwardhist;
 
 	// Get all string items and display them in a list box
-	FXint num=forwardhist->getNumItems();
+	int num=forwardhist->getNumItems();
 	if (num>0)
 	{
 		FXString *dirs= new FXString[num];
@@ -902,7 +903,7 @@ long  XFileImage::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* ptr)
 		}
 		
 		// Display list box
-		FXint pos=DirHistBox::box(btnforwardhist,DECOR_NONE,strlist,this->getX()+285,this->getY()+37);
+		int pos=DirHistBox::box(btnforwardhist,DECOR_NONE,strlist,this->getX()+285,this->getY()+37);
 		
 		// If an item was selected
 		if (pos!=-1)
@@ -920,7 +921,7 @@ long  XFileImage::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* ptr)
 			backhist->insertFirstItem(filelist->getDirectory());
 			if (pos>0)
 			{
-				for (FXint i=0; i<=pos-1; i++)
+				for (int i=0; i<=pos-1; i++)
 					backhist->insertFirstItem(dirs[i]);
 			}
 	
@@ -1257,7 +1258,7 @@ long XFileImage::onCmdToggleHidden(FXObject* sender,FXSelector sel,void* ptr)
 // Update toggle hidden command
 long XFileImage::onUpdToggleHidden(FXObject* sender,FXSelector sel,void* ptr)
 {	
-    FXuint msg = FXWindow::ID_UNCHECK;
+    unsigned int msg = FXWindow::ID_UNCHECK;
 	hiddenfiles = filelist->shownHiddenFiles();
 		
 	if(hiddenfiles == TRUE)
@@ -1283,7 +1284,7 @@ long XFileImage::onCmdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr
 // Update toggle hidden command
 long XFileImage::onUpdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr)
 {	
-    FXuint msg = FXWindow::ID_UNCHECK;
+    unsigned int msg = FXWindow::ID_UNCHECK;
 	thumbnails = filelist->shownThumbnails();
 		
 	if(thumbnails == TRUE)
@@ -1331,7 +1332,7 @@ long XFileImage::onUpdFileView(FXObject* sender,FXSelector sel,void* ptr)
 	// Keep the filebox height relative to the window height
 
 	// Get the current height
-	FXint height=getHeight();
+	int height=getHeight();
 	
 	// If height has changed
 	if (relative_resize && prev_height!=height)
@@ -1340,7 +1341,7 @@ long XFileImage::onUpdFileView(FXObject* sender,FXSelector sel,void* ptr)
 		if (filebox->shown())
 		{
 			// Set filebox height to the new value
-			filebox->setHeight((FXint)round(fileheight_pct*height));
+			filebox->setHeight((int)round(fileheight_pct*height));
 		}
 	}
 			
@@ -1349,10 +1350,10 @@ long XFileImage::onUpdFileView(FXObject* sender,FXSelector sel,void* ptr)
 		
 	// Update the relative size (only if window size is sufficient)
 	if (getHeight()>10)
-		fileheight_pct=(FXdouble)(filebox->getHeight())/(FXdouble)(getHeight());
+		fileheight_pct=(double)(filebox->getHeight())/(double)(getHeight());
 		
 	// Update radio buttons
-	FXuint msg = FXWindow::ID_UNCHECK;
+	unsigned int msg = FXWindow::ID_UNCHECK;
 		
     switch(FXSELID(sel))
     {
@@ -1418,7 +1419,7 @@ long XFileImage::onUpdTitle(FXObject* sender,FXSelector,void*)
 // Open recent file
 long XFileImage::onCmdRecentFile(FXObject*,FXSelector,void* ptr)
 {
-    filename=(FXchar*)ptr;
+    filename=(char*)ptr;
     filelist->setCurrentFile(filename);
     loadimage(filename);
     return 1;
@@ -1428,7 +1429,7 @@ long XFileImage::onCmdRecentFile(FXObject*,FXSelector,void* ptr)
 // Double clicked in the file list
 long XFileImage::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
 {
-    FXint index=(FXint)(FXival)ptr;
+    int index=(int)(FXival)ptr;
     if(0<=index)
     {
         if(filelist->isItemDirectory(index))
@@ -1462,14 +1463,14 @@ long XFileImage::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
 	if (single_click != SINGLE_CLICK_NONE)
 	{		
 		// In detailed mode, avoid single click when cursor is not over the first column
-		FXint x, y;
-		FXuint state;
+		int x, y;
+		unsigned int state;
 		getCursorPosition(x,y,state);
 		FXbool allow=TRUE;
 		if (!(filelist->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-filelist->getXPosition())>filelist->getHeaderSize(0))
 			allow=FALSE;
 
-		FXint index=(FXint)(FXival)ptr;
+		int index=(int)(FXival)ptr;
 		if(0<=index)
 		{
 			if((single_click != SINGLE_CLICK_NONE) && filelist->isItemDirectory(index) && allow)
@@ -1589,8 +1590,8 @@ long XFileImage::onCmdZoomIn(FXObject*,FXSelector,void*)
 	// Resize the actual image according to the new zoom factor
 	indZoom+=1;
 	if (indZoom>NB_ZOOM-1) indZoom=NB_ZOOM-1;
-	FXint sx=(FXint)(tmpimg->getWidth()*zoomtab[indZoom]);
-	FXint sy=(FXint)(tmpimg->getHeight()*zoomtab[indZoom]);
+	int sx=(int)(tmpimg->getWidth()*zoomtab[indZoom]);
+	int sy=(int)(tmpimg->getHeight()*zoomtab[indZoom]);
 	
 	// Scale only if the actual image size is different
 	if (indZoom==ZOOM_100)
@@ -1602,8 +1603,8 @@ long XFileImage::onCmdZoomIn(FXObject*,FXSelector,void*)
 		{
 			indZoom-=1;
 			if (indZoom<0) indZoom=0;
-			sx=(FXint)(tmpimg->getWidth()*zoomtab[indZoom]);
-			sy=(FXint)(tmpimg->getHeight()*zoomtab[indZoom]);
+			sx=(int)(tmpimg->getWidth()*zoomtab[indZoom]);
+			sy=(int)(tmpimg->getHeight()*zoomtab[indZoom]);
 		}
 
 		// Scale image according to the new zoom factor
@@ -1632,8 +1633,8 @@ long XFileImage::onCmdZoomOut(FXObject*,FXSelector,void*)
 	// Resize the image according to the new zoom factor
 	indZoom-=1;
 	if (indZoom<0) indZoom=0;
-	FXint sx=(FXint)(tmpimg->getWidth()*zoomtab[indZoom]);
-	FXint sy=(FXint)(tmpimg->getHeight()*zoomtab[indZoom]);
+	int sx=(int)(tmpimg->getWidth()*zoomtab[indZoom]);
+	int sy=(int)(tmpimg->getHeight()*zoomtab[indZoom]);
 
 	// Scale only if the actual image size is different
 	if (indZoom==ZOOM_100)
@@ -1671,21 +1672,21 @@ long XFileImage::onCmdZoomWin(FXObject*,FXSelector,void*)
 	getApp()->beginWaitCursor();
 
 	// Window and image sizes
-	FXint winw=imageview->getWidth();
-	FXint winh=imageview->getHeight();
-	FXint w=img->getWidth();
-	FXint h=img->getHeight();
+	int winw=imageview->getWidth();
+	int winh=imageview->getHeight();
+	int w=img->getWidth();
+	int h=img->getHeight();
 	
 	// Compute zoom factor
-	FXdouble fitwin;	
-	if (FXdouble(w)/FXdouble(h)>FXdouble(winw)/FXdouble(winh))
-		fitwin=0.98*(FXdouble)winw/(FXdouble)w;
+	double fitwin;	
+	if (double(w)/double(h)>double(winw)/double(winh))
+		fitwin=0.98*(double)winw/(double)w;
 	else
-		fitwin=0.98*(FXdouble)winh/(FXdouble)h;
+		fitwin=0.98*(double)winh/(double)h;
 
 	// Find the most approaching predefined zoom
 	// This is used in other zoom functions
-	for (FXint k=0; k<NB_ZOOM; k++)
+	for (int k=0; k<NB_ZOOM; k++)
 	{
  		if (zoomtab[k]>fitwin)
 		{	
@@ -1702,8 +1703,8 @@ long XFileImage::onCmdZoomWin(FXObject*,FXSelector,void*)
 	tmpimg->setData(tmpdata,IMAGE_OWNED,img->getWidth(),img->getHeight());	
 
 	// Resize the image according to the new zoom factor
-	FXint sx=(FXint)(w*fitwin);
-	FXint sy=(FXint)(h*fitwin);
+	int sx=(int)(w*fitwin);
+	int sy=(int)(h*fitwin);
 
 	// Scale image according to the new zoom factor
     tmpimg->scale(sx,sy,1);
@@ -1730,10 +1731,10 @@ void XFileImage::start(FXString startimage)
 void XFileImage::create()
 {
 	// Get size and position
-    FXuint ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);    // Workaround for a possible bug in some WMs
-    FXuint hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);  // Workaround for a possible bug in some WMs
+    unsigned int ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);    // Workaround for a possible bug in some WMs
+    unsigned int hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);  // Workaround for a possible bug in some WMs
     fileheight_pct=getApp()->reg().readRealEntry("OPTIONS","fileheight_pct",0.25);
-    FXuint fs=getApp()->reg().readIntEntry("OPTIONS","filesshown",TRUE);
+    unsigned int fs=getApp()->reg().readIntEntry("OPTIONS","filesshown",TRUE);
 
 	filelist->setDirectory(FXSystem::getCurrentDirectory());
    	pathlink->setPath(FXSystem::getCurrentDirectory());
@@ -1772,7 +1773,7 @@ void XFileImage::create()
 	//filelist->showThumbnails(thumbnails);
   
 	// Get list style
-	liststyle=getApp()->reg().readUnsignedEntry("OPTIONS","liststyle",(FXuint)IconList::ID_SHOW_DETAILS);
+	liststyle=getApp()->reg().readUnsignedEntry("OPTIONS","liststyle",(unsigned int)IconList::ID_SHOW_DETAILS);
 	filelist->setListStyle(liststyle);
 
 	// Get file view
@@ -1788,8 +1789,8 @@ void XFileImage::create()
 	// Get position and position window
     if (save_win_pos)
 	{
-		FXint xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
-		FXint ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
+		int xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+		int ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 		position(xpos,ypos,ww,hh);
 	}
 	else
@@ -1801,7 +1802,7 @@ void XFileImage::create()
 		filelist->setPattern(imgpatterns);
 
 	// Set file list height
-    filebox->setHeight((FXint)round(fileheight_pct*getHeight()));
+    filebox->setHeight((int)round(fileheight_pct*getHeight()));
 
 	show();
 
@@ -1815,8 +1816,8 @@ void XFileImage::create()
 void XFileImage::saveConfig()
 {
     // Write new window size and position back to registry
-	getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","width",(unsigned int)getWidth());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","height",(unsigned int)getHeight());
 
 	if (save_win_pos)
 	{
