@@ -10,8 +10,8 @@ class XFileImage : public FXMainWindow
 protected:
 	FXbool             hiddenfiles;           // Show or hide hidden files
 	FXbool             thumbnails;            // Show or hide image thumbnails
-	FXuint             fileview;              // File list view
-	FXuint			   liststyle;             // Icon list style
+	unsigned int             fileview;              // File list view
+	unsigned int			   liststyle;             // Icon list style
     FXImageView       *imageview;             // Image viewer
     FXRecentFiles      mrufiles;              // Recent files
     FXString           filename;              // File being viewed
@@ -32,18 +32,18 @@ protected:
 	FXImage			  *img;					  // Image loaded
 	FXImage			  *tmpimg;				  // Temporary image
     FXColor 		  *tmpdata;				  // Temporary image data
-	FXint			  indZoom;				  // Zoom index
-	FXdouble		  zoomval;				  // Actual zoom factor
+	int			  indZoom;				  // Zoom index
+	double		  zoomval;				  // Actual zoom factor
 	FXbool			  fitwin;                 // Fit window when opening an image
 	FXbool            filterimgs;             // List only image files in file list
 	InputDialog*	  printdialog;
 	FXbool			  smoothscroll;
-	FXdouble		  fileheight_pct;
+	double		  fileheight_pct;
 	FXArrowButton     *btnbackhist;           // Back history
 	FXArrowButton     *btnforwardhist;        // Forward history
     PathLinker*		  pathlink;
 	TextLabel*		  pathtext;
-	FXint 			  prev_height;
+	int 			  prev_height;
 protected:
     XFileImage()
     {}
