@@ -35,7 +35,7 @@ FXbool dpkg=FALSE;
 FXbool rpm=FALSE;
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
-FXuint single_click;
+unsigned int single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXbool save_win_pos;
@@ -48,7 +48,7 @@ FXString xdgdatahome;
 #define hand_height 32
 #define hand_x_hot 6
 #define hand_y_hot 1
- static const FXuchar hand_bits[] = {
+ static const unsigned char hand_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
    0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
    0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
@@ -61,7 +61,7 @@ FXString xdgdatahome;
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
  
- static const FXuchar hand_mask_bits[] = {
+ static const unsigned char hand_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
    0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
    0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
@@ -146,9 +146,10 @@ XFilePackage::XFilePackage(FXApp *a):FXMainWindow(a,"Xfp",NULL,NULL,DECOR_ALL)
 	mc->setAccelText(key);
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
+	getAccelTable()->addAccel(KEY_Escape,this,FXSEL(SEL_COMMAND,ID_QUIT));
 	
     // Preferences menu
-    new FXMenuCheck(prefsmenu,_("&Toolbar")+TAB+_("Display toolbar"),toolbar,FXWindow::ID_TOGGLESHOWN);
+    new FXMenuCheck(prefsmenu,_("&Toolbar"),toolbar,FXWindow::ID_TOGGLESHOWN);
 
     // Help Menu entries
     mc=new FXMenuCommand(helpmenu,_("&About X File Package"),NULL,this,ID_ABOUT,0);
@@ -224,7 +225,7 @@ long XFilePackage::onCmdAbout(FXObject*,FXSelector,void*)
 // Open package
 long XFilePackage::onCmdOpen(FXObject*,FXSelector,void*)
 {
-    const FXchar *patterns[]=
+    const char *patterns[]=
         {
             _("All Files"),			"*",
             _("RPM source packages"),	"*.src.rpm",
@@ -343,8 +344,8 @@ long XFilePackage::onCmdUninstall(FXObject*,FXSelector,void*)
 void XFilePackage::saveConfig()
 {
     // Write new window size and position back to registry
-    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
-    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(unsigned int)getWidth());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(unsigned int)getHeight());
 
 	if (save_win_pos)
 	{
@@ -589,14 +590,14 @@ void XFilePackage::create()
         toolbar->hide();
 
     // Get size
-    FXuint width=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
-    FXuint height=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
+    unsigned int width=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
+    unsigned int height=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
 
 	// Get position and position window
     if (save_win_pos)
 	{
-		FXint xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
-		FXint ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
+		int xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+		int ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 		position(xpos,ypos,width,height);
 	}
 	else
