@@ -29,7 +29,7 @@
 
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
-FXuint single_click;
+unsigned int single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXString homedir;
@@ -42,7 +42,7 @@ FXString xdgdatahome;
 #define hand_height 32
 #define hand_x_hot 6
 #define hand_y_hot 1
- static const FXuchar hand_bits[] = {
+ static const unsigned char hand_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
    0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
    0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
@@ -55,7 +55,7 @@ FXString xdgdatahome;
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
  
- static const FXuchar hand_mask_bits[] = {
+ static const unsigned char hand_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
    0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
    0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
@@ -102,7 +102,7 @@ void XFileWrite::init(int& argc,char** argv,bool connect)
 
 
 // Exit application
-void XFileWrite::exit(FXint code)
+void XFileWrite::exit(int code)
 {
     // Write registry, and quit
     FXApp::exit(code);
@@ -141,8 +141,8 @@ XFileWrite::~XFileWrite()
 int main(int argc,char *argv[])
 {
     WriteWindow *window=NULL;
-    FXString    file;
-    FXint       i;
+    FXString file;
+    int i;
 	const char *appname = "xfw";
 	const char *xfename = XFEAPPNAME;
 	const char *vdrname = XFEVDRNAME;
