@@ -187,7 +187,7 @@
   =-=-=-=-=-=-=-=-=-=-=-=-=\n \
 \n \
  Dragging a file or group or files (by moving the mouse while maintaining the left button pressed)\n \
- to a directory or a file panel optionally opens a dialog that allows to select the file operation: copy,\n \
+ to a directory or a file panel optionally opens a dialog that allows one to select the file operation: copy,\n \
  move, link or cancel.\n \
 \n \
 \n \
