@@ -1,11 +1,11 @@
 #include "config.h"
 #include "i18n.h"
 
-
 #include <stdlib.h>
 #include <sys/time.h>
 #include <unistd.h>
 #include <errno.h>
+#include <assert.h>
 
 #include <fx.h>
 
@@ -14,6 +14,7 @@
 #include "startupnotification.h"
 
 
+
 #ifdef STARTUP_NOTIFICATION  // Use startup notification
 
 
@@ -44,18 +45,36 @@ void startup_completed(void)
 }
 
 
-// Obtain a timestamp for the startup notification
+// Hack to obtain a timestamp for startup notification
+// Create a fake window and set up a property change event
+// Code snippet borrowed from the Internet 
 Time gettimestamp (void)
-{
-	static struct timeval tv;
-	gettimeofday(&tv,NULL);
-	return tv.tv_sec;
+{      
+	Display *display;
+	Window window;
+	XEvent event;
+	Atom atom_name, atom_type;
+
+	display = XOpenDisplay(0);
+	window = XCreateWindow(display, DefaultRootWindow (display), 0, 0, 1, 1, 0, 0, InputOnly, 0, 0, NULL);
+	XSelectInput(display, window, PropertyChangeMask);
+	atom_name = XInternAtom(display, "_NET_WM_USER_TIME_WINDOW", False);
+	atom_type = XInternAtom(display, "WINDOW", TRUE);
+	XChangeProperty(display, window, atom_name, atom_type, 8, PropModeReplace, (const unsigned char*)&window, 1);
+	XNextEvent(display, &event);
+	assert(event.type == PropertyNotify);
+	XCloseDisplay(display);
+
+	return ((XPropertyEvent *) &event)->time;
 }
 
 
 // Launch a command and initiate a startup notification 
-FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcepts="")
+int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbool usesn=TRUE, FXString snexcepts="")
 {
+	// Change to current directory
+	chdir(dir.text());
+	
 	// Get rid of possible command options
 	cmdname=cmdname.before(' ');
 	
@@ -64,7 +83,7 @@ FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcep
 	if(snexcepts != "")
 	{
 		FXString entry;
-		for(FXint i=0; ; i++)
+		for(int i=0; ; i++)
 		{
 			entry=snexcepts.section(':',i);
 			if(streq(entry.text(),""))
@@ -90,6 +109,7 @@ FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcep
 		if (xdisplay == NULL)
 		{
 			fprintf (stderr,_("Error! Can't open display\n"));
+			chdir(startdir.text());
 			return -1;
 		}
 	  
@@ -109,7 +129,7 @@ FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcep
 
 		// Run command in background
 		cmd += " &";
-		
+	
 		static pid_t child_pid = 0;
 		switch ((child_pid = fork ()))
 		{
@@ -118,7 +138,7 @@ FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcep
 				break;
 		
 			case 0:
-				sn_launcher_context_setup_child_process(context);
+				sn_launcher_context_setup_child_process(context);				
 				execl("/bin/sh","sh","-c",cmd.text(),(char *)NULL);
 				exit(1);
 				break;
@@ -137,6 +157,9 @@ FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcep
 		sleep(1);
 	}
 	
+	// Go back to startup directory
+	chdir(startdir.text());
+	
 	return 0;
 }
 
@@ -144,8 +167,11 @@ FXint runcmd(FXString cmd, FXString cmdname, FXbool usesn=TRUE, FXString snexcep
 #else  // Don't use startup notification
 
 // Run a command and simulate a startup time
-FXint runcmd(FXString cmd)
+int runcmd(FXString cmd, FXString dir, FXString startdir)
 {
+	// Change to current directory
+	chdir(dir.text());
+
 	// Run the command in background
 	cmd += " &";
 	system(cmd.text());
@@ -153,6 +179,9 @@ FXint runcmd(FXString cmd)
 	// Very ugly simulation of a startup time!!!
 	sleep(SIMULATED_STARTUP_TIME);
 	
+	// Go back to startup directory
+	chdir(startdir.text());
+
 	return 0;
 }
 #endif
