@@ -1,7 +1,12 @@
 // Common Xfe constants
 
 #ifndef COPYRIGHT
-#define COPYRIGHT "Copyright (C) 2002-2012 Roland Baudin (roland65@free.fr)"
+#define COPYRIGHT "Copyright (C) 2002-2013 Roland Baudin (roland65@free.fr)"
+#endif
+
+// Default file and directory list time format
+#ifndef DEFAULT_TIME_FORMAT
+#define DEFAULT_TIME_FORMAT "%x %X"
 #endif
 
 // Default initial main window width
@@ -209,12 +214,12 @@
 
 // Default audio viewer program
 #ifndef DEFAULT_AUDIOVIEWER
-#define DEFAULT_AUDIOVIEWER "xmms"
+#define DEFAULT_AUDIOVIEWER "audacious"
 #endif
 
 // Default video viewer program
 #ifndef DEFAULT_VIDEOVIEWER
-#define DEFAULT_VIDEOVIEWER "xine"
+#define DEFAULT_VIDEOVIEWER "mplayer"
 #endif
 
 
