@@ -26,8 +26,8 @@
 // Parse accelerator from string
 FXHotKey _parseAccel(const FXString& string)
 {
-	register FXuint code=0,mods=0;
-	register FXint pos=0;
+	register unsigned int code=0,mods=0;
+	register int pos=0;
 
 	// Parse leading space
 	while(pos<string.length() && Ascii::isSpace(string[pos]))
@@ -171,7 +171,7 @@ FXbool existCommand(const FXString cmd)
 		{
 			FXString path;
 
-			for(FXint i=0;;i++)
+			for(int i=0;;i++)
 			{
 				// Obtain path component
 				path=execpath.section(':',i);
@@ -197,10 +197,10 @@ FXbool existCommand(const FXString cmd)
 FXString getKeybinding(FXEvent* event)
 {
 	// Get modifiers and key
-	FXint mods=event->state;
-	FXint code=event->code;
+	int mods=event->state;
+	int code=event->code;
 	
-	FXchar buffer[64];
+	char buffer[64];
 	FXString s;
 
 	// Handle modifier keys
@@ -314,10 +314,10 @@ FXString getKeybinding(FXEvent* event)
 // Return 0 if success or -1 if fail
 // Original author : Niall O'Higgins */
 // http://niallohiggins.com/2009/01/08/mkpath-mkdir-p-alike-in-c-for-unix
-FXint mkpath(const FXchar* s, mode_t mode)
+int mkpath(const char* s, mode_t mode)
 {
-	FXchar *q, *r = NULL, *path = NULL, *up = NULL;
-	FXint rv;
+	char *q, *r = NULL, *path = NULL, *up = NULL;
+	int rv;
 
 	rv = -1;
 	if (strcmp(s, ".") == 0 || strcmp(s, "/") == 0)
@@ -329,7 +329,7 @@ FXint mkpath(const FXchar* s, mode_t mode)
 	if ((q = strdup(s)) == NULL)
 		exit(1);
 
-	if ((r = (FXchar*)dirname(q)) == NULL)
+	if ((r = (char*)dirname(q)) == NULL)
 		goto out;
 
 	if ((up = strdup(r)) == NULL)
@@ -360,11 +360,11 @@ FXString createTrashpathname(FXString pathname, FXString trashfileslocation)
 
 	// Eventually modify the trash files path name by adding a suffix like '_1', '_2', etc.,
 	// if the file already exists in the trash can files directory
-	for (FXint i=1; ; i++)
+	for (int i=1; ; i++)
 	{
 		if (::exists(trashpathname))
 		{
-			FXchar suffix[32];
+			char suffix[32];
 			snprintf(suffix,sizeof(suffix)-1,"_%d",i);
 			FXString prefix=trashpathname.rbefore('_');
 			if (prefix=="")
@@ -380,23 +380,23 @@ FXString createTrashpathname(FXString pathname, FXString trashfileslocation)
 
 
 // Create trashinfo file based on the pathname and the trashpathname
-FXint createTrashinfo(FXString pathname, FXString trashpathname, FXString trashfileslocation, FXString trashinfolocation)
+int createTrashinfo(FXString pathname, FXString trashpathname, FXString trashfileslocation, FXString trashinfolocation)
 {
 	// Create trash can files if it doesn't exist
 	if (!exists(trashfileslocation))
 	{
-		FXint mask=umask(0);
+		int mask=umask(0);
 		umask(mask);
-		FXint ret=mkpath(trashfileslocation.text(),511 & ~mask);
+		int ret=mkpath(trashfileslocation.text(),511 & ~mask);
 		return ret;
 	}
 	
 	// Create trash can info if it doesn't exist
 	if (!exists(trashinfolocation))
 	{
-		FXint mask=umask(0);
+		int mask=umask(0);
 		umask(mask);
-		FXint ret=mkpath(trashinfolocation.text(),511 & ~mask);
+		int ret=mkpath(trashinfolocation.text(),511 & ~mask);
 		return ret;
 
 	}
@@ -411,7 +411,7 @@ FXint createTrashinfo(FXString pathname, FXString trashpathname, FXString trashf
 
 	// Create trash info file
 	FILE *fp;
-	FXint ret;
+	int ret;
 	if ((fp=fopen(trashinfopathname.text(),"w"))!=NULL)
 	{
 		fprintf(fp,"[Trash Info]\n");
@@ -438,7 +438,7 @@ FXString mimetype(FXString filepath)
         perror("popen");
         exit(1);
     }
-    FXchar text[128]={0};
+    char text[128]={0};
     FXString buf;
     while(fgets(text,sizeof(text),filecmd))
         buf+=text;
@@ -453,7 +453,7 @@ FXString mimetype(FXString filepath)
 FXString quote(FXString str)
 {
 	FXString result = "'";
-	const FXchar *p;
+	const char *p;
 
 	for (p = str.text(); *p; p++)
 		if (*p == '\'')
@@ -469,42 +469,42 @@ FXString quote(FXString str)
 // Test if a string is encoded in UTF-8
 // "length" is the number of bytes of the string to consider
 // Taken from the weechat project. Original author FlashCode <flashcode@flashtux.org>
-FXbool isUtf8(const FXchar* string, FXuint length)
+FXbool isUtf8(const char* string, unsigned int length)
 {
-    FXuint n=0;
+    unsigned int n=0;
 	while (n<length)
     {
         // UTF-8, 2 bytes, should be: 110vvvvv 10vvvvvv
-        if (((unsigned FXchar)(string[0]) & 0xE0) == 0xC0)
+        if (((unsigned char)(string[0]) & 0xE0) == 0xC0)
         {
-            if (!string[1] || (((unsigned FXchar)(string[1]) & 0xC0) != 0x80))
+            if (!string[1] || (((unsigned char)(string[1]) & 0xC0) != 0x80))
                 return FALSE;
             string += 2;
 			n += 2;
         }
         // UTF-8, 3 bytes, should be: 1110vvvv 10vvvvvv 10vvvvvv
-        else if (((unsigned FXchar)(string[0]) & 0xF0) == 0xE0)
+        else if (((unsigned char)(string[0]) & 0xF0) == 0xE0)
         {
             if (!string[1] || !string[2]
-                || (((unsigned FXchar)(string[1]) & 0xC0) != 0x80)
-                || (((unsigned FXchar)(string[2]) & 0xC0) != 0x80))
+                || (((unsigned char)(string[1]) & 0xC0) != 0x80)
+                || (((unsigned char)(string[2]) & 0xC0) != 0x80))
                 return FALSE;
             string += 3;
 			n += 3;
        }
         // UTF-8, 4 bytes, should be: 11110vvv 10vvvvvv 10vvvvvv 10vvvvvv
-        else if (((unsigned FXchar)(string[0]) & 0xF8) == 0xF0)
+        else if (((unsigned char)(string[0]) & 0xF8) == 0xF0)
         {
             if (!string[1] || !string[2] || !string[3]
-                || (((unsigned FXchar)(string[1]) & 0xC0) != 0x80)
-                || (((unsigned FXchar)(string[2]) & 0xC0) != 0x80)
-                || (((unsigned FXchar)(string[3]) & 0xC0) != 0x80))
+                || (((unsigned char)(string[1]) & 0xC0) != 0x80)
+                || (((unsigned char)(string[2]) & 0xC0) != 0x80)
+                || (((unsigned char)(string[3]) & 0xC0) != 0x80))
                 return FALSE;
             string += 4;
 			n += 4;
         }
         // UTF-8, 1 byte, should be: 0vvvvvvv
-        else if ((unsigned FXchar)(string[0]) >= 0x80)
+        else if ((unsigned char)(string[0]) >= 0x80)
 		{
             return FALSE;
 		}
@@ -522,7 +522,7 @@ FXbool isUtf8(const FXchar* string, FXuint length)
 #if defined(linux)
 // Stat function used to test if a mount point is up or down
 // Actually, this is simply the lstat() function
-FXint lstatmt(const FXchar* filename, struct stat* buf)
+int lstatmt(const char* filename, struct stat* buf)
 {
 	return lstat(filename,buf);
 }
@@ -532,9 +532,9 @@ FXint lstatmt(const FXchar* filename, struct stat* buf)
 // Safe strcpy function (Public domain, by C.B. Falconer)
 // The destination string is always null terminated
 // Size sz must be equal to strlen(src)+1
-size_t strlcpy(FXchar* dst, const char* src, size_t sz)
+size_t strlcpy(char* dst, const char* src, size_t sz)
 {
-	const FXchar *start = src;
+	const char *start = src;
 
 	if (src && sz--)
 	{
@@ -561,9 +561,9 @@ size_t strlcpy(FXchar* dst, const char* src, size_t sz)
 
 // Safe strcat function (Public domain, by C.B. Falconer)
 // The destination string is always null terminated
-size_t strlcat(FXchar* dst, const FXchar* src, size_t sz)
+size_t strlcat(char* dst, const char* src, size_t sz)
 {
-   FXchar *start = dst;
+   char *start = dst;
 
    while (*dst++)      // assumes sz >= strlen(dst)
       if (sz)
@@ -574,14 +574,14 @@ size_t strlcat(FXchar* dst, const FXchar* src, size_t sz)
 
 
 // Obtain the non recursive size of a directory
-unsigned long long dirsize(const FXchar* path)
+FXulong dirsize(const char* path)
 {
     DIR *dp;
 	struct dirent *dirp;
 	struct stat statbuf;
-	FXchar buf[MAXPATHLEN];
-	unsigned long long dsize=0;
-	FXint ret;
+	char buf[MAXPATHLEN];
+	FXulong dsize=0;
+	int ret;
 			
 	if((dp=opendir(path))==NULL)
         return 0;
@@ -606,7 +606,7 @@ unsigned long long dirsize(const FXchar* path)
 		if(ret==0)
 		{
 			if(!S_ISDIR(statbuf.st_mode))
-		  		dsize += (unsigned long long) statbuf.st_size;
+		  		dsize += (FXulong) statbuf.st_size;
 		}
 	}
 	if(closedir(dp)<0)
@@ -620,19 +620,19 @@ unsigned long long dirsize(const FXchar* path)
 // Caution: this only works if nbfiles and nbsubdirs are initialized to 0 in the calling function
 // After that, nbfiles contains the total number of files (including the count of sub directories)
 // and nbsubdirs the number of sub directories
-unsigned long long pathsize(FXchar* path, FXuint* nbfiles, FXuint* nbsubdirs)
+FXulong pathsize(char* path, unsigned int* nbfiles, unsigned int* nbsubdirs)
 {
 	struct stat statbuf;
 	struct dirent *dirp;
-    FXchar *ptr;
+    char *ptr;
     DIR *dp;
-	unsigned long long dsize;
-	FXint ret;
+	FXulong dsize;
+	int ret;
 
 	ret=lstatrep(path,&statbuf);
 	if(ret<0)
         return 0;
-    dsize = (unsigned long long) statbuf.st_size;
+    dsize = (FXulong) statbuf.st_size;
 	(*nbfiles)++;
     
 	// Not a directory
@@ -642,7 +642,7 @@ unsigned long long pathsize(FXchar* path, FXuint* nbfiles, FXuint* nbsubdirs)
 	// Directory
 	(*nbsubdirs)++;
 
-	ptr=(FXchar*)path + strlen(path);
+	ptr=(char*)path + strlen(path);
     if(ptr[-1]!='/')
     {
         *ptr++='/';
@@ -671,14 +671,14 @@ unsigned long long pathsize(FXchar* path, FXuint* nbfiles, FXuint* nbsubdirs)
 
 
 // Write the file size in human readable form (bytes or Kbytes or Mbytes)
-FXString hSize(FXchar* size)
+FXString hSize(char* size)
 {
-    FXint flag=0;
-    FXchar suf[64];
-	FXchar buf[128];
+    int flag=0;
+    char suf[64];
+	char buf[128];
 	FXString hsize;
 
-    unsigned long long lsize = strtoull(size,NULL,10);
+    FXulong lsize = strtoull(size,NULL,10);
     float fsize=0.0;
 
 	strlcpy(suf,_("bytes"),sizeof(suf)); 
@@ -843,12 +843,12 @@ long deltime(FXString delstr)
 
 // Test if a directory is empty
 // Return -1 if not a directory, 1 if empty and 0 if not empty
-FXint isEmptyDir(const FXString directory)
+int isEmptyDir(const FXString directory)
 {
-	FXint ret=-1;
+	int ret=-1;
 	DIR* dir;
 	struct dirent *entry;
-	FXint n=0;
+	int n=0;
 	
 	if ((dir=opendir(directory.text()))!=NULL)
 	{
@@ -867,9 +867,9 @@ FXint isEmptyDir(const FXString directory)
 
 // Test if a directory has sub-directories
 // Return -1 if not a directory, 1 if has sub-directories, 0 if does not have
-FXint hasSubDirs(const FXString directory)
+int hasSubDirs(const FXString directory)
 {
-	FXint ret=-1;
+	int ret=-1;
 	DIR* dir;
 	struct dirent *entry;
 	
@@ -944,9 +944,9 @@ FXbool isFile(const FXString& file)
 // (thanks to Armin Buehler <abuehler@users.sourceforge.net>)
 FXbool isGroupMember(gid_t gid)
 {
-	static long ngroups = 0;
+	static int ngroups = 0;
 	static gid_t *gids = NULL;
-	long i;
+	int i;
 
 	// First call : initialization of the number of supplementary groups and the group list
 	if (ngroups == 0)
@@ -979,7 +979,7 @@ FXbool isReadExecutable(const FXString& file)
 	// File exists and can be stated
 	if (!file.empty() && (statrep(file.text(),&info)==0))
 	{
-		FXint ret=access(file.text(),R_OK|X_OK);
+		int ret=access(file.text(),R_OK|X_OK);
 		if (ret==0)
 			return TRUE;
 		else
@@ -999,7 +999,7 @@ FXbool isReadable(const FXString& file)
 	// File exists and can be stated
 	if (!file.empty() && (statrep(file.text(),&info)==0))
 	{
-		FXint ret=access(file.text(),R_OK);
+		int ret=access(file.text(),R_OK);
 		if (ret==0)
 			return TRUE;
 		else
@@ -1019,7 +1019,7 @@ FXbool isWritable(const FXString& file)
 	// File exists and can be stated
 	if (!file.empty() && (statrep(file.text(),&info)==0))
 	{
-		FXint ret=access(file.text(),W_OK);
+		int ret=access(file.text(),W_OK);
 		if (ret==0)
 			return TRUE;
 		else
@@ -1049,9 +1049,9 @@ FXbool info(const FXString& file,struct stat& inf)
 
 // Return permissions string
 // (the FOX function FXSystem::modeString() seems to use another format for the mode field) 
-FXString permissions(FXuint mode)
+FXString permissions(unsigned int mode)
 {
-	FXchar result[11];
+	char result[11];
 	result[0]=S_ISLNK(mode) ? 'l' : S_ISREG(mode) ? '-' : S_ISDIR(mode) ? 'd' : S_ISCHR(mode) ? 'c' : S_ISBLK(mode) ? 'b' : S_ISFIFO(mode) ? 'p' : S_ISSOCK(mode) ? 's' : '?';
 	result[1]=(mode&S_IRUSR) ? 'r' : '-';
 	result[2]=(mode&S_IWUSR) ? 'w' : '-';
@@ -1070,8 +1070,8 @@ FXString permissions(FXuint mode)
 // Read symbolic link
 FXString readLink(const FXString& file)
 {
-	FXchar lnk[MAXPATHLEN+1];
-	FXint len=readlink(file.text(),lnk,MAXPATHLEN);
+	char lnk[MAXPATHLEN+1];
+	int len=readlink(file.text(),lnk,MAXPATHLEN);
 	if(0<=len)
   		return FXString(lnk,len);
   	else
@@ -1095,9 +1095,9 @@ FXbool identical(const FXString& file1,const FXString& file2)
 // Start or stop wait cursor (start if type is BEGIN_CURSOR, stop if type is END_CURSOR)
 // Do nothing if type is QUERY_CURSOR or anything different from BEGIN_CURSOR and END_CURSOR)
 // Return wait cursor count (0 means wait cursor is not set)
-FXint setWaitCursor(FXApp* app, FXuint type)
+int setWaitCursor(FXApp* app, unsigned int type)
 {
-	static FXint waitcount=0;
+	static int waitcount=0;
 	
 	// Begin wait cursor
 	if (type==BEGIN_CURSOR)
@@ -1127,10 +1127,10 @@ FXint setWaitCursor(FXApp* app, FXuint type)
 // Run a command in an internal Xvt terminal
 // Return 0 if success, -1 else
 // N.B.: zombie process should be dealt with in the main application class
-FXint runinxvt(FXString cmd)
+int runinxvt(FXString cmd)
 {
 	FXString str1, str2;
-	FXint nbargs, i, j;
+	int nbargs, i, j;
 
 	// First pass to find the number of commmand arguments
 	nbargs=0;
@@ -1157,7 +1157,7 @@ FXint runinxvt(FXString cmd)
 	nbargs--;
 
 	// Second pass to allocate the argument strings	
-	FXchar** args=(FXchar**)malloc((nbargs + 1)*sizeof(FXchar*));
+	char** args=(char**)malloc((nbargs + 1)*sizeof(char*));
 	nbargs=0;
 	i=0;
 	j=1;
@@ -1169,13 +1169,13 @@ FXint runinxvt(FXString cmd)
 			str2=cmd.section('\'',j);
 			j+=2;
 			i+=str2.contains(' ');
-			args[nbargs] = (FXchar *)malloc(str2.length()+1);
+			args[nbargs] = (char *)malloc(str2.length()+1);
 			strlcpy(args[nbargs],str2.text(),str2.length()+1);
 			nbargs++;
 		}
 		else
 		{
-			args[nbargs] = (FXchar *)malloc(str1.length()+1);
+			args[nbargs] = (char *)malloc(str1.length()+1);
 			strlcpy(args[nbargs],str1.text(),str1.length()+1);
 			nbargs++;
 		}
@@ -1189,7 +1189,7 @@ FXint runinxvt(FXString cmd)
 	args[nbargs]=NULL;
 
 	// Launch the command in an internal Xvt terminal
-	FXint res;
+	int res;
 	static pid_t childpid = 0;
     childpid = fork();
  
@@ -1220,7 +1220,7 @@ FXint runinxvt(FXString cmd)
     }
 	
 	// Free allocated strings
-	for (FXint i=0; i<nbargs; i++)
+	for (int i=0; i<nbargs; i++)
 		free(args[i]);
 	free(args);
 	
