@@ -39,14 +39,14 @@ enum
 // Note : some inline functions must be declared in the header file or it won't compile!
 
 // Convert a character to lower case
-inline FXint toLower(FXint c)
+inline int toLower(int c)
 {
 	return ('A' <= c && c <= 'Z' ? c + 32 : c);
 }
 
 
 // To test if two strings are equal (strcmp replacement, thanks to Francesco Abbate)
-inline FXint streq(const FXchar*a, const FXchar*b)
+inline int streq(const char*a, const char*b)
 {
 	if (a == NULL || b == NULL)
 		return 0;
@@ -55,7 +55,7 @@ inline FXint streq(const FXchar*a, const FXchar*b)
 
 
 // Convert a string to lower cases and returns the string size
-inline void strlow (FXchar* str)
+inline void strlow (char* str)
 {
     while (*str)
     {
@@ -66,11 +66,11 @@ inline void strlow (FXchar* str)
 
 
 // Replacement of the stat function
-inline FXint statrep(const FXchar* filename, struct stat* buf)
+inline int statrep(const char* filename, struct stat* buf)
 {
 #if defined(linux)
 
-	static FXint ret;
+	static int ret;
 
 	// It's a mount point
 	if(mtdevices->find(filename))
@@ -100,11 +100,11 @@ inline FXint statrep(const FXchar* filename, struct stat* buf)
 
 
 // Replacement of the lstat function
-inline FXint lstatrep(const FXchar* filename, struct stat* buf)
+inline int lstatrep(const char* filename, struct stat* buf)
 {
 #if defined(linux)
 
-	static FXint ret;
+	static int ret;
 
 	// It's a mount point
 	if(mtdevices->find(filename))
@@ -135,30 +135,30 @@ inline FXint lstatrep(const FXchar* filename, struct stat* buf)
 FXHotKey _parseAccel(const FXString&);
 FXbool existCommand(const FXString);
 FXString getKeybinding(FXEvent*);
-FXint mkpath(const FXchar*, mode_t);
+int mkpath(const char*, mode_t);
 FXString createTrashpathname(FXString, FXString);
-FXint createTrashinfo(FXString, FXString, FXString, FXString);
+int createTrashinfo(FXString, FXString, FXString, FXString);
 FXString mimetype(FXString);
 FXString quote(FXString);
-FXbool isUtf8(const FXchar*, FXuint);
-int statrep(const FXchar*, struct stat*);
-int lstatrep(const FXchar*, struct stat*);
+FXbool isUtf8(const char*, unsigned int);
+int statrep(const char*, struct stat*);
+int lstatrep(const char*, struct stat*);
 #if defined(linux)
-int lstatmt(const FXchar*, struct stat*);
+int lstatmt(const char*, struct stat*);
 #endif
-size_t strlcpy(FXchar*, const FXchar*, size_t);
-size_t strlcat(FXchar*, const FXchar*, size_t);
-unsigned long long dirsize(const FXchar*);
-unsigned long long pathsize(FXchar*, FXuint*, FXuint*);
-FXString hSize(FXchar*);
+size_t strlcpy(char*, const char*, size_t);
+size_t strlcat(char*, const char*, size_t);
+FXulong dirsize(const char*);
+FXulong pathsize(char*, unsigned int*, unsigned int*);
+FXString hSize(char*);
 FXString cleanPath(const FXString);
 FXString filePath(const FXString);
 FXString filePath(const FXString, const FXString);
 FXString fileFromURI(FXString);
 FXString fileToURI(const FXString&);
 long deltime(FXString);
-FXint isEmptyDir(const FXString);
-FXint hasSubDirs(const FXString);
+int isEmptyDir(const FXString);
+int hasSubDirs(const FXString);
 FXbool exists(const FXString&);
 FXbool isDirectory(const FXString&);
 FXbool isFile(const FXString&);
@@ -168,11 +168,11 @@ FXbool isReadable(const FXString&);
 FXbool isReadExecutable(const FXString&);
 FXbool isLink(const FXString&);
 FXbool info(const FXString&, struct stat&);
-FXString permissions(FXuint);
+FXString permissions(unsigned int);
 FXString readLink(const FXString&);
 FXbool identical(const FXString& ,const FXString&);
-FXint setWaitCursor(FXApp*, FXuint);
-FXint runinxvt(FXString);
+int setWaitCursor(FXApp*, unsigned int);
+int runinxvt(FXString);
 
 #endif
 
