@@ -142,7 +142,7 @@
 #endif /* KFREEBSD */
 
 /* GNU HURD */
-#if defined (__hurd__)
+#if defined (__hurd__) || defined (__gnu_hurd__) || defined (__GNU__)
 #include <sys/ioctl.h>
 #include <pty.h>
 #define BSD_PTY
@@ -214,7 +214,7 @@ static void write_utmp()
     if (pw != NULL)
         strncpy(utent.ut_name,pw->pw_name,sizeof(utent.ut_name));
     strncpy(utent.ut_host,XDisplayString(display),sizeof(utent.ut_host));
-    time(&utent.ut_time);
+    time((time_t*)&utent.ut_time);
     pututline(&utent);
     endutent();
 #endif /* SVR4_UTMP */
@@ -312,7 +312,7 @@ static void tidy_utmp()
     if (getutid(&utent) == NULL)
         return;
     utent.ut_type = DEAD_PROCESS;
-    time(&utent.ut_time);
+    time((time_t*)&utent.ut_time);
     pututline(&utent);
 #endif /* SVR4_UTMP || SVR4_UTMPX */
 #ifdef SVR4_UTMPX
